@@ -55,15 +55,16 @@ proc 3DDialog {} {
     $mb add cascade -label [msgcat::mc {Border}] -menu $mb.border
     $mb add cascade -label [msgcat::mc {Compass}] -menu $mb.compass
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] -command 3DApplyDialog
     $mb.file add command -label [msgcat::mc {Reset}] -command 3DResetDialog
     $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command 3DDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command 3DDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb ithreed
 
-    menu $mb.render
+    ThemeMenu $mb.render
     $mb.render add radiobutton -label [msgcat::mc {MIP}] \
 	-variable threed(method) -value {mip} -command 3DRenderMethod 
     $mb.render add radiobutton -label [msgcat::mc {AIP}] \
@@ -76,7 +77,7 @@ proc 3DDialog {} {
     $mb.render add radiobutton -label [msgcat::mc {Elevation}] \
 	-variable threed(background) -value {elevation} -command 3DBackground
 
-    menu $mb.highlite
+    ThemeMenu $mb.highlite
     $mb.highlite add checkbutton -label [msgcat::mc {Show}] \
 	-variable threed(highlite) -command 3DHighlite
     $mb.highlite add separator
@@ -84,7 +85,7 @@ proc 3DDialog {} {
 	-menu $mb.highlite.color
     ColorMenu $mb.highlite.color threed highlite,color 3DHighliteColor
 
-    menu $mb.border
+    ThemeMenu $mb.border
     $mb.border add checkbutton -label [msgcat::mc {Show}] \
 	-variable threed(border) -command 3DBorder
     $mb.border add separator
@@ -92,7 +93,7 @@ proc 3DDialog {} {
 	-menu $mb.border.color
     ColorMenu $mb.border.color threed border,color 3DBorderColor
 
-    menu $mb.compass
+    ThemeMenu $mb.compass
     $mb.compass add checkbutton -label [msgcat::mc {Show}] -variable threed(compass) -command 3DCompass
     $mb.compass add separator
     $mb.compass add cascade -label [msgcat::mc {Color}] -menu $mb.compass.color
@@ -137,6 +138,8 @@ proc 3DDialog {} {
     pack $w.buttons $w.sep $w.status $w.sep2 -side bottom -fill x
     pack $w.param $w.sep3 $w.scale -side top -fill x
 
+    bind $w <<Close>> 3DDestroyDialog
+
     Update3DDialog
 }
 
@@ -205,6 +208,8 @@ proc Update3DDialog {} {
 }
 
 proc 3DBackup {ch which} {
+    # zoom needs to be set before 3d view
+    puts $ch "$which zoom to [$which get zoom]"
     puts $ch "$which 3d view [$which get 3d view]"
     puts $ch "$which 3d scale [$which get 3d scale]"
     puts $ch "$which 3d method [$which get 3d method]"
@@ -368,11 +373,19 @@ proc Lock3DView {which} {
 }
 
 proc 3DMotion {which x y} {
-    global canvas
+    global ds9
     global threed
 
-    set threed(az) [expr -(double($x)/$canvas(width)  - .5) *2*90]
-    set threed(el) [expr  (double($y)/$canvas(height) - .5) *2*90]
+    set ixx [$ds9(canvas) itemcget $which -x]
+    set iyy [$ds9(canvas) itemcget $which -y]
+    set ww [$ds9(canvas) itemcget $which -width]
+    set hh [$ds9(canvas) itemcget $which -height]
+
+    set xx [expr $x-$ixx]
+    set yy [expr $y-$iyy]
+
+    set threed(az) [expr -(double($xx)/$ww  - .5) *2*90]
+    set threed(el) [expr  (double($yy)/$hh - .5) *2*90]
     if {$threed(az) < -90} {
 	set threed(az) -90
     }
@@ -429,8 +442,8 @@ proc PrefsDialog3d {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {3D}]
-    lappend dprefs(tabs) [ttk::frame $w.threed]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.threed] \
+	-text [msgcat::mc {3D}]
 
     set f [ttk::labelframe $w.threed.misc -text [msgcat::mc {Render}]]
     ttk::label $f.tmethod -text [msgcat::mc {Method}]
@@ -444,14 +457,14 @@ proc PrefsDialog3d {} {
     grid $f.tbackground $f.background -padx 2 -pady 2 -sticky w
 
     set m $f.method.menu
-    menu $m
+    ThemeMenu $m
     $m add radiobutton -label [msgcat::mc {MIP}] \
 	-variable pthreed(method) -value {mip}
     $m add radiobutton -label [msgcat::mc {AIP}] \
 	-variable pthreed(method) -value {aip}
 
     set m $f.background.menu
-    menu $m
+    ThemeMenu $m
     $m add radiobutton -label [msgcat::mc {None}] \
 	-variable pthreed(background) -value {none}
     $m add radiobutton -label [msgcat::mc {Azimuth}] \
