@@ -100,16 +100,21 @@ proc ClearAnalysis {} {
     # clear params
     for {set ii 0} {$ii<$ianalysis(param,count)} {incr ii} {
 	for {set jj 0} {$jj<$ianalysis(param,$ii,count)} {incr jj} {
-	    unset ianalysis(param,$ii,$jj,var)
-	    unset ianalysis(param,$ii,$jj,type)
-	    unset ianalysis(param,$ii,$jj,title)
-	    unset ianalysis(param,$ii,$jj,default)
-	    unset ianalysis(param,$ii,$jj,last)
-	    unset ianalysis(param,$ii,$jj,value)
-	    unset ianalysis(param,$ii,$jj,info)
+	    for {set kk 0} {$kk<$ianalysis(param,$ii,$jj,count)} {incr kk} {
+		unset ianalysis(param,$ii,$jj,$kk,var)
+		unset ianalysis(param,$ii,$jj,$kk,type)
+		unset ianalysis(param,$ii,$jj,$kk,title)
+		unset ianalysis(param,$ii,$jj,$kk,default)
+		unset ianalysis(param,$ii,$jj,$kk,last)
+		unset ianalysis(param,$ii,$jj,$kk,value)
+		unset ianalysis(param,$ii,$jj,$kk,menubutton)
+		unset ianalysis(param,$ii,$jj,$kk,info)
+	    }
+	    unset ianalysis(param,$ii,$jj)
+	    unset ianalysis(param,$ii,$jj,count)
 	}
-	unset ianalysis(param,$ii,count)
 	unset ianalysis(param,$ii)
+	unset ianalysis(param,$ii,count)
     }
     set ianalysis(param,count) 0
 }
@@ -161,8 +166,6 @@ proc InitAnalysisFile {} {
 	    }
 	}
     }
-
-#    UpdateAnalysisMenu
 }
 
 proc ProcessAnalysisFile {fn} {
@@ -178,10 +181,7 @@ proc ProcessAnalysisFile {fn} {
 	set data [read $ch]
 	close $ch
 
-	if {![ProcessAnalysis data]} {
-	    Error "[msgcat::mc {Unable to process Analysis file}] $fn"
-	    return
-	}
+	ProcessAnalysis data
 
 	# add directory to path
 	set env(PATH) "[file dirname $fn]:$env(PATH)"
@@ -209,18 +209,22 @@ proc ProcessAnalysis {varname} {
     $baseparent add separator
 
     set lines [split $var \n]
-    set l [llength $lines]
+    set len [llength $lines]
 
-    for {set ii 0} {$ii<$l} {incr ii} {
-	set line [string trim [lindex $lines $ii]]
+    for {set ll 0} {$ll<$len} {incr ll} {
+	set line [string trim [lindex $lines $ll]]
 
 	# eat empty lines and comments for all except help
 	if {$state != 6} {
 	    # empty line
-	    if {[string length $line] == 0} continue
+	    if {[string length $line] == 0} {
+		continue
+	    }
 
 	    # comments	    
-	    if {[string range $line 0 0] == "\#"} continue
+	    if {[string range $line 0 0] == "\#"} {
+		continue
+	    }
 
 	    # strip any end of line comments
 	    set id [string first "\#" $line]
@@ -234,9 +238,11 @@ proc ProcessAnalysis {varname} {
 		# param
 		if {[lindex $line 0] == {param}} {
 		    if {[lindex $line 1] != {}} {
-			set ianalysis(param,$ianalysis(param,count)) \
-			    [lindex $line 1]
-			set ianalysis(param,$ianalysis(param,count),count) 0
+			set id $ianalysis(param,count)
+			set ianalysis(param,$id) [lindex $line 1]
+			set ianalysis(param,$id,count) 0
+			set ianalysis(param,$id,0) def
+			set ianalysis(param,$id,0,count) 0
 			set state 5
 		    }
 		    continue
@@ -251,15 +257,15 @@ proc ProcessAnalysis {varname} {
 			set item Help
 		    }
 
-		    set i $ianalysis(menu,count)
-		    set ianalysis(menu,$i,parent) $currentparent
-		    set ianalysis(menu,$i,item) $item
-		    set ianalysis(menu,$i,template) {*}
-		    set ianalysis(menu,$i,cmd) {help}
-		    set ianalysis(menu,$i,inuse) 0
-		    set ianalysis(menu,$i,var) {}
+		    set ii $ianalysis(menu,count)
+		    set ianalysis(menu,$ii,parent) $currentparent
+		    set ianalysis(menu,$ii,item) $item
+		    set ianalysis(menu,$ii,template) {*}
+		    set ianalysis(menu,$ii,cmd) {help}
+		    set ianalysis(menu,$ii,inuse) 0
+		    set ianalysis(menu,$ii,var) {}
 		    $currentparent add command -label $item \
-			-command [list AnalysisTask $i menu]
+			-command [list AnalysisTask $ii menu]
 
 		    set state 6
 		    continue
@@ -279,7 +285,7 @@ proc ProcessAnalysis {varname} {
 		    lappend ianalysis(menu,hmenu) $nmenu
 		    incr ianalysis(menu,hmenu,count)
 
-		    menu $nmenu
+		    ThemeMenu $nmenu
 		    $currentparent add cascade -label "$item" -menu $nmenu
 
 		    set currentparent $nmenu
@@ -325,39 +331,39 @@ proc ProcessAnalysis {varname} {
 		    $type != {} && $cmd != {}} {
 		    switch -- [lindex $type 0] {
 			bind {
-			    set b [lindex $type 1]
-			    if {$b != {}} {
-				set i $ianalysis(bind,count)
-				set ianalysis(bind,$i,item) "<$b>"
-				set ianalysis(bind,$i,template) "$template"
-				set ianalysis(bind,$i,cmd) "$cmd"
-				set ianalysis(bind,$i,inuse) 0
+			    set bb [lindex $type 1]
+			    if {$bb != {}} {
+				set ii $ianalysis(bind,count)
+				set ianalysis(bind,$ii,item) "<$bb>"
+				set ianalysis(bind,$ii,template) "$template"
+				set ianalysis(bind,$ii,cmd) "$cmd"
+				set ianalysis(bind,$ii,inuse) 0
 				incr ianalysis(bind,count)
 			    }
 			}
 			web {
-			    set i $ianalysis(menu,count)
-			    set ianalysis(menu,$i,parent) $currentparent
-			    set ianalysis(menu,$i,item) $item
-			    set ianalysis(menu,$i,template) "$template"
-			    set ianalysis(menu,$i,cmd) {web}
-			    set ianalysis(menu,$i,inuse) 0
-			    set ianalysis(menu,$i,var) "$cmd"
+			    set ii $ianalysis(menu,count)
+			    set ianalysis(menu,$ii,parent) $currentparent
+			    set ianalysis(menu,$ii,item) $item
+			    set ianalysis(menu,$ii,template) "$template"
+			    set ianalysis(menu,$ii,cmd) {web}
+			    set ianalysis(menu,$ii,inuse) 0
+			    set ianalysis(menu,$ii,var) "$cmd"
 			    $currentparent add command -label "$item" \
-				-command [list AnalysisTask $i menu]
+				-command [list AnalysisTask $ii menu]
 			    incr ianalysis(menu,count)
 			}
 			menu {
-			    set i $ianalysis(menu,count)
-			    set ianalysis(menu,$i,parent) $currentparent
-			    set ianalysis(menu,$i,item) "$item"
-			    set ianalysis(menu,$i,template) "$template"
-			    set ianalysis(menu,$i,cmd) "$cmd"
-			    set ianalysis(menu,$i,inuse) 0
-			    set ianalysis(menu,$i,var) {}
+			    set ii $ianalysis(menu,count)
+			    set ianalysis(menu,$ii,parent) $currentparent
+			    set ianalysis(menu,$ii,item) "$item"
+			    set ianalysis(menu,$ii,template) "$template"
+			    set ianalysis(menu,$ii,cmd) "$cmd"
+			    set ianalysis(menu,$ii,inuse) 0
+			    set ianalysis(menu,$ii,var) {}
 			    $currentparent add check -label "$item" \
-				-command [list AnalysisTask $i menu] \
-				-variable ianalysis(menu,$i,inuse) \
+				-command [list AnalysisTask $ii menu] \
+				-variable ianalysis(menu,$ii,inuse) \
 				-selectcolor green
 			    incr ianalysis(menu,count)
 			}
@@ -371,36 +377,67 @@ proc ProcessAnalysis {varname} {
 	    }
 
 	    5 {
-		# end param
-		if {[lindex $line 0] == {endparam} || 
-		    [lindex $line 0] == {end}} {
-		    incr ianalysis(param,count)
-		    set state 1
-		    continue
-		}
-
 		if {[string range $line 0 0] == {@}} {
 		    ParseIRAFParam [string range $line 1 end]
 		    continue
 		}
 
-		set i $ianalysis(param,count)
-		set j $ianalysis(param,$i,count)
-		set ianalysis(param,$i,$j,var) [lindex $line 0]
-		set ianalysis(param,$i,$j,type) [lindex $line 1]
-		set ianalysis(param,$i,$j,title) [lindex $line 2]
+		set ii $ianalysis(param,count)
 
-		# default can contain the full menu 'aaa|bbb|ccc'
-		set ianalysis(param,$i,$j,default) [lindex $line 3]
-		# set last to first item
-		set ianalysis(param,$i,$j,last) \
-		    [lindex [split [lindex $line 3] |] 0]
-		# and set value to last
-		set ianalysis(param,$i,$j,value) \
-		    $ianalysis(param,$i,$j,last)
+		# endtab
+		if {[lindex $line 0] == {endtab}} {
+		    incr ianalysis(param,$ii,count)
+		    continue
+		}
 
-		set ianalysis(param,$i,$j,info) [lindex $line 4]
-		incr ianalysis(param,$i,count)
+		# end param
+		if {[lindex $line 0] == {endparam} || 
+		    [lindex $line 0] == {end}} {
+		    if {$ianalysis(param,$ii,count) == 0} {
+			incr ianalysis(param,$ii,count)
+			set $ianalysis(param,$ii) def
+		    }
+		    incr ianalysis(param,count)
+		    set state 1
+		    continue
+		}
+
+		set jj $ianalysis(param,$ii,count)
+
+		# tab
+		if {[lindex $line 0] == {tab}} {
+		    set ianalysis(param,$ii,$jj) [lindex $line 1]
+		    set ianalysis(param,$ii,$jj,count) 0
+		    continue
+		}
+
+		set kk $ianalysis(param,$ii,$jj,count)
+
+		set ianalysis(param,$ii,$jj,$kk,var) [lindex $line 0]
+		set ianalysis(param,$ii,$jj,$kk,type) [lindex $line 1]
+		set ianalysis(param,$ii,$jj,$kk,title) [lindex $line 2]
+		set ianalysis(param,$ii,$jj,$kk,default) [lindex $line 3]
+		set ianalysis(param,$ii,$jj,$kk,info) [lindex $line 4]
+		# to be filled in later
+		set ianalysis(param,$ii,$jj,$kk,menubutton) {}
+
+		switch $ianalysis(param,$ii,$jj,$kk,type) {
+		    menu {
+			# default can contain the full menu 'aaa|bbb|ccc'
+			# set last to first item
+			set pp [split $ianalysis(param,$ii,$jj,$kk,default) |]
+			set ianalysis(param,$ii,$jj,$kk,last) [lindex $pp 0]
+		    }
+		    default {
+			set ianalysis(param,$ii,$jj,$kk,last) \
+			    $ianalysis(param,$ii,$jj,$kk,default)
+		    }
+		}
+		set ianalysis(param,$ii,$jj,$kk,value) \
+		    $ianalysis(param,$ii,$jj,$kk,last)
+
+
+		incr ianalysis(param,$ii,$jj,count)
 	    }
 
 	    6 {
@@ -412,8 +449,8 @@ proc ProcessAnalysis {varname} {
 		    continue
 		}
 
-		set i $ianalysis(menu,count)
-		append ianalysis(menu,$i,var) "$line\n"
+		set ii $ianalysis(menu,count)
+		append ianalysis(menu,$ii,var) "$line\n"
 	    }
 	}
     }
@@ -427,9 +464,97 @@ proc ProcessAnalysis {varname} {
     return 1
 }
 
+proc ParseIRAFParam {filename} {
+    global ianalysis
+    global env
+
+    # we are only concerned with unix like os
+    set uparm {}
+    if {[info exists env(UPARM)]} {
+	set uparm "$env(UPARM)/$filename"
+    }
+    set iraf {}
+    if {[info exists env(HOME)]} {
+	set iraf "$env(HOME)/$filename"
+    }
+    
+    if {[file exists "$filename"]} {
+	catch {set ch [open "$filename"]}
+    } elseif {[file exists "$uparm"]} {
+	catch {set ch [open "$uparm"]}
+    } elseif {[file exists "$iraf"]} {
+	catch {set ch [open "$iraf"]}
+    } else {
+	return
+    }
+
+    set ii $ianalysis(param,count)
+
+    while {[gets $ch line] >= 0} {
+	set exp {([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),([^,]*)}
+	if {[regexp $exp $line foo p1 p2 p3 p4 p5 p6 p7]} {
+	    if {$p1 != {mode}} {
+		regsub -all {\"} $p4 {} p4
+		regsub -all {\"} $p7 {} p7
+		set jj $ianalysis(param,$ii,count)
+		set kk $ianalysis(param,$ii,$jj,count)
+		set ianalysis(param,$ii,$jj,$kk,var) "$p1"
+		if {$p3 == {h}} {
+		    set ianalysis(param,$ii,$jj,$kk,title) "(${p1})"
+		} else {
+		    set ianalysis(param,$ii,$jj,$kk,title) "$p1"
+		}
+		set ianalysis(param,$ii,$jj,$kk,info) "$p7"
+		# to be filled in later
+		set ianalysis(param,$ii,$jj,$kk,menubutton) {}
+		incr ianalysis(param,$ii,$jj,count)
+		
+		switch -- $p2 {
+		    b {
+			set ianalysis(param,$ii,$jj,$kk,type) checkbox
+			set ianalysis(param,$ii,$jj,$kk,default) [FromYesNo $p4]
+			set ianalysis(param,$ii,$jj,$kk,last) \
+			    $ianalysis(param,$ii,$jj,$kk,default)
+		    }
+		    s {
+			if {$p5 != {}} {
+			    set ianalysis(param,$ii,$jj,$kk,type) menu
+			    set ianalysis(param,$ii,$jj,$kk,default) "$p5"
+			    set pp \
+				[split $ianalysis(param,$ii,$jj,$kk,default) |]
+			    set ianalysis(param,$ii,$jj,$kk,last) [lindex $pp 0]
+			} else {
+			    set ianalysis(param,$ii,$jj,$kk,type) entry
+			    set ianalysis(param,$ii,$jj,$kk,default) "$p4"
+			    set ianalysis(param,$ii,$jj,$kk,last) \
+				$ianalysis(param,$ii,$jj,$kk,default)
+			}
+		    }
+		    default {
+			set ianalysis(param,$ii,$jj,$kk,type) entry
+			set ianalysis(param,$ii,$jj,$kk,default) "$p4"
+			set ianalysis(param,$ii,$jj,$kk,last) \
+			    $ianalysis(param,$ii,$jj,$kk,default)
+		    }
+		}
+		set ianalysis(param,$ii,$jj,$kk,value) \
+		    $ianalysis(param,$ii,$jj,$kk,last)
+	    }
+	}
+    }
+
+    close $ch
+}
+
 proc AnalysisTask {i which {frame {}} {x 0} {y 0} {sync 0}} {
     global ianalysis
     global current
+    global ds9
+
+    # MacOSX and maybe Ubuntu returns bogus values in x,y
+    # calculate our own values
+    set x [expr {[winfo pointerx $ds9(canvas)] - [winfo rootx $ds9(canvas)]}]
+    set y [expr {[winfo pointery $ds9(canvas)] - [winfo rooty $ds9(canvas)]}]
 
     if {$frame == {}} {
 	set frame $current(frame)
@@ -600,6 +725,8 @@ proc AnalysisTaskDoit {i which frame x y sync} {
     ParseZMacro cmd $frame
 
     # $message
+    ParseMessageOKMacro cmd
+
     if {![ParseMessageMacro cmd]} {
 	AnalysisTaskEnd $which $i
 	return
@@ -772,7 +899,8 @@ proc AnalysisReaderFinish {ch which i} {
 		$ianalysis($which,$i,plot,xaxis) \
 		$ianalysis($which,$i,plot,yaxis) \
 		$ianalysis($which,$i,plot,dim) \
-		$ianalysis($which,$i,result)
+		$ianalysis($which,$i,result) \
+		false
 	}
 	plotstdin {
 	    AnalysisPlotStdin line "at${which}${i}" $ianalysis($which,$i,item) \
@@ -833,9 +961,9 @@ proc AnalysisPlotStdin {type w wtt result} {
 
     if {$d != {} && $rr != {}} {
 	switch $type {
-	    line {PlotLine $w $wtt $t $x $y $d $rr}
-	    bar {PlotBar $w $wtt $t $x $y $d $rr}
-	    scatter {PlotScatter $w $wtt $t $x $y $d $rr}
+	    line {PlotLine $w $wtt $t $x $y $d $rr false}
+	    bar {PlotBar $w $wtt $t $x $y $d $rr false}
+	    scatter {PlotScatter $w $wtt $t $x $y $d $rr false}
 	}
     } else {
 	Error "[msgcat::mc {Error}] [string range $tt 0 40]"
@@ -880,7 +1008,9 @@ proc AnalysisProcessGetURL {which i result} {
 		  $ianalysis($which,$i,plot,xaxis) \
 		  $ianalysis($which,$i,plot,yaxis) \
 		  $ianalysis($which,$i,plot,dim) \
-		  $ianalysis($which,$i,result)}
+		  $ianalysis($which,$i,result) \
+		  false
+	      } 
 	plotstdin {AnalysisPlotStdin line "at${which}${i}" \
 		       $ianalysis($which,$i,item) \
 		       $ianalysis($which,$i,result)}
@@ -1555,7 +1685,7 @@ proc ParseZMacro {cmdname frame} {
     set exp1 {\$z\(([^)]*)\)}
     if {[regexp $exp1 $cmd foo pp]} {
         set sys $pp
-        set coord [$frame get fits slice from image $sys fk5]
+        set coord [$frame get fits slice from image $sys]
         regsub -all $exp1 $cmd "$coord" cmd
         return
     }
@@ -1597,6 +1727,24 @@ while {[regexp $exp $cmd foo message]} {
 return 1
 }
 
+proc ParseMessageOKMacro {cmdname} {
+    upvar $cmdname cmd
+
+    # two args
+    set exp {\|?.?\$messageok\((ok|okcancel|yesno),([^)]*)\).?\|?}
+while {[regexp $exp $cmd foo type message]} {
+    set result [AnalysisMessageOK $type $message]
+    regsub $exp $cmd $result cmd
+}
+
+# one args
+set exp {\|?.?\$messageok\(([^)]*)\).?\|?}
+while {[regexp $exp $cmd foo message]} {
+    set result [AnalysisMessageOK ok $message]
+    regsub $exp $cmd $result cmd
+}
+}
+
 proc ParseEntryMacro {cmdname} {
     upvar $cmdname cmd
     
@@ -1750,6 +1898,14 @@ proc AnalysisMessage {type message} {
     }
 }
 
+proc AnalysisMessageOK {type message} {
+    if {$type == {}} {
+	set type ok
+    }
+
+    return [tk_messageBox -message $message -type $type]
+}
+
 proc AnalysisEntry {message resultvar} {
     upvar $resultvar result
 
@@ -1769,14 +1925,14 @@ proc ProcessAnalysisCmd {varname iname buf fn} {
     upvar $varname var
     upvar $iname i
 
-	global parse
-	set parse(buf) $buf
-	set parse(fn) $fn
-	
-	analysis::YY_FLUSH_BUFFER
-	analysis::yy_scan_string [lrange $var $i end]
-	analysis::yyparse
-	incr i [expr $analysis::yycnt-1]
+    global parse
+    set parse(buf) $buf
+    set parse(fn) $fn
+    
+    analysis::YY_FLUSH_BUFFER
+    analysis::yy_scan_string [lrange $var $i end]
+    analysis::yyparse
+    incr i [expr $analysis::yycnt-1]
 }
 
 proc AnalysisCmdTask {task} {
@@ -1827,16 +1983,16 @@ proc AnalysisCmdPlotLine {title xaxis yaxis dim} {
     global parse
 
     if {$parse(buf) != {}} {
-	PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim $parse(buf)
+	PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim $parse(buf) false
     } elseif {$parse(fn) != {}} {
 	if {[file exists $parse(fn)]} {
 	    set ch [open $parse(fn) r]
 	    set rr [read $ch]
 	    close $ch
-	    PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim $rr
+	    PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim $rr false
 	}
     } else {
-	PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim {}
+	PlotLine $iap(tt) Plot $title $xaxis $yaxis $dim {} false
     }
 }
 
