@@ -218,7 +218,7 @@ proc BinDialog {} {
     $mb add cascade -label [msgcat::mc {Bin}] -menu $mb.bin
     $mb add cascade -label [msgcat::mc {Buffer}] -menu $mb.buffer
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] \
 	-command BinApplyDialog
     $mb.file add separator
@@ -228,17 +228,17 @@ proc BinDialog {} {
 	-command BinClearFilterDialog
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command BinDestroyDialog
+	-command BinDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb ibin
 
-    menu $mb.method
+    ThemeMenu $mb.method
     $mb.method add radiobutton -label [msgcat::mc {Average}] \
 	-variable bin(function) -value average -command ChangeBinFunction
     $mb.method add radiobutton -label [msgcat::mc {Sum}] \
 	-variable bin(function) -value sum -command ChangeBinFunction
 
-    menu $mb.bin
+    ThemeMenu $mb.bin
     $mb.bin add command -label [msgcat::mc {Bin In}] \
 	-command {Bin .5 .5}
     $mb.bin add command -label [msgcat::mc {Bin Out}] \
@@ -265,7 +265,7 @@ proc BinDialog {} {
     $mb.bin add radiobutton -label "[msgcat::mc {Bin}] 256" \
 	-variable bin(factor) -value {256 256} -command ChangeBinFactor
 
-    menu $mb.buffer
+    ThemeMenu $mb.buffer
     $mb.buffer add radiobutton -label {128x128} \
 	-variable bin(buffersize) -value 128 -command ChangeBinBufferSize 
     $mb.buffer add radiobutton -label {256x256} \
@@ -358,15 +358,18 @@ proc BinDialog {} {
     set dbin(auto) 0
     set dbin(minmax) 1
 
+    bind $w <<Close>> BinDestroyDialog
+
     UpdateBinDialog
 }
 
-proc PopUp {b m l cmd} {
+proc BinPopUp {b m l cmd} {
     global ds9
 
     destroy $m
 
-    menu $m -tearoff 0
+    ThemeMenu $m
+    $m configure -tearoff 0
     set cnt -1
     for {set ii 0} {$ii<[llength $l]} {incr ii} {
 	$m add command -label [lindex $l $ii] \
@@ -381,9 +384,10 @@ proc PopUp {b m l cmd} {
     }
 }
 
-proc BlankPopUp {m} {
+proc BinBlankPopUp {m} {
     destroy $m
-    menu $m -tearoff 0
+    ThemeMenu $m
+    $m configure -tearoff 0
 }
 
 proc UpdateBinDialog {} {
@@ -418,8 +422,8 @@ proc UpdateBinDialog {} {
 
 	set dbin(xcol) [lindex $cols 0]
 	set dbin(ycol) [lindex $cols 1]
-	PopUp dbin(xcol) $w.cols.x.m $colslist UpdateXCol
-	PopUp dbin(ycol) $w.cols.y.m $colslist UpdateYCol
+	BinPopUp dbin(xcol) $w.cols.x.m $colslist UpdateXCol
+	BinPopUp dbin(ycol) $w.cols.y.m $colslist UpdateYCol
 
 	set mm [$current(frame) get bin cols minmax \{$dbin(xcol)\}]
 	set dbin(xcol,min) [lindex $mm 0]
@@ -436,7 +440,7 @@ proc UpdateBinDialog {} {
 	set dbin(filter) [$current(frame) get bin filter]
 
 	set dbin(zcol) [lindex $cols 2]
-	PopUp dbin(zcol) $w.z.z.m $colslist UpdateZCol
+	BinPopUp dbin(zcol) $w.z.z.m $colslist UpdateZCol
 	set mm [$current(frame) get bin cols dim \{$dbin(zcol)\}]
 	set dbin(zcol,min) [lindex $mm 0]
 	set dbin(zcol,max) [lindex $mm 1]
@@ -458,9 +462,9 @@ proc UpdateBinDialog {} {
 	set dbin(zcol,min) {}
 	set dbin(zcol,max) {}
 
-	BlankPopUp $w.cols.x.m
-	BlankPopUp $w.cols.y.m
-	BlankPopUp $w.z.z.m
+	BinBlankPopUp $w.cols.x.m
+	BinBlankPopUp $w.cols.y.m
+	BinBlankPopUp $w.z.z.m
     }
 }
 
