@@ -58,8 +58,8 @@ proc CATDef {} {
 		       {{AC 2000.2} catac cds {I/275/ac2002}} \
 		       {{ASCC-2.5} catascss cds {I/280A/ascc01}} \
 		       {{Carlsberg Meridian 14} catcmc cds {I/304}}\
-		       {{GAIA DR1} catgaia1 cds {I/337}} \
-		       {{GAIA DR2} catgaia cds {I/345}} \
+		       {{GAIA DR1} catgaia1 cds {I/337/gaia}} \
+		       {{GAIA DR2} catgaia cds {I/345/gaia2}} \
 		       {{GSC 2.2} catgsc2 cds {I/271/out}} \
 		       {{GSC 2.3} catgsc cds {I/305/out}} \
 		       {{NOMAD} catnomad cds {I/297/out}} \
@@ -77,9 +77,11 @@ proc CATDef {} {
 		       {{USNO URAT1} caturat1 cds {I/329}} \
 		       {- {Infrared} ir} \
 		       {{2MASS Point Sources} cat2mass cds {II/246/out}}\
-		       {{IRAS Point Sources} catiras cds {II/125}}\
+		       {{IRAS Point Sources} catiras cds {II/125/main}}\
 		       {- {High Energy} hea} \
-		       {{Chandra Source} catcsc cxc {Current Release}}
+		       {{Chandra Source 1.1} catcsc11 cds {IX/45/csc11}}
+		       {{Chandra Source 2.0} catcsc20 cds {IX/57/csc2master}}
+		       {{Chandra Source Current} catcsc cxc {Current Release}}
 		       {{2XMMi Source} catxmm cds {IX/40/xmm2is}} \
 		       {{Second ROSAT PSPC} catrosat cds {IX/30}} \
 		       {- {Radio} radio} \
@@ -110,140 +112,38 @@ proc CATDef {} {
     set pcat(sym,font,slant) roman
 }
 
-# Load via HTTP
-
-proc CATGetURL {varname} {
+proc CATLoad {varname url query} {
     upvar #0 $varname var
     global $varname
 
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATGetURL $varname $var(url)?$var(query)"
+	puts stderr "CATLoad $varname $url?$query"
     }
 
-    ARStatus $varname [msgcat::mc {Loading}]
-
-    global ihttp
-    if {$var(sync)} {
-	if {![catch {set var(token) [http::geturl $var(url) \
-					 -query $var(query) \
-					 -timeout $ihttp(timeout) \
-					 -headers "[ProxyHTTP]"]
-	}]} {
-	    # reset errorInfo (may be set in http::geturl)
-	    global errorInfo
-	    set errorInfo {}
-
-	    set var(active) 1
-	    CATGetURLFinish $varname $var(token)
-	} else {
-	    ARError $varname "[msgcat::mc {Unable to locate URL}] $var(url)"
-	}
-    } else {
-	if {![catch {set var(token) [http::geturl $var(url) \
-					 -query $var(query) \
-					 -timeout $ihttp(timeout) \
-					 -command \
-					 [list CATGetURLFinish $varname] \
-					 -headers "[ProxyHTTP]"]
-	}]} {
-	    # reset errorInfo (may be set in http::geturl)
-	    global errorInfo
-	    set errorInfo {}
-
-	    set var(active) 1
-	} else {
-	    ARError $varname "[msgcat::mc {Unable to locate URL}] $var(url)"
-	}
-    }
-}
-
-proc CATGetURLFinish {varname token} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATGetURLFinish $varname"
-    }
-
-    if {!($var(active))} {
-	ARCancelled $varname
-	return
-    }
-
-    upvar #0 $token t
-
-    # Code
-    set code [http::ncode $token]
-
-    # Meta
-    set meta $t(meta)
-
-    # Log it
-    HTTPLog $token
-
-    # Result?
-    switch -- $code {
-	{} -
-	200 -
-	203 -
-	404 -
-	503 {
-	    if {[info exist ${varname}(proc,parser)]} {
-		eval [list $var(proc,parser) $var(catdb) $token]
-	    }
-
-	    ARDone $varname
-	    eval $var(proc,done) $varname
-	}
-
-	201 -
-	300 -
-	301 -
-	302 -
-	303 -
-	305 -
-	307 {
-	    foreach {name value} $meta {
-		if {[regexp -nocase ^location$ $name]} {
-		    global debug
-		    if {$debug(tcl,cat)} {
-			puts stderr "CATGetURLFinish redirect $code to $value"
-		    }
-		    # clean up and resubmit
-		    http::cleanup $token
-		    unset var(token)
-
-		    set var(url) $value
-		    eval $var(proc,load) $varname
-		}
-	    }
-	}
-
-	default {ARError $varname "[msgcat::mc {Error code was returned}] $code"}
-    }
-}
-
-proc CATLoad {varname} {
-    upvar #0 $varname var
-    global $varname
-
     # clear previous db
     global $var(catdb)
     if {[info exists $var(catdb)]} {
 	unset $var(catdb)
     }
 
+    TBLGetURL $varname $url $query
+    return
+}
+
+proc CATProcess {varname} {
+    upvar #0 $varname var
+    global $varname
+
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATLoad $varname $var(url)?$var(query)"
+	puts stderr "CATProcess $varname"
     }
 
-    set var(proc,done) CATLoadDone
-    set var(proc,load) CATLoad
-    CATGetURL $varname
-    return
+    VOTParse $var(catdb) $var(token)
+    ARDone $varname
+
+    CATLoadDone $varname
 }
 
 proc CATLoadDone {varname} {
@@ -255,7 +155,7 @@ proc CATLoadDone {varname} {
 	puts stderr "CATLoadDone $varname"
     }
 
-    CATSortMenu $varname
+    TBLSortMenu $varname
     CATConfigCols $varname
     CATColsMenu $varname
     CATTable $varname
@@ -263,165 +163,6 @@ proc CATLoadDone {varname} {
     CATDialogUpdate $varname
 }
 
-# Load via File
-
-proc CATLoadSBFile {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    set fn [OpenFileDialog catfbox]
-    if {$fn != {}} {
-	CATLoadFn $varname $fn starbase_read
-    }
-}
-
-proc CATLoadVOTFile {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    set fn [OpenFileDialog catvotfbox]
-    if {$fn != {}} {
-	CATLoadFn $varname $fn VOTRead
-    }
-}
-
-proc CATLoadTSVFile {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    set fn [OpenFileDialog cattsvfbox]
-    if {$fn != {}} {
-	CATLoadFn $varname $fn TSVRead
-    }
-}
-
-# used by backup
-proc CATLoadFn {varname fn reader} {
-    upvar #0 $varname var
-    global $varname
-    global $var(catdb)
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATLoadFn $varname $fn $reader"
-    }
-
-    ARStatus $varname [msgcat::mc {Loading Catalog}]
-
-    CATOff $varname
-    CATSet $varname {} {} $fn
-
-    set var(name) {}
-    set var(x) {}
-    set var(y) {}
-    set var(radius) {}
-
-    if {[file exists $fn]} {
-	$reader $var(catdb) $fn
-    } else {
-	Error "[msgcat::mc {Unable to open file}] $fn"
-	return
-    }
-
-    ARDone $varname
-    CATLoadDone $varname
-}
-
-# Save via File
-
-proc CATSaveSBFile {varname} {
-    set fn [SaveFileDialog catfbox]
-    CATSaveFn $varname $fn starbase_write
-}
-
-proc CATSaveVOTFile {varname} {
-    set fn [SaveFileDialog catvotfbox]
-    CATSaveFn $varname $fn VOTWrite
-}
-
-proc CATSaveTSVFile {varname} {
-    set fn [SaveFileDialog cattsvfbox]
-    CATSaveFn $varname $fn TSVWrite
-}
-
-proc CATSaveFn {varname fn writer} {
-    upvar #0 $varname var
-    global $varname
-    global $var(tbldb)
-
-    if {$fn == {}} {
-	return
-    }
-
-    # do we have a db?
-    if {![CATValidDB $var(tbldb)]} {
-	return
-    }
-
-    $writer $var(tbldb) $fn
-    ARDone $varname
-}
-
-# Other procedures
-
-proc CATStatusRows {varname rowlist} {
-    upvar #0 $varname var
-    global $varname
-
-    # rowlist start at 1
-    if {[llength $rowlist]>0} {
-	ARStatus $varname "[msgcat::mc {Row}] [join $rowlist {,}]"
-    } else {
-	ARStatus $varname {}
-    }
-}
-
-proc CATOff {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global $var(catdb)
-    if {[info exists $var(catdb)]} {
-	unset $var(catdb)
-    }
-    global $var(tbldb)
-    if {[info exists $var(tbldb)]} {
-	unset $var(tbldb)
-    }
-    set db $var(tbldb)
-    set ${db}(Nrows) {}
-
-    $var(tbl) selection clear all
-
-    if {[info commands $var(frame)] != {}} {
-	if {[$var(frame) has fits]} {
-	    $var(frame) marker catalog $varname delete
-	}
-    }
-
-    CATSortMenu $varname
-    CATColsMenu $varname
-    set var(filter) {}
-    set var(sort) {}
-    set var(colx) {}
-    set var(coly) {}
-
-    set var(blink) 0
-
-    # plot window?
-    if {$var(plot)} {
-	PlotDestroy $var(plot,var)
-	set var(plot) 0
-	set var(plot,var) {}
-	set var(plot,x) {}
-	set var(plot,xerr) {}
-	set var(plot,y) {}
-	set var(plot,yerr) {}
-    }
-
-    CATDialogUpdate $varname
-}
-
 # used by backup
 proc CATTable {varname} {
     upvar #0 $varname var
@@ -434,7 +175,7 @@ proc CATTable {varname} {
 	puts stderr "CATTable $varname"
     }
 
-    if {![CATValidDB $var(catdb)]} {
+    if {![TBLValidDB $var(catdb)]} {
 	return
     }
 
@@ -460,7 +201,7 @@ proc CATTable {varname} {
     } else {
 	set var(tbldb) ${varname}tbldb
 	global $var(tbldb)
-	if {![CATFltSort $varname]} {
+	if {![TBLFltSort $varname $var(catdb) $var(tbldb)]} {
 	    Error "[msgcat::mc {Unable to evaluate filter}] $var(filter)"
 	    if {[info exists $var(tbldb)]} {
 		unset $var(tbldb)
@@ -520,7 +261,7 @@ proc CATGenerate {varname} {
     }
 
     # do we have a db?
-    if {![CATValidDB $var(tbldb)]} {
+    if {![TBLValidDB $var(tbldb)]} {
 	return
     }
 
@@ -540,7 +281,7 @@ proc CATGenerate {varname} {
 	if {[info commands $var(frame)] != {}} {
 	    if {[$var(frame) has fits]} {
 		if {[catch {$var(frame) marker catalog command ds9 var reg}]} {
-		    ARError $varname "[msgcat::mc {Internal Parse Error}]"
+		    $var(proc,error) $varname "[msgcat::mc {Internal Parse Error}]"
 		    return
 		}
 	    }
@@ -561,7 +302,7 @@ proc CATGenerateRegions {varname} {
     }
 
     # do we have a db?
-    if {![CATValidDB $var(tbldb)]} {
+    if {![TBLValidDB $var(tbldb)]} {
 	return
     }
 
@@ -573,7 +314,7 @@ proc CATGenerateRegions {varname} {
     if {[info commands $var(frame)] != {}} {
 	if {[$var(frame) has fits]} {
 	    if {[catch {$var(frame) marker command ds9 var reg}]} {
-		ARError $varname "[msgcat::mc {Internal Parse Error}]"
+		$var(proc,error) $varname "[msgcat::mc {Internal Parse Error}]"
 		return
 	    }
 	}
@@ -582,6 +323,128 @@ proc CATGenerateRegions {varname} {
     ARStatus $varname [msgcat::mc Done]
 }
 
+# Load via File
+
+proc CATLoadVOTFile {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn [OpenFileDialog votfbox $var(top)]
+    if {$fn != {}} {
+	CATLoadFn $varname $fn VOTRead
+    }
+}
+
+proc CATLoadRDBFile {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn [OpenFileDialog rdbfbox $var(top)]
+    if {$fn != {}} {
+	CATLoadFn $varname $fn starbase_read
+    }
+}
+
+proc CATLoadTSVFile {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn [OpenFileDialog tsvfbox $var(top)]
+    if {$fn != {}} {
+	CATLoadFn $varname $fn TSVRead
+    }
+}
+
+proc CATLoadFITSFile {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set fn [OpenFileDialog catfitsfbox $var(top)]
+    if {$fn != {}} {
+	CATLoadFn $varname $fn FITSRead
+    }
+}
+
+# used by backup
+proc CATLoadFn {varname fn reader} {
+    upvar #0 $varname var
+    global $varname
+    global $var(catdb)
+
+    global debug
+    if {$debug(tcl,cat)} {
+	puts stderr "CATLoadFn $varname $fn $reader"
+    }
+
+    ARStatus $varname [msgcat::mc {Loading Catalog}]
+
+    CATOff $varname
+    CATSet $varname {} {} $fn
+
+    set var(name) {}
+    set var(x) {}
+    set var(y) {}
+    set var(radius) {}
+
+    if {[file exists $fn]} {
+	$reader $var(catdb) $fn
+    } else {
+	Error "[msgcat::mc {Unable to open file}] $fn"
+	return
+    }
+
+    ARDone $varname
+    CATLoadDone $varname
+}
+
+# Other procedures
+
+proc CATOff {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    global $var(catdb)
+    if {[info exists $var(catdb)]} {
+	unset $var(catdb)
+    }
+    global $var(tbldb)
+    if {[info exists $var(tbldb)]} {
+	unset $var(tbldb)
+    }
+    set db $var(tbldb)
+    set ${db}(Nrows) {}
+
+    $var(tbl) selection clear all
+
+    if {[info commands $var(frame)] != {}} {
+	if {[$var(frame) has fits]} {
+	    $var(frame) marker catalog $varname delete
+	}
+    }
+
+    TBLSortMenu $varname
+    CATColsMenu $varname
+    set var(filter) {}
+    set var(sort) {}
+    set var(colx) {}
+    set var(coly) {}
+
+    set var(blink) 0
+
+    # plot window?
+    if {$var(plot)} {
+	PlotDestroy $var(plot,var)
+	set var(plot) 0
+	set var(plot,var) {}
+	set var(plot,x) {}
+	set var(plot,xerr) {}
+	set var(plot,y) {}
+	set var(plot,yerr) {}
+    }
+
+    CATDialogUpdate $varname
+}
+
 proc CATGenerateUpdate {varname row} {
     upvar #0 $varname var
     global $varname
@@ -640,25 +503,10 @@ proc CATSet {varname format catalog title} {
     set var(sort,dir) "-increasing"
 }
 
-proc CATValidDB {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    if {[info exists var(Nrows)] && 
-	[info exists var(Ncols)] &&
-	[info exists var(HLines)] &&
-	[info exists var(Header)]} {
-	return 1
-    } else {
-	return 0
-    }
-}
-
-proc CATAnalysisMenu {} {
+proc CATAnalysisMenu {mb} {
     global icat
     global ds9
 
-    set mm "$ds9(mb).analysis.cat"
     set nn {}
 
     foreach ff $icat(def) {
@@ -668,12 +516,12 @@ proc CATAnalysisMenu {} {
 	set cc [lindex $ff 3]
 
 	if {$ll != {-}} {
-	    $mm.$nn add command -label $ll \
+	    $mb.$nn add command -label $ll \
 		-command [list CATDialog $ww $ss $cc $ll apply]
 	} else {
 	    set nn "$ss"
-	    menu $mm.$nn
-	    $mm add cascade -label $ww -menu $mm.$nn
+	    ThemeMenu $mb.$nn
+	    $mb add cascade -label $ww -menu $mb.$nn
 	}
     }
 }
@@ -686,7 +534,7 @@ proc CATServerMenu {varname} {
 
     $var(mb) add cascade -label [msgcat::mc {Catalog Server}] \
 	-menu $var(mb).server
-    menu $var(mb).server
+    ThemeMenu $var(mb).server
 
     set ll [llength $icat(server,menu)]
     for {set ii 0} {$ii<$ll} {incr ii} {
@@ -696,41 +544,6 @@ proc CATServerMenu {varname} {
     }
 }
 
-proc CATSortMenu {varname} {
-    upvar #0 $varname var
-    global $varname
-    global $var(catdb)
-
-    global ds9
-
-    set m $var(sortmenu).menu
-    catch {destroy $m}
-
-    menu $m -tearoff 0
-    $m add command -label {} -command "CATSortCmd $varname {}"
-    if {[CATValidDB $var(catdb)]} {
-	set cnt -1
-	foreach col [starbase_columns $var(catdb)] {
-	    $m add command -label $col -command "CATSortCmd $varname \{$col\}"
-
-	    # wrap if needed
-	    incr cnt
-	    if {$cnt>=$ds9(menu,size,wrap)} {
-		set cnt 0
-		$m entryconfig $col -columnbreak 1
-	    }
-	}
-    }
-}
-
-proc CATSortCmd {varname val} {
-    upvar #0 $varname var
-    global $varname
-
-    set ${varname}(sort) $val
-    CATTable $varname
-}
-
 # backward backup compatibility version 6.1
 proc CATRADECMenu {varname} {
     CATColsMenu $varname
@@ -747,8 +560,9 @@ proc CATColsMenu {varname} {
     set m $var(ramenu).menu
     catch {destroy $m}
 
-    menu $m -tearoff 0
-    if {[CATValidDB $var(catdb)]} {
+    ThemeMenu $m
+    $m configure -tearoff 0
+    if {[TBLValidDB $var(catdb)]} {
 	set cnt -1
 	foreach col [starbase_columns $var(catdb)] {
 	    $m add command -label $col -command "CATColXCmd $varname \{$col\}"
@@ -765,8 +579,9 @@ proc CATColsMenu {varname} {
     set m $var(decmenu).menu
     catch {destroy $m}
 
-    menu $m -tearoff 0
-    if {[CATValidDB $var(catdb)]} {
+    ThemeMenu $m
+    $m configure -tearoff 0
+    if {[TBLValidDB $var(catdb)]} {
 	set cnt -1
 	foreach col [starbase_columns $var(catdb)] {
 	    $m add command -label $col -command "CATColYCmd $varname \{$col\}"
@@ -813,7 +628,7 @@ proc CATConfigCols {varname} {
     set var(colx) {}
     set var(coly) {}
 
-    if {![CATValidDB $var(catdb)]} {
+    if {![TBLValidDB $var(catdb)]} {
 	return
     }
 
@@ -997,14 +812,6 @@ proc CATTool {} {
     CATDialog cattool {} {} [msgcat::mc {Catalog Tool}] none
 }
 
-proc CATClearFrame {} {
-    global current
-
-    if {$current(frame) != {}} {
-	$current(frame) marker catalog delete all
-    }
-}
-
 proc CATUpdateWCS {} {
     global icat
     global current
@@ -1026,17 +833,6 @@ proc CATUpdateWCS {} {
     }
 }
 
-proc CATUpdateFont {} {
-    global icat
-
-    foreach varname $icat(cats) {
-	upvar #0 $varname var
-	global $varname
-
-	$var(tbl) configure -font [font actual TkDefaultFont]
-    }
-}
-
 proc CATBackup {ch which fdir rdir} {
     global icat
 
@@ -1055,7 +851,7 @@ proc CATBackup {ch which fdir rdir} {
 		set rfn $rdir/${varname}.cat
 
 		catch {file delete -force $fn}
-		CATSaveFn $varname $fn VOTWrite
+		TBLSaveFn $varname $fn VOTWrite
 		puts $ch "CATLoadFn $varname \"$rfn\" VOTRead"
 	    } else {
 		# internal var
@@ -1082,8 +878,8 @@ proc PrefsDialogCatalog {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Catalogs}]
-    lappend dprefs(tabs) [ttk::frame $w.cat]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.cat] \
+	-text [msgcat::mc {Catalogs}]
 
     # Catalog
     set f [ttk::labelframe $w.cat.param -text [msgcat::mc {Catalogs}]]
@@ -1106,7 +902,7 @@ proc PrefsDialogCatalog {} {
     FontMenuButton $f.font pcat sym,font sym,font,size \
 	sym,font,weight, sym,font,slant {}
 
-    menu $f.svr.menu
+    ThemeMenu $f.svr.menu
 
     set ll [llength $icat(server,menu)]
     for {set ii 0} {$ii<$ll} {incr ii} {
@@ -1115,7 +911,7 @@ proc PrefsDialogCatalog {} {
 	-variable pcat(server) -value [lindex $item 1]
     }
 
-    menu $f.shape.menu
+    ThemeMenu $f.shape.menu
     $f.shape.menu add radiobutton -label [msgcat::mc {Circle}] \
 	-variable pcat(sym,shape) -value circle
     $f.shape.menu add radiobutton -label [msgcat::mc {Ellipse}] \
@@ -1127,7 +923,7 @@ proc PrefsDialogCatalog {} {
     $f.shape.menu add cascade -label [msgcat::mc {Point}] \
 	-menu $f.shape.menu.point
 
-    menu $f.shape.menu.point
+    ThemeMenu $f.shape.menu.point
     $f.shape.menu.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable pcat(sym,shape) -value {circle point}
     $f.shape.menu.point add radiobutton -label [msgcat::mc {Box}] \
@@ -1174,25 +970,41 @@ proc ProcessCatalogCmd {varname iname} {
     incr i [expr $cat::yycnt-1]
 }
 
-proc CatalogCmdCheck {} {
-    global cvarname
-    upvar #0 $cvarname cvar
+proc ProcessSendCatalogCmd {proc id param sock fn} {
+    global icat
 
-    if {![info exists cvar(top)]} {
-	Error "[msgcat::mc {Unable to find catalog window}] $cvarname"
-	return 0
+    set rr {}
+    foreach ii $icat(cats) {
+	lappend rr [string replace $ii 0 2]
     }
-    if {![winfo exists $cvar(top)]} {
-	Error "[msgcat:: mc {Unable to find catalog window}] $cvarname"
-	return 0
-    }
-    return 1
+    $proc $id "$rr\n"
 }
 
 proc CatalogCmdRef {ref} {
     global icat
     global cvarname
 
+    # backward compatibility
+    if {$ref == "cxc"} {
+	set ref csc
+    }
+    set rr cat${ref}
+    set id [lsearch $icat(cats) $rr]
+
+    # look for reference in current list
+    if { $id < 0} {
+	Error "[msgcat::mc {Unable to find catalog window}] $ref"
+	return
+    }
+
+    set icat(cats) [lreplace $icat(cats) $id $id]
+    lappend icat(cats) $rr
+}
+
+proc CatalogCmdRetrieve {ref} {
+    global icat
+    global cvarname
+
     # backward compatibility
     if {$ref == "cxc"} {
 	set ref csc
@@ -1209,30 +1021,12 @@ proc CatalogCmdRef {ref} {
 
 	    if {$ll != {-} && "cat${ref}" == $ww} {
 		CATDialog $ww $ss $cc $ll sync
-		set cvarname cat${ref}
 		return
 	    }
 	}
 
 	# not a default, assume other name
 	CATDialog cat${ref} cds $ref $ref sync
-	set cvarname cat${ref}
-    }
-}
-
-proc CatalogCmdFilterLoad {fn} {
-    global cvarname
-    upvar #0 $cvarname cvar
-
-    if {$fn != {}} {
-	if {[catch {open $fn r} fp]} {
-	    Error "[msgcat::mc {Unable to open file}] $fn: $fp"
-	    yyerror
-	}
-	set flt [read -nonewline $fp]
-	catch {regsub {\n} $flt " " $flt}
-	set cvar(filter) [string trim $flt]
-	catch {close $fp}
     }
 }
 
@@ -1240,9 +1034,8 @@ proc CatalogCmdLoad {fn reader} {
     global icat
 
     if {$fn != {}} {
-	CATDialog cattool {} {} {} none
+	CATDialog cattool {} {} [msgcat::mc {Catalog Tool}] none
 	CATLoadFn [lindex $icat(cats) end] $fn $reader
-	FileLast catfbox $fn
     }
 }
 
@@ -1298,15 +1091,6 @@ proc CatalogCmdSAMPSend {name} {
     }
 }
 
-proc CatalogCmdSave {fn writer} {
-    global cvarname
-
-    if {$fn != {}} {
-	CATSaveFn $cvarname $fn $writer
-    	FileLast catfbox $fn
-    }
-}
-
 proc CatalogCmdSkyframe {skyframe} {
     global cvarname
     upvar #0 $cvarname cvar
@@ -1422,48 +1206,3 @@ proc CatalogCmdSymbolSave {fn} {
 
     starbase_write $cvar(symdb) $fn
 }
-
-proc ProcessSendCatalogCmd {proc id param sock fn} {
-    global parse
-    set parse(proc) $proc
-    set parse(id) $id
-    set parse(sock) $sock
-    set parse(fn) $fn
-
-    global icat
-    set ref [lindex $icat(cats) end]
-    global cvarname
-    set cvarname $ref
-
-    catsend::YY_FLUSH_BUFFER
-    catsend::yy_scan_string $param
-    catsend::yyparse
-}
-
-proc CatalogSendCmdHeader {} {
-    global parse
-    global cvarname
-
-    ProcessSend $parse(proc) $parse(id) $parse(sock) $parse(fn) \
-	{.txt} [CATGetHeader $cvarname]
-}
-
-proc CatalogSendCmdRef {ref} {
-    global icat
-    global cvarname
-
-    # backward compatibility
-    if {$ref == "catcxc"} {
-	set ref catcsc
-    }
-
-    # look for reference in current list
-    if {[lsearch $icat(cats) $ref] < 0} {
-	Error "[msgcat::mc {Unable to find catalog window}] $ref"
-	return 0
-    }
-
-    set cvarname $ref
-    return [CatalogCmdCheck]
-}
-
