@@ -14,14 +14,11 @@ proc CATCDS {varname} {
 	puts stderr "CATCDS $varname"
     }
 
-    # go for votable or tsv
-    set var(proc,parser) VOTParse
-
     # url
     set site [CATCDSURL $var(server)]
     set cgidir {viz-bin}
     set script {votable}
-    set var(url) "http://$site/$cgidir/$script"
+    set url "http://$site/$cgidir/$script"
     
     # query
     switch $var(skyformat) {
@@ -80,10 +77,7 @@ proc CATCDS {varname} {
 	append query "&-out.all"
     }
 
-    # url?query
-    set var(query) $query
-
-    CATLoad $varname
+    CATLoad $varname $url $query
 }
 
 proc CATCDSURL {server} {
