@@ -26,8 +26,12 @@ proc CATCDSSrchDialog {varname} {
 	return
     }
 
+    # procs
+    set var(proc,process) CATCDSSrchProcess
+    set var(proc,load) CATCDSSrchLoad
+    set var(proc,error) ARError
+
     # defaults
-    # maybe modified
     set var(list,wave,param) $icatcdssrch(list,wave,param)
     set var(list,wave) $icatcdssrch(list,wave)
     set var(list,mission,param) $icatcdssrch(list,mission,param)
@@ -58,23 +62,24 @@ proc CATCDSSrchDialog {varname} {
 
     # file
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
-    menu $mb.file
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command "CATCDSSrchLoadFile $varname" -accelerator "${ds9(ctrl)}O"
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command "CATCDSSrchSaveFile $varname" -accelerator "${ds9(ctrl)}S"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Retrieve}] \
 	-command "CATCDSSrchApply $varname"
     $mb.file add command -label [msgcat::mc {Cancel}] \
 	-command "ARCancel $varname"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Load}] \
 	-command "CATCDSSrchCatalog $varname"
     $mb.file add command -label [msgcat::mc {Clear}] \
 	-command "CATCDSSrchClear $varname"
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load}]..." \
-	-command "CATCDSSrchLoadFile $varname"
-    $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command "CATCDSSrchSaveFile $varname"
-    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command "CATCDSSrchDestroy $varname"
+	-command "CATCDSSrchDestroy $varname" -accelerator "${ds9(ctrl)}W"
 
     # edit
     AREditMenu $varname
@@ -121,13 +126,15 @@ proc CATCDSSrchDialog {varname} {
 
     ttk::scrollbar $f.srch.wave.f.scroll \
 	-command [list $f.srch.wave.f.list yview]
-    set ${varname}(listbox,wave) [listbox $f.srch.wave.f.list \
-				      -yscroll \
-				      [list $f.srch.wave.f.scroll set] \
-				      -setgrid true \
-				      -selectmode browse \
-				      -exportselection 0 \
-				      -listvariable ${varname}(list,wave)]
+    set var(listbox,wave) [ttk::treeview $f.srch.wave.f.list \
+			       -yscroll [list $f.srch.wave.f.scroll set] \
+			       -selectmode browse \
+			       -show tree \
+			      ]
+    foreach tt $var(list,wave) {
+	$var(listbox,wave) insert {} end -id $tt -text $tt
+    }
+
     grid $f.srch.wave.f.list $f.srch.wave.f.scroll -sticky news
     grid rowconfigure $f.srch.wave.f 0 -weight 1
     grid columnconfigure $f.srch.wave.f 0 -weight 1
@@ -141,13 +148,15 @@ proc CATCDSSrchDialog {varname} {
 
     ttk::scrollbar $f.srch.mission.f.scroll \
 	-command [list $f.srch.mission.f.list yview]
-    set ${varname}(listbox,mission) [listbox $f.srch.mission.f.list \
-					 -yscroll \
-					 [list $f.srch.mission.f.scroll set] \
-					 -setgrid true \
-					 -selectmode browse \
-					 -exportselection 0 \
-					 -listvariable ${varname}(list,mission)]
+    set var(listbox,mission) [ttk::treeview $f.srch.mission.f.list \
+				  -yscroll [list $f.srch.mission.f.scroll set] \
+				  -selectmode browse \
+				  -show tree \
+				 ]
+    foreach tt $var(list,mission) {
+	$var(listbox,mission) insert {} end -id $tt -text $tt
+    }
+
     grid $f.srch.mission.f.list $f.srch.mission.f.scroll \
 	-sticky news
     grid rowconfigure $f.srch.mission.f 0 -weight 1
@@ -162,13 +171,14 @@ proc CATCDSSrchDialog {varname} {
 
     ttk::scrollbar $f.srch.astro.f.scroll \
 	-command [list $f.srch.astro.f.list yview]
-    set ${varname}(listbox,astro) [listbox $f.srch.astro.f.list \
-				       -yscroll \
-				       [list $f.srch.astro.f.scroll set] \
-				       -setgrid true \
-				       -selectmode browse \
-				       -exportselection 0 \
-				       -listvariable ${varname}(list,astro)]
+    set var(listbox,astro) [ttk::treeview $f.srch.astro.f.list \
+				-yscroll [list $f.srch.astro.f.scroll set] \
+				-selectmode browse \
+				-show tree \
+			       ]
+    foreach tt $var(list,astro) {
+	$var(listbox,astro) insert {} end -id $tt -text $tt
+    }
     grid $f.srch.astro.f.list $f.srch.astro.f.scroll -sticky news
     grid rowconfigure $f.srch.astro.f 0 -weight 1
     grid columnconfigure $f.srch.astro.f 0 -weight 1
@@ -190,15 +200,21 @@ proc CATCDSSrchDialog {varname} {
 		      -maxwidth 400 \
 		      -maxheight 190 \
 		      -titlerows 1 \
+		      -resizeborders col \
 		      -xscrollcommand [list $f.xscroll set]\
 		      -yscrollcommand [list $f.yscroll set]\
 		      -selecttype row \
 		      -selectmode extended \
 		      -anchor w \
 		      -font [font actual TkDefaultFont] \
-		      -fg $ds9(gui,fg) -bg $ds9(gui,bg) \
+		      -fg [ThemeTreeForeground] \
+		      -bg [ThemeTreeBackground] \
 		     ]
 
+    $var(tbl) tag configure sel \
+	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
+    $var(tbl) tag configure title -fg [ThemeForeground] -bg [ThemeBackground]
+
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] \
 	-orient vertical
     ttk::scrollbar $f.xscroll -command [list $var(tbl) xview] \
@@ -245,10 +261,15 @@ proc CATCDSSrchDialog {varname} {
     ARStatus $varname {}
 
     # initialize
-    $var(listbox,wave) selection set 0
-    $var(listbox,mission) selection set 0
-    $var(listbox,astro) selection set 0
+    $var(listbox,wave) selection set [lindex $var(list,wave) 0]
+    $var(listbox,mission) selection set [lindex $var(list,mission) 0]
+    $var(listbox,astro) selection set [lindex $var(list,astro) 0]
+
     $w.param.name.source select range 0 end
+
+    bind $w <<Open>> [list CATCDSSrchLoadFile $varname]
+    bind $w <<Save>> [list CATCDSSrchSaveFile $varname]
+    bind $w <<Close>> [list CATCDSSrchDestroy $varname]
 }
 
 proc CATCDSSrchApply {varname} {
@@ -262,31 +283,64 @@ proc CATCDSSrchApply {varname} {
 	puts stderr "CATCDSSrchApply $varname"
     }
 
-    set id [$var(listbox,wave) curselection]
-    if {$id > 0} {
-	set var(wave) [lindex $var(list,wave) $id]
-    } else {
+    set var(wave) [$var(listbox,wave) selection]
+    if {$var(wave) == {none}} {
 	set var(wave) {}
     }
-    set id [$var(listbox,mission) curselection]
-    if {$id > 0} {
-	set var(mission) [lindex $var(list,mission) $id]
-    } else {
+    set var(mission) [$var(listbox,mission) selection]
+    if {$var(mission) == {none}} {
 	set var(mission) {}
     }
-    set id [$var(listbox,astro) curselection]
-    if {$id > 0} {
-	set var(astro) [lindex $var(list,astro) $id]
-    } else {
+    set var(astro) [$var(listbox,astro) selection]
+    if {$var(astro) == {none}} {
 	set var(astro) {}
     }
 
     ARApply $varname
-    ARStatus $varname [msgcat::mc {Searching for catalogs}]
-
+    ARStatus $varname [msgcat::mc {Contacting Server}]
     CATCDSSrch $varname
 }
 
+proc CATCDSSrch {varname} {
+    upvar #0 $varname var
+    global $varname
+    global pcat
+
+    global debug
+    if {$debug(tcl,cat)} {
+	puts stderr "CATCDSSrch $varname"
+    }
+
+    #url
+    set site [CATCDSURL $var(server)]
+    set cgidir {viz-bin}
+    set script {votable}
+    set url "http://$site/$cgidir/$script"
+    
+    # defaults
+    set query {-meta}
+    append query "&[http::formatQuery -out.max 1000]"
+    append query "&[http::formatQuery -out.form VOTable]"
+
+    if {$var(source) != {}} {
+	append query "&[http::formatQuery -source $var(source)]"
+    }
+    if {$var(words) !={}} {
+	append query "&[http::formatQuery -words $var(words)]"
+    }
+    if {$var(wave) !={}} {
+	append query "&[http::formatQuery $var(list,wave,param) $var(wave)]"
+    }
+    if {$var(mission) !={}} {
+	append query "&[http::formatQuery $var(list,mission,param) $var(mission)]"
+    }
+    if {$var(astro) !={}} {
+	append query "&[http::formatQuery $var(list,astro,param) $var(astro)]"
+    }
+
+    CATCDSSrchLoad $varname $url $query
+}
+
 proc CATCDSSrchDestroy {varname} {
     upvar #0 $varname var
     global $varname
@@ -303,173 +357,3 @@ proc CATCDSSrchDestroy {varname} {
 
     ARDestroy $varname
 }
-
-proc CATCDSSrchConfig {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATCDSSrchConfig $varname"
-    }
-
-    set site [CATCDSURL $var(server)]
-    set cgidir {viz-bin}
-    set script {votable}
-
-    set var(url) "http://$site/$cgidir/$script"
-    set var(query) [http::formatQuery -meta.aladin all]
-
-    CATCDSSrchConfigLoad $varname
-    return
-}
-
-proc CATCDSSrchConfigLoad {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATCDSSrchConfigLoad $varname"
-    }
-
-    set var(proc,parser) CATCDSSrchConfigParse
-    set var(proc,done) CATCDSSrchConfigDone
-    set var(proc,load) CATCDSSrchConfigLoad
-    CATGetURL $varname
-    return 
-}
-
-proc CATCDSSrchConfigDone {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATCDSSrchConfigDone $varname"
-    }
-
-    CATCDSSrchConfigParse
-}
-
-proc CATCDSSrchConfigParse {t token} {
-    upvar #0 $t T
-    global $t
-    global debug
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATCDSSrchConfigParse"
-    }
-    if {$debug(tcl,cat)} {
-	set fp [open debug.xml w]
-	puts $fp [http::data $token]
-	close $fp
-    }
-
-    set xml [xml::parser \
-		 -elementstartcommand [list CATCDSSrchConfigElemStartCB $t] \
-		 -elementendcommand [list CATCDSSrchConfigElemEndCB $t] \
-		 -ignorewhitespace 1 \
-		]
-
-    set T(tree,enable) 0
-    set T(tree,state) {}
-    if {[catch {$xml parse [http::data $token]} err]} {
-	if {$debug(tcl,cat)} {
-	    puts stderr "CATCDSSrchConfigParse: $err"
-	}
-    }
-    unset ${t}(tree,enable)
-    unset ${t}(tree,state)
-
-    $xml free
-}
-
-proc CATCDSSrchConfigElemStartCB {t name attlist args} {
-    upvar #0 $t T
-    global $t
-    global debug
-
-    # hardcoded
-    set varname catcdssrch1
-    upvar #0 $varname var
-    global $varname
-
-    switch -- $name {
-	RESOURCE {
-	    set id {}
-	    set type {}
-	    foreach {key value} $attlist {
-		switch -- [string tolower $key] {
-		    type {set type "$value"}
-		    id {set id "$value"}
-		}
-	    }
-	    if {[string tolower $id] == "vizier"} {
-		set T(tree,enable) 1
-
-		set ${varname}(list,wave) [list none]
-		set ${varname}(list,mission) [list none]
-		set ${varname}(list,astro) [list none]
-	    }
-	}
-	PARAM {
-	    if {$T(tree,enable)} {
-		set id {}
-		set fname {}
-		foreach {key value} $attlist {
-		    switch -- [string tolower $key] {
-			name {set fname "$value"}
-			id {set id "$value"}
-		    }
-		}
-		set T(tree,state) [string trim [string tolower $id]]
-		switch -- $T(tree,state) {
-		    wavelength {set ${varname}(list,wave,param) $fname}
-		    mission {set ${varname}(list,mission,param) $fname}
-		    astronomy {set ${varname}(list,astro,param) $fname}
-		}
-		
-	    }
-	}
-	VALUES {}
-	OPTION {
-	    if {$T(tree,enable)} {
-		set item {}
-		foreach {key value} $attlist {
-		    switch -- [string tolower $key] {
-			value {set item "$value"}
-		    }
-		}
-		if {$item != {}} {
-		    global icatcdssrch
-		    switch -- $T(tree,state) {
-			wavelength {lappend ${varname}(list,wave) $item}
-			mission {lappend ${varname}(list,mission) $item}
-			astronomy {lappend ${varname}(list,astro) $item}
-		    }
-		}
-	    }
-	}
-    }
-
-    return {}
-}
-
-proc CATCDSSrchConfigElemEndCB {t name args} {
-    upvar #0 $t T
-    global $t
-    global debug
-
-    # we can't count on this being called for all end-tags
-    switch -- $name {
-	RESOURCE {
-	    # ok, we're done
-	    set T(tree,enable) 0
-	    return -code break
-	}
-    }
-
-    return {}
-}
