@@ -45,6 +45,12 @@ proc CATDialog {varname format catalog title action} {
     # AR variables
     ARInit $varname CATServer
 
+    # procs
+    set var(proc,process) CATProcess
+    set var(proc,load) CATLoad
+    set var(proc,error) ARError
+    set var(proc,table) CATTable
+
     # CAT variables
     lappend icat(cats) $varname
 
@@ -108,11 +114,11 @@ proc CATDialog {varname format catalog title action} {
     $mb add cascade -label [msgcat::mc {Preferences}] -menu $mb.prefs
 
     # file
-    menu $mb.file
-    $mb.file add command -label "[msgcat::mc {Load}]..." \
-	-command [list CATLoadVOTFile $varname]
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command [list CATLoadVOTFile $varname] -accelerator "${ds9(ctrl)}O"
     $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command [list CATSaveVOTFile $varname]
+	-command [list TBLSaveVOTFile $varname] -accelerator "${ds9(ctrl)}S"
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {Import}] -menu $mb.file.import
     $mb.file add cascade -label [msgcat::mc {Export}] -menu $mb.file.export
@@ -142,36 +148,38 @@ proc CATDialog {varname format catalog title action} {
 	-command [list CATAck $varname]
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Update from Current Frame}] \
-	-command [list CATUpdate $varname]
+	-command [list TBLUpdate $varname]
     $mb.file add command \
 	-label [msgcat::mc {Update from Current Crosshair}] \
-	-command [list CATCrosshair $varname]
+	-command [list TBLCrosshair $varname]
     $mb.file add separator
 	$mb.file add command -label [msgcat::mc {Copy to Regions}] \
 	-command [list CATGenerateRegions $varname]
     $mb.file add separator
     $mb.file add command -label "[msgcat::mc {Print}]..." \
-	-command [list CATPrint $varname]
+	-command [list TBLPrint $varname] -accelerator "${ds9(ctrl)}P"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command [list CATDestroy $varname]
+	-command [list CATDestroy $varname] -accelerator "${ds9(ctrl)}W"
 
     # Import
-    menu $mb.file.import
+    ThemeMenu $mb.file.import
     $mb.file.import add command -label "[msgcat::mc {Starbase}]..." \
-	-command [list CATLoadSBFile $varname]
+	-command [list CATLoadRDBFile $varname]
     $mb.file.import add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
 	-command [list CATLoadTSVFile $varname]
+    $mb.file.import add command -label "[msgcat::mc {FITS}]..." \
+	-command [list CATLoadFITSFile $varname]
 
     # Export
-    menu $mb.file.export
+    ThemeMenu $mb.file.export
     $mb.file.export add command -label "[msgcat::mc {Starbase}]..." \
-	-command [list CATSaveSBFile $varname]
+	-command [list TBLSaveRDBFile $varname]
     $mb.file.export add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
-	-command [list CATSaveTSVFile $varname]
+	-command [list TBLSaveTSVFile $varname]
 
     # SAMP
-    menu $mb.file.samp
+    ThemeMenu $mb.file.samp
     $mb.file.samp add command -label [msgcat::mc {Connect}] \
 	-command SAMPConnect
     $mb.file.samp add command -label [msgcat::mc {Disconnect}] \
@@ -180,17 +188,17 @@ proc CATDialog {varname format catalog title action} {
     $mb.file.samp add cascade -label [msgcat::mc {Send}] \
 	-menu $mb.file.samp.send
 
-    menu $mb.file.samp.send
+    ThemeMenu $mb.file.samp.send
     $mb.file.samp.send add command -label [msgcat::mc {Broadcast}] \
 	-command [list SAMPSendTableLoadVotable {} $varname]
     $mb.file.samp.send add separator
 
     # edit
-    menu $mb.edit
+    ThemeMenu $mb.edit
     $mb.edit add command -label [msgcat::mc {Cut}] \
-	-command "CATCut $varname" -accelerator "${ds9(ctrl)}X"
+	-command "TBLCut $varname" -accelerator "${ds9(ctrl)}X"
     $mb.edit add command -label [msgcat::mc {Copy}] \
-	-command "CATCopy $varname" -accelerator "${ds9(ctrl)}C"
+	-command "TBLCopy $varname" -accelerator "${ds9(ctrl)}C"
     $mb.edit add command -label [msgcat::mc {Paste}] \
 	-command "EntryPaste $var(top)" -accelerator "${ds9(ctrl)}V"
     $mb.edit add separator
@@ -209,7 +217,7 @@ proc CATDialog {varname format catalog title action} {
     set fw [starbase_colnum $var(symdb) fontweight]
     set fl [starbase_colnum $var(symdb) fontslant]
 
-    menu $mb.symbol
+    ThemeMenu $mb.symbol
     $mb.symbol add cascade -label [msgcat::mc {Shape}] -menu $mb.symbol.shape
     $mb.symbol add cascade -label [msgcat::mc {Color}] -menu $mb.symbol.color
     $mb.symbol add cascade -label [msgcat::mc {Width}] -menu $mb.symbol.width
@@ -218,7 +226,7 @@ proc CATDialog {varname format catalog title action} {
     $mb.symbol add command -label "[msgcat::mc {Advanced}]..." \
 	-command [list CATSymDialog $varname]
 
-    menu $mb.symbol.shape
+    ThemeMenu $mb.symbol.shape
     $mb.symbol.shape add radiobutton -label [msgcat::mc {Circle}] \
 	-variable ${flt}(1,$sn) -value circle \
 	-command [list CATGenerate $varname]
@@ -234,7 +242,7 @@ proc CATDialog {varname format catalog title action} {
     $mb.symbol.shape add cascade -label [msgcat::mc {Point}] \
 	-menu $mb.symbol.shape.point
 
-    menu $mb.symbol.shape.point
+    ThemeMenu $mb.symbol.shape.point
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable ${flt}(1,$sn) -value {circle point} \
 	-command [list CATGenerate $varname]
@@ -265,7 +273,7 @@ proc CATDialog {varname format catalog title action} {
     FontMenu $mb.symbol.font $flt 1,$fn 1,$fs 1,$fw 1,$fl \
 	[list CATGenerate $varname]
 
-    menu $mb.prefs
+    ThemeMenu $mb.prefs
     $mb.prefs add checkbutton -label [msgcat::mc {Pan To}] \
 	-variable ${varname}(panto)
     $mb.prefs add separator
@@ -317,7 +325,7 @@ proc CATDialog {varname format catalog title action} {
     CoordMenuEnable $f.coord.menu $varname system sky skyformat
 
     ttk::button $f.update -text [msgcat::mc {Update}] \
-	-command [list CATUpdate $varname]
+	-command [list TBLUpdate $varname]
 
     ttk::label $f.rtitle -text [msgcat::mc {Radius}]
     ttk::entry $f.r -textvariable ${varname}(radius) -width 14
@@ -348,7 +356,7 @@ proc CATDialog {varname format catalog title action} {
     ttk::label $f.mfilter -text [msgcat::mc {Filter}]
     ttk::entry $f.filter -textvariable ${varname}(filter) -width 50
     ttk::button $f.bfilter -text [msgcat::mc {Edit}] \
-	-command [list CATEditDialog $varname filter $var(catdb)]
+	-command [list TBLEditDialog $varname filter $var(catdb)]
 
     ttk::label $f.msort -text [msgcat::mc {Sort}]
     set var(sortmenu) [ttk::menubutton $f.sort \
@@ -411,6 +419,7 @@ proc CATDialog {varname format catalog title action} {
 		      -maxwidth 300 \
 		      -maxheight 300 \
 		      -titlerows 1 \
+		      -resizeborders col \
 		      -xscrollcommand [list $f.xscroll set]\
 		      -yscrollcommand [list $f.yscroll set]\
 		      -selecttype row \
@@ -418,9 +427,14 @@ proc CATDialog {varname format catalog title action} {
 		      -anchor w \
 		      -font [font actual TkDefaultFont] \
 		      -browsecommand [list CATSelectCmd $varname %s %S] \
-		      -fg $ds9(gui,fg) -bg $ds9(gui,bg) \
+		      -fg [ThemeTreeForeground] \
+		      -bg [ThemeTreeBackground] \
 		     ]
 
+    $var(tbl) tag configure sel \
+	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
+    $var(tbl) tag configure title -fg [ThemeForeground] -bg [ThemeBackground]
+
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] -orient vertical
     ttk::scrollbar $f.xscroll -command [list $var(tbl) xview] -orient horizontal
 
@@ -429,6 +443,8 @@ proc CATDialog {varname format catalog title action} {
     grid rowconfigure $f 0 -weight 1
     grid columnconfigure $f 0 -weight 1
 
+    TBLBindMouseWheel $varname
+
     # Status
     set f [ttk::frame $w.status]
 
@@ -440,8 +456,8 @@ proc CATDialog {varname format catalog title action} {
     # Buttons
     set f [ttk::frame $w.buttons]
 
-    ButtonButton $f.load [msgcat::mc {Load}] [list CATLoadVOTFile $varname]
-    ButtonButton $f.save [msgcat::mc {Save}] [list CATSaveVOTFile $varname]
+    ButtonButton $f.load [msgcat::mc {Open}] [list CATLoadVOTFile $varname]
+    ButtonButton $f.save [msgcat::mc {Save}] [list TBLSaveVOTFile $varname]
 
     set var(apply) [ttk::button $f.apply \
 			-text [msgcat::mc {Retrieve}] \
@@ -471,8 +487,13 @@ proc CATDialog {varname format catalog title action} {
     pack $w.cat $w.obj $w.param -side top -fill x
     pack $w.tbl -side top -fill both -expand true
 
+    bind $w <<Open>> [list CATLoadVOTFile $varname]
+    bind $w <<Save>> [list TBLSaveVOTFile $varname]
+    bind $w <<Print>> PSPrint
+    bind $w <<Close>> [list CATDestroy $varname]
+
     # needs to go after sort menu button is defined
-    CATSortMenu $varname
+    TBLSortMenu $varname
     CATColsMenu $varname
     CATColsUpdate $varname
     switch $var(format) {
@@ -480,14 +501,13 @@ proc CATDialog {varname format catalog title action} {
 	cxc -
 	ned -
 	skybot -
-	sdss -
 	simbad {
 	    $mb entryconfig [msgcat::mc {Catalog Server}] -state disabled
 	}
     }
 
     ARCoord $varname
-    CATUpdate $varname
+    TBLUpdate $varname
     CATDialogUpdate $varname
 
     ARStatus $varname {}
@@ -515,7 +535,7 @@ proc CATDialogUpdate {varname} {
     }
 
     # do we have a db?
-    if {[CATValidDB $var(tbldb)]} {
+    if {[TBLValidDB $var(tbldb)]} {
 	$var(mb).file entryconfig [msgcat::mc {Filter}] -state normal
 	$var(mb).file entryconfig [msgcat::mc {Clear}] -state normal
 	$var(mb).file entryconfig [msgcat::mc {Plot}] -state normal
@@ -585,9 +605,19 @@ proc CATAck {varname} {
 	ned {CATNEDAck $varname}
 	skybot {CATSkyBotAck $varname}
 	simbad {CATSIMBADAck $varname}
+	default {CATDefaultAck $varname}
     }
 }
 
+proc CATDefaultAck {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    set msg {No Acknowledgment available}
+    SimpleTextDialog ${varname}ack [msgcat::mc {Acknowledgment}] \
+	80 10 insert top $msg
+}
+
 proc CATApply {varname sync} {
     upvar #0 $varname var
     global $varname
@@ -615,74 +645,27 @@ proc CATApply {varname sync} {
     }
 }
 
-proc CATCopy {varname} {
+proc CATServer {varname} {
     upvar #0 $varname var
     global $varname
 
-    set w [focus -displayof $var(top)]
-    if {$w == $var(tbl)} {
-	CATCopyTable $varname
-    } else {
-	EntryCopy $var(top)
+    global debug
+    if {$debug(tcl,cat)} {
+	puts stderr "CATServer $varname"
     }
-}
 
-proc CATCut {varname} {
-    upvar #0 $varname var
-    global $varname
+    if {($var(x) != {}) && ($var(y) != {}) && ($var(radius) != {})} {
+	ARStatus $varname [msgcat::mc {Contacting Server}]
 
-    set w [focus -displayof $var(top)]
-    if {$w == $var(tbl)} {
-	CATCopyTable $varname
-    } else {
-	EntryCut $var(top)
-    }
-}
-
-proc CATCopyTable {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    set w [focus -displayof $var(top)]
-
-    set sel [$var(tbl) curselection]
-    set data {}
-    set row [lindex [split [lindex $sel 0] ,] 0]
-    foreach ss $sel {
-	set rr [lindex [split $ss ,] 0]
-	if {$rr != $row} {
-	    append data "\n"
-	    set row $rr
-	} else {
-	    if {$data != {}} {
-		append data "\t"
-	    }
+	switch $var(format) {
+	    cds {CATCDS $varname}
+	    cxc {CATCXC $varname}
+	    ned {CATNED $varname}
+	    skybot {CATSkyBot $varname}
+	    simbad {CATSIMBAD $varname}
 	}
-	append data "[$var(tbl) get $ss]"
-    }
-    append data "\n"
-    clipboard clear -displayof $w
-    clipboard append -displayof $w $data
-}
-
-proc CATCrosshair {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    if {[info commands $var(frame)] == {}} {
-	return
-    }
-
-    if {![$var(frame) has fits]} {
-	return
-    }
-
-    if {[$var(frame) has wcs celestial $var(system)]} {
-	set coord [$var(frame) get crosshair \
-		       $var(system) $var(sky) $var(skyformat)]
-	set var(x) [lindex $coord 0]
-	set var(y) [lindex $coord 1]
-	set var(name) {}
+    } else {
+	eval [list $var(proc,error) $varname [msgcat::mc {Please specify radius and either name or (ra,dec)}]]
     }
 }
 
@@ -704,7 +687,7 @@ proc CATDestroy {varname} {
     # stop timer if needed
     if {$var(blink)} {
 	set var(blink) 0
-	after cancel [list CATSelectTimer $varname]
+	after cancel [list TBLSelectTimer $varname catalog]
     }
 
     # frame may have been deleted
@@ -794,77 +777,16 @@ proc CATGetHeader {varname} {
     set t $var(tbldb)
     upvar #0 $t T
 
-    if {[CATValidDB $var(tbldb)]} {
-	set hdr {}
-
-	# header
-	set nl [expr $T(HLines)-2]
-	for {set ll 1} {$ll <= $nl} {incr ll} {
-	    append hdr "$T(H_$ll)\n"
-	}
-	append hdr "\n"
-
-	# dump cols stats
-	set nc $T(Ncols)
-	for {set cc 1} {$cc <= $nc} {incr cc} {
-	    append hdr "# name=[lindex $T(Header) [expr $cc-1]] "
-	    if {[info exists ${t}(DataType)]} {
-		append hdr "datatype=[lindex $T(DataType) [expr $cc-1]] "
-	    }
-
-	    if {[info exists ${t}(Id)]} {
-		if {[lindex $T(Id) [expr $cc-1]] != {}} {
-		    append hdr "id=[lindex $T(Id) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(ArraySize)]} {
-		if {[lindex $T(ArraySize) [expr $cc-1]] != {}} {
-		    append hdr "arraysize=[lindex $T(ArraySize) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Width)]} {
-		if {[lindex $T(Width) [expr $cc-1]] != {}} {
-		    append hdr "width=[lindex $T(Width) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Precision)]} {
-		if {[lindex $T(Precision) [expr $cc-1]] != {}} {
-		    append hdr "precision=[lindex $T(Precision) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Unit)]} {
-		if {[lindex $T(Unit) [expr $cc-1]] != {}} {
-		    append hdr "unit=[lindex $T(Unit) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Ref)]} {
-		if {[lindex $T(Ref) [expr $cc-1]] != {}} {
-		    append hdr "ref=[lindex $T(Ref) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Ucd)]} {
-		if {[lindex $T(Ucd) [expr $cc-1]] != {}} {
-		    append hdr "ucd=[lindex $T(Ucd) [expr $cc-1]] "
-		}
-	    }
-
-	    if {[info exists ${t}(Description)]} {
-		if {[lindex $T(Description) [expr $cc-1]] != {}} {
-		    append hdr "[lindex $T(Description) [expr $cc-1]] "
-		}
-	    }
-	    append hdr "\n"
-	}
-
-	return $hdr
+    if {![TBLValidDB $var(tbldb)]} {
+	return {}
     }
-    return {}
+
+    set hdr {}
+    set nl [expr $T(HLines)-2]
+    for {set ll 1} {$ll <= $nl} {incr ll} {
+	append hdr "$T(H_$ll)\n"
+    }
+    return $hdr
 }
 
 proc CATHeader {varname} {
@@ -896,108 +818,11 @@ proc CATPageSetup {varname} {
     upvar #0 $varname var
     global $varname
 
-    global ds9
-    switch $ds9(wm) {
-	x11 -
-	aqua {}
-	win32 {win32 pm pagesetup}
-    }
-}
-
-proc CATPrint {varname} {
-    upvar #0 $varname var
-    global $varname
-    global $var(tbldb)
-
     global ds9
     switch $ds9(wm) {
 	x11 -
 	aqua -
-	win32 {CATPSPrint $varname}
-    }	
-}
-
-proc CATPSPrint {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    if {[PRPrintDialog]} { 
-	if {[catch {CATPostScript $varname} printError]} {
-	    Error "[msgcat::mc {An error has occurred while printing}] $printError"
-	}
-    }
-}
-
-proc CATPostScript {varname} {
-    upvar #0 $varname var
-    global $varname
-    global $var(tbldb)
-
-    global ps
-
-    if {$ps(dest) == "file"} {
-	set ch [open "| cat > $ps(filename,txt)" w]
-    } else {
-	set ch [open "| $ps(cmd)" w]
-    }
-
-    starbase_writefp $var(tbldb) $ch
-    close $ch
-}
-
-proc CATServer {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATServer $varname"
-    }
-
-    if {($var(x) != {}) && ($var(y) != {}) && ($var(radius) != {})} {
-	ARStatus $varname "Searching [string range $var(title) 0 50]"
-
-	switch $var(format) {
-	    cds {CATCDS $varname}
-	    cxc {CATCXC $varname}
-	    ned {CATNED $varname}
-	    skybot {CATSkyBot $varname}
-	    simbad {CATSIMBAD $varname}
-	}
-    } else {
-	ARError $varname [msgcat::mc {Please specify radius and either name or (ra,dec)}]
-    }
-}
-
-proc CATUpdate {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,cat)} {
-	puts stderr "CATUpdate $varname"
-    }
-
-    if {[info commands $var(frame)] == {}} {
-	return
-    }
-
-    if {![$var(frame) has fits]} {
-	return
-    }
-
-    if {[$var(frame) has wcs celestial $var(system)]} {
-	set coord [$var(frame) get fits center \
-		       $var(system) $var(sky) $var(skyformat)]
-	set var(x) [lindex $coord 0]
-	set var(y) [lindex $coord 1]
-
-	set size [$var(frame) get fits size \
-		      $var(system) $var(sky) $var(rformat)]
-	set ww [lindex $size 0]
-	set hh [lindex $size 1]
-	set var(radius) [expr ($ww+$hh)/4]
-	set var(name) {}
+	win32 {}
     }
 }
 
@@ -1025,10 +850,8 @@ proc CATColsUpdate {varname} {
 	physical -
 	detector -
 	amplifier {
-	    $var(raname) configure -text {X} \
-		-font [font actual TkDefaultFont]
-	    $var(decname) configure -text {Y} \
-		-font [font actual TkDefaultFont]
+	    $var(raname) configure -text {X} -font [font actual TkDefaultFont]
+	    $var(decname) configure -text {Y} -font [font actual TkDefaultFont]
 	}
 	default {
 	    if {[$var(frame) has wcs celestial $var(psystem)]} {
@@ -1064,262 +887,6 @@ proc CATColsUpdate {varname} {
     }
 }
 
-# Edit Dialog
-
-proc CATEditDialog {varname which db} {
-    upvar #0 $varname var
-    global $varname
-    global ds9
-    global ed
-
-    set w ".${varname}edit"
-    set mb ".${varname}editmb"
-
-    set ed(ok) 0
-    set ed(text) $w.param.txt
-
-    DialogCreate $w [msgcat::mc {Edit}] ed(ok)
-
-    $w configure -menu $mb
-    menu $mb
-
-    # file
-    $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
-    menu $mb.file
-    $mb.file add command -label [msgcat::mc {Apply}] \
-	-command {set ed(ok) 1}
-    $mb.file add command -label [msgcat::mc {Clear}] \
-	-command CATEditClear
-    $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load}]..." \
-	-command CATEditLoad
-    $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command CATEditSave
-    $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Cancel}] \
-	-command {set ed(ok) 0}
-
-    # edit
-    $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
-    menu $mb.edit
-    $mb.edit add command -label [msgcat::mc {Undo}] \
-	-command "$ed(text) edit undo" -accelerator "${ds9(ctrl)}Z"
-    $mb.edit add command -label [msgcat::mc {Redo}] \
-	-command "$ed(text) edit redo" -accelerator "${ds9(shiftctrl)}Z"
-    $mb.edit add separator
-    $mb.edit add command -label [msgcat::mc {Cut}] \
-	-command "tk_textCut $ed(text)" -accelerator "${ds9(ctrl)}X"
-    $mb.edit add command -label [msgcat::mc {Copy}] \
-	-command "tk_textCopy $ed(text)" -accelerator "${ds9(ctrl)}C"
-    $mb.edit add command -label [msgcat::mc {Paste}] \
-	-command "tk_textPaste $ed(text)" -accelerator "${ds9(ctrl)}V"
-
-    global $db
-    # column
-    $mb add cascade -label [msgcat::mc {Column}] -menu $mb.col
-    if {[info exists $mb.col]} {
-	destroy $mb.col
-    }
-    menu $mb.col
-    if {[CATValidDB $db]} {
-	set cnt -1
-	foreach col [starbase_columns $db] {
-	    $mb.col add command -label "$col" \
-		-command "$ed(text) insert insert \{\$$col\}"
-
-	    # wrap if needed
-	    incr cnt
-	    if {$cnt>=$ds9(menu,size,wrap)} {
-		set cnt 0
-		$mb.col entryconfig $col -columnbreak 1
-	    }
-	}
-    }
-
-    # operator
-    $mb add cascade -label [msgcat::mc {Operator}] -menu $mb.op
-    menu $mb.op
-    $mb.op add command -label {-} \
-	-command "$ed(text) insert insert {-}"
-    $mb.op add command -label {!} \
-	-command "$ed(text) insert insert {!}"
-    $mb.op add command -label {(} \
-				   -command "$ed(text) insert insert {(}"
-	$mb.op add command -label {)} \
-	-command "$ed(text) insert insert {)}"
-    $mb.op add separator
-    $mb.op add command -label {*} \
-	-command "$ed(text) insert insert {*}"
-    $mb.op add command -label {/} \
-	-command "$ed(text) insert insert {/}"
-    $mb.op add command -label {%} \
-	-command "$ed(text) insert insert {%}"
-    $mb.op add command -label {+} \
-	-command "$ed(text) insert insert {+}"
-    $mb.op add command -label {-} \
-	-command "$ed(text) insert insert {-}"
-    $mb.op add separator
-    $mb.op add command -label {<} \
-	-command "$ed(text) insert insert {<}"
-    $mb.op add command -label {>} \
-	-command "$ed(text) insert insert {>}"
-    $mb.op add command -label {<=} \
-	-command "$ed(text) insert insert {<=}"
-    $mb.op add command -label {>=} \
-	-command "$ed(text) insert insert {>=}"
-    $mb.op add command -label {==} \
-	-command "$ed(text) insert insert {==}"
-    $mb.op add command -label {!=} \
-	-command "$ed(text) insert insert {!=}"
-    $mb.op add separator
-    $mb.op add command -label {&&} \
-	-command "$ed(text) insert insert {&&}"
-    $mb.op add command -label {||} \
-	-command "$ed(text) insert insert {||}"
-
-    # operator
-    $mb add cascade -label [msgcat::mc {Math Function}] -menu $mb.math
-    menu $mb.math
-    $mb.math add command -label {acos} \
-	-command "$ed(text) insert insert {acos()}"
-    $mb.math add command -label {asin} \
-	-command "$ed(text) insert insert {asin()}"
-    $mb.math add command -label {atan} \
-	-command "$ed(text) insert insert {atan()}"
-    $mb.math add command -label {atan2} \
-	-command "$ed(text) insert insert {atan2(,)}"
-    $mb.math add command -label {ceil} \
-	-command "$ed(text) insert insert {ceil()}"
-    $mb.math add command -label {cos} \
-	-command "$ed(text) insert insert {cos()}"
-    $mb.math add command -label {cosh} \
-	-command "$ed(text) insert insert {cosh()}"
-    $mb.math add command -label {exp} \
-	-command "$ed(text) insert insert {exp()}"
-    $mb.math add command -label {floor} \
-	-command "$ed(text) insert insert {floor()}"
-    $mb.math add command -label {fmod} \
-	-command "$ed(text) insert insert {fmod(,)}"
-    $mb.math add command -label {hypot} \
-	-command "$ed(text) insert insert {hypot(,)}"
-    $mb.math add command -label {log} \
-	-command "$ed(text) insert insert {log()}"
-    $mb.math add command -label {log10} \
-	-command "$ed(text) insert insert {log10()}"
-    $mb.math add command -label {pow} \
-        -command "$ed(text) insert insert {pow(,)}"
-    $mb.math add command -label {sin} \
-	-command "$ed(text) insert insert {sin()}"
-    $mb.math add command -label {sinh} \
-	-command "$ed(text) insert insert {sinh()}"
-    $mb.math add command -label {sqrt} \
-	-command "$ed(text) insert insert {sqrt()}"
-    $mb.math add command -label {tan} \
-	-command "$ed(text) insert insert {tan()}"
-    $mb.math add command -label {tanh} \
-	-command "$ed(text) insert insert {tanh()}"
-    $mb.math add command -label {abs} \
-	-command "$ed(text) insert insert {abs()}"
-    $mb.math add command -label {double} \
-	-command "$ed(text) insert insert {double()}"
-    $mb.math add command -label {int} \
-	-command "$ed(text) insert insert {int()}"
-    $mb.math add command -label {round} \
-	-command "$ed(text) insert insert {round()}"
-
-    # Text  
-    set f [ttk::frame $w.param]
-
-    text $f.txt \
-	-height 10 \
-	-width 60 \
-	-yscrollcommand "$f.yscroll set" \
-	-xscrollcommand "$f.xscroll set" \
-	-undo true \
-	-wrap none 
-    ttk::scrollbar $f.yscroll -command [list $ed(text) yview] \
-	-orient vertical
-    ttk::scrollbar $f.xscroll -command [list $ed(text) xview] \
-	-orient horizontal
-
-    grid $ed(text) $f.yscroll -sticky news
-    grid $f.xscroll -stick news
-    grid rowconfigure $f 0 -weight 1
-    grid columnconfigure $f 0 -weight 1
-
-    # Buttons
-    set f [ttk::frame $w.buttons]
-    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
-        -default active 
-    ttk::button $f.clear -text [msgcat::mc {Clear}] -command CATEditClear
-    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
-    pack $f.ok $f.clear $f.cancel -side left -expand true -padx 2 -pady 4
-
-    bind $w <Return> {set ed(ok) 1}
-
-    # Fini
-    ttk::separator $w.sep -orient horizontal
-    pack $w.param -side top -fill both -expand true
-    pack $w.buttons $w.sep -side bottom -fill x
-
-    $ed(text) insert end $var($which)
-    $ed(text) see end
-
-    DialogCenter $w
-    DialogWait $w ed(ok) $w.buttons.ok
-
-    if {$ed(ok)} {
-	set flt [$ed(text) get 1.0 end]
-	catch {regsub {\n} $flt " " flt}
-	set var($which) [string trim $flt]
-    }
-
-    DialogDismiss $w
-    destroy $mb
-
-    set rr $ed(ok)
-    unset ed
-    return $rr
-}
-
-proc CATEditClear {} {
-    global ed
-
-    $ed(text) delete 1.0 end
-}
-
-proc CATEditSave {} {
-    global ed
-
-    set fn [SaveFileDialog catfltfbox]
-    if {$fn != {}} {
-	if {[catch {open $fn w} fp]} {
-	    Error "[msgcat::mc {Unable to open file}] $fn: $fp"
-	    return
-	}
-	set flt [$ed(text) get 1.0 end]
-	catch {regsub {\n} $flt " " flt}
-	puts $fp [string trim $flt]
-	catch {close $fp}
-    }
-}
-
-proc CATEditLoad {} {
-    global ed
-
-    set fn [OpenFileDialog catfltfbox]
-    if {$fn != {}} {
-	if {[catch {open $fn r} fp]} {
-	    Error "[msgcat::mc {Unable to open file}] $fn: $fp"
-	    return
-	}
-	$ed(text) delete 1.0 end
-	$ed(text) insert end [read -nonewline $fp]
-	$ed(text) see end
-	catch {close $fp}
-    }
-}
-
 proc UpdateCATDialog {} {
     global icat
 
