@@ -14,9 +14,6 @@ proc CATNED {varname} {
 	puts stderr "CATNED $varname"
     }
 
-    # parser
-    set var(proc,parser) VOTParse
-
     # query
     switch $var(skyformat) {
 	degrees {
@@ -89,11 +86,10 @@ proc CATNED {varname} {
     }
 
     # url
-    set var(query) {}
     set query [http::formatQuery search_type "Near Position Search" RA $xx DEC $yy SR $rr of $out in_csys $sky in_equinox $eq out_csys $psky out_equinox $peq]
-    set var(url) "http://ned.ipac.caltech.edu/cgi-bin/nph-objsearch?$query"
+    set url "http://ned.ipac.caltech.edu/cgi-bin/nph-objsearch"
 
-    CATLoad $varname
+    CATLoad $varname "$url?$query" {}
 }
 
 proc CATNEDAck {varname} {
