@@ -9,7 +9,7 @@ proc CATPlot {varname} {
     global $varname
 
     # do we have a db?
-    if {![CATValidDB $var(tbldb)]} {
+    if {![TBLValidDB $var(tbldb)]} {
 	return
     }
 
@@ -109,7 +109,7 @@ proc CATPlotGenerate {varname} {
     $yedata set $ye
 
     if {![PlotPing $vvarname]} {
-	PlotDialog $vvarname $var(title)
+	PlotDialog $vvarname $var(title) true
 	PlotAddGraph $vvarname scatter
 
 	set vvar(mode) pointer
@@ -154,11 +154,11 @@ proc CATPlotDialog {varname} {
     DialogCreate $w [msgcat::mc {Plot}] ed2(ok)
 
     $w configure -menu $mb
-    menu $mb
+    ThemeMenu $mb
 
     # file
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] -command {set ed2(ok) 1}
     $mb.file add command -label [msgcat::mc {Cancel}] -command {set ed2(ok) 0}
 
@@ -175,10 +175,10 @@ proc CATPlotDialog {varname} {
     ttk::label $f.tx -text {X}
     ttk::entry $f.x -textvariable ed2(x) -width 21
     ttk::button $f.bx -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog ed2 x $var(catdb)"
+	-command "TBLEditDialog ed2 x $var(catdb)"
     ttk::entry $f.xerr -textvariable ed2(xerr) -width 21
     ttk::button $f.bxerr -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog ed2 xerr $var(catdb)"
+	-command "TBLEditDialog ed2 xerr $var(catdb)"
     ttk::menubutton $f.mx -text {Cols} -menu $f.mx.menu
     ttk::menubutton $f.mxerr -text {Cols} -menu $f.mxerr.menu
 
@@ -188,10 +188,10 @@ proc CATPlotDialog {varname} {
     ttk::label $f.ty -text {Y}
     ttk::entry $f.y -textvariable ed2(y) -width 21
     ttk::button $f.by -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog ed2 y $var(catdb)"
+	-command "TBLEditDialog ed2 y $var(catdb)"
     ttk::entry $f.yerr -textvariable ed2(yerr) -width 21
     ttk::button $f.byerr -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog ed2 yerr $var(catdb)"
+	-command "TBLEditDialog ed2 yerr $var(catdb)"
     ttk::menubutton $f.my -text {Cols} -menu $f.my.menu
     ttk::menubutton $f.myerr -text {Cols} -menu $f.myerr.menu
 
@@ -218,8 +218,9 @@ proc CATPlotDialog {varname} {
     pack $w.param -side top -fill both -expand true
     pack $w.buttons $w.sep -side bottom -fill x
 
-    DialogCenter $w
     DialogWait $w ed2(ok) $w.buttons.ok
+    destroy $w
+    destroy $mb
 
     if {$ed2(ok)} {
 	set var(plot,x) $ed2(x)
@@ -228,9 +229,6 @@ proc CATPlotDialog {varname} {
 	set var(plot,yerr) $ed2(yerr)
     }
 
-    DialogDismiss $w
-    destroy $mb
-
     set rr $ed2(ok)
     unset ed2
     return $rr
@@ -245,8 +243,9 @@ proc CATPlotDialogColsMenu {varname f ww} {
 
     set m $f.menu
 
-    menu $m -tearoff 0
-    if {[CATValidDB $var(catdb)]} {
+    ThemeMenu $m
+    $m configure -tearoff 0
+    if {[TBLValidDB $var(catdb)]} {
 	set cnt -1
 	foreach col [starbase_columns $var(catdb)] {
 	    $m add command -label $col -command "set ed2($ww) \\$$col"
