@@ -25,8 +25,6 @@ proc CATSkyBotVOT {varname} {
 	puts stderr "CATSkyBotVOT $varname"
     }
 
-    set var(proc,parser) VOTParse
-    
     # coord (degrees)
     switch $var(skyformat) {
 	degrees {
@@ -75,7 +73,7 @@ proc CATSkyBotVOT {varname} {
 	set epoch [string trim [$current(frame) get fits header keyword DATE]]
     }
     if {$epoch == {}} {
-	ARError $varname [msgcat::mc {Unable to determine date of observation}]
+	eval [list $var(proc,error) $varname [msgcat::mc {Unable to determine date of observation}]]
 	return
     }
 
@@ -132,9 +130,9 @@ proc CATSkyBotVOT {varname} {
     }
 
     # query
-    set var(query) [http::formatQuery EPOCH $epoch RA $xx DEC $yy SR $rr VERB $type -mime votable -loc $var(loc) -filter 0 -objFilter $var(asteroids)$var(planets)$var(comets)]
-    set var(url) "http://vo.imcce.fr/webservices/skybot/skybotconesearch_query.php"
-    CATLoad $varname
+    set query [http::formatQuery EPOCH $epoch RA $xx DEC $yy SR $rr VERB $type -mime votable -loc $var(loc) -filter 0 -objFilter $var(asteroids)$var(planets)$var(comets)]
+    set url "http://vo.imcce.fr/webservices/skybot/skybotconesearch_query.php"
+    CATLoad $varname $url $query
 }
 
 proc CATSkyBotAck {varname} {
