@@ -80,38 +80,32 @@ proc CATSymDialog {parent} {
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
 
     # menu
-    menu $mb.file
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command "CATSymLoad $varname" -accelerator "${ds9(ctrl)}O"
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command "CATSymSave $varname" -accelerator "${ds9(ctrl)}S"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Apply}] \
 	-command "CATSymApply $varname"
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command "CATSymSave $varname"
-    $mb.file add command -label "[msgcat::mc {Load}]..." \
-	-command "CATSymLoad $varname"
-    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Add}] \
 	-command "CATSymAdd $varname"
     $mb.file add command -label [msgcat::mc {Delete}] \
 	-command "CATSymRemove $varname"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command "CATSymDestroy $varname"
-
-    menu $mb.edit
-    $mb.edit add command -label [msgcat::mc {Cut}] \
-	-command "EntryCut $var(top)" -accelerator "${ds9(ctrl)}X"
-    $mb.edit add command -label [msgcat::mc {Copy}] \
-	-command "EntryCopy $var(top)" -accelerator "${ds9(ctrl)}C"
-    $mb.edit add command -label [msgcat::mc {Paste}] \
-	-command "EntryPaste $var(top)" -accelerator "${ds9(ctrl)}V"
+	-command "CATSymDestroy $varname" -accelerator "${ds9(ctrl)}W"
 
+    EditMenu $mb $varname
+    
     # Param
     set f [ttk::frame $w.param]
 
     ttk::label $f.tcondition -text [msgcat::mc {If}] 
     ttk::entry $f.condition -textvariable ${varname}(condition) -width 40
     ttk::button $f.bcondition -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname condition $pvar(catdb)"
+	-command "TBLEditDialog $varname condition $pvar(catdb)"
     ttk::label $f.tthen -text [msgcat::mc {Then}] 
     ttk::label $f.tshape -text [msgcat::mc {Shape}] 
     ttk::menubutton $f.shape -textvariable ${varname}(shape) -menu $f.shape.menu
@@ -124,25 +118,40 @@ proc CATSymDialog {parent} {
     ttk::label $f.ttext -text [msgcat::mc {Text}] 
     ttk::entry $f.text -textvariable ${varname}(text) -width 40
     ttk::button $f.btext -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname text  $pvar(catdb)"
+	-command "TBLEditDialog $varname text  $pvar(catdb)"
     ttk::label $f.tsize -text [msgcat::mc {Size/Radius}] 
     ttk::entry $f.size -textvariable ${varname}(size) -width 40
     ttk::button $f.bsize -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname size $pvar(catdb)"
+	-command "TBLEditDialog $varname size $pvar(catdb)"
     ttk::label $f.tsize2 -text "[msgcat::mc {Size/Radius}] 2" 
     ttk::entry $f.size2 -textvariable ${varname}(size2) -width 40
     ttk::button $f.bsize2 -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname size2 $pvar(catdb)"
+	-command "TBLEditDialog $varname size2 $pvar(catdb)"
     ttk::label $f.tunits -text [msgcat::mc {Units}] 
-    tk_optionMenu $f.units ${varname}(units) \
-	image physical degrees arcmin arcsec
+
+    set m $f.units
+    set mm $m.menu
+    ttk::menubutton $m -textvariable ${varname}(units) -menu $mm
+    ThemeMenu $mm
+    $mm add radiobutton -label [msgcat::mc {Image}] \
+	-variable ${varname}(units) -value image
+    $mm add radiobutton -label [msgcat::mc {Physical}] \
+	-variable ${varname}(units) -value physical
+    $mm add separator
+    $mm add radiobutton -label [msgcat::mc {Degrees}] \
+	-variable ${varname}(units) -value degrees
+    $mm add radiobutton -label [msgcat::mc {ArcMin}] \
+	-variable ${varname}(units) -value arcmin
+    $mm add radiobutton -label [msgcat::mc {ArcSec}] \
+	    -variable ${varname}(units) -value arcsec
+
     $f.units.menu configure
     ttk::label $f.tangle -text [msgcat::mc {Angle}] 
     ttk::entry $f.angle -textvariable ${varname}(angle) -width 40
     ttk::button $f.bangle -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname angle $pvar(catdb)"
+	-command "TBLEditDialog $varname angle $pvar(catdb)"
 
-    menu $f.shape.menu
+    ThemeMenu $f.shape.menu
     $f.shape.menu add radiobutton  -label [msgcat::mc {Circle}] \
 	-variable ${varname}(shape) -value {circle}
     $f.shape.menu add radiobutton  -label [msgcat::mc {Ellipse}] \
@@ -156,7 +165,7 @@ proc CATSymDialog {parent} {
     $f.shape.menu add cascade -label [msgcat::mc {Point}] \
 	-menu $f.shape.menu.point
 
-    menu $f.shape.menu.point
+    ThemeMenu $f.shape.menu.point
     $f.shape.menu.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable ${varname}(shape) -value {circle point}
     $f.shape.menu.point add radiobutton -label [msgcat::mc {Box}] \
@@ -200,15 +209,22 @@ proc CATSymDialog {parent} {
 		      -maxwidth 550 \
 		      -maxheight 300 \
 		      -titlerows 1 \
+		      -resizeborders col \
 		      -xscrollcommand [list $f.xscroll set]\
 		      -yscrollcommand [list $f.yscroll set]\
 		      -selecttype row \
 		      -selectmode single \
 		      -anchor w \
 		      -font [font actual TkDefaultFont] \
-		      -browsecommand [list CATSymSelectCB $varname]
+		      -browsecommand [list CATSymSelectCB $varname] \
+		      -fg [ThemeTreeForeground] \
+		      -bg [ThemeTreeBackground] \
 		 ]
 
+    $var(tbl) tag configure sel \
+	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
+    $var(tbl) tag configure title -fg [ThemeForeground] -bg [ThemeBackground]
+
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] -orient vertical
     ttk::scrollbar $f.xscroll -command [list $var(tbl) xview] -orient horizontal
 
@@ -240,6 +256,10 @@ proc CATSymDialog {parent} {
     CATSymTable $varname
 
     $var(tbl) selection set $var(row),1
+
+    bind $w <<Open>> [list CATSymLoad $varname]
+    bind $w <<Save>> [list CATSymSave $varname]
+    bind $w <<Close>> [list CATSymDestroy $varname]
 }
 
 proc CATSymDestroy {varname} {
@@ -352,7 +372,7 @@ proc CATSymSave {varname} {
     global $varname
     global $var(symdb)
 
-    set fn [SaveFileDialog catsymfbox]
+    set fn [SaveFileDialog catsymfbox $var(top)]
     if {$fn != {}} {
 	starbase_write $var(symdb) $fn
     }
@@ -363,7 +383,7 @@ proc CATSymLoad {varname} {
     global $varname
     global $var(symdb)
 
-    set fn [OpenFileDialog catsymfbox]
+    set fn [OpenFileDialog catsymfbox $var(top)]
     if {$fn != {}} {
 	if {[file exists $fn]} {
 	    if {[info exists $var(symdb)]} {
