@@ -53,19 +53,14 @@ proc CATVOTHTTP {url catalog title} {
     upvar #0 $varname var
     global $varname
 
-    set ${varname}(query) {}
-    set ${varname}(url) $url
-    set ${varname}(proc,parser) VOTParse
-
-    CATLoad $varname
+    CATLoad $varname $url {}
 }
 
 proc CATVOTFile {fn} {
     global icat
 
-    CATDialog catvot {} {} {} none
+    CATDialog catvot {} {} [msgcat::mc {Catalog Tool}] none
     if {$fn != {}} {
  	CATLoadFn [lindex $icat(cats) end] $fn VOTRead
     }
 }
-
