@@ -71,7 +71,8 @@ proc CreateColorbar {} {
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
 	-times $ds9(times) \
-	-fg $ds9(foreground) -bg $ds9(background)
+	-fg [ThemeTreeForeground] \
+	-bg [ThemeTreeBackground]
 
     $ds9(canvas) bind colorbar <Motion> [list ColorbarMotion %x %y]
     $ds9(canvas) bind colorbar <Enter> [list ColorbarEnter %x %y]
@@ -95,7 +96,8 @@ proc CreateColorbar {} {
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
 	-times $ds9(times) \
-	-fg $ds9(foreground) -bg $ds9(background)
+	-fg [ThemeTreeForeground] \
+	-bg [ThemeTreeBackground]
 
     $ds9(canvas) bind colorbarrgb <Motion> [list ColorbarMotion %x %y]
     $ds9(canvas) bind colorbarrgb <Enter> [list ColorbarEnter %x %y]
@@ -131,7 +133,9 @@ proc ResetColormap {} {
 }
 
 proc LoadColormap {} {
-    LoadColormapFile [OpenFileDialog colorbarfbox]
+    global icolorbar
+    
+    LoadColormapFile [OpenFileDialog colorbarfbox $icolorbar(top)]
 }
 
 # used by backup
@@ -171,8 +175,10 @@ proc LoadColormapFile {fn} {
 }
 
 proc SaveColormap {} {
+    global icolorbar
+
     FileLast colorbarfbox [colorbar get file name]
-    SaveColormapFile [SaveFileDialog colorbarfbox]
+    SaveColormapFile [SaveFileDialog colorbarfbox $icolorbar(top)]
 }
 
 proc SaveColormapFile {fn} {
@@ -187,9 +193,10 @@ proc SaveColormapFile {fn} {
 }
 
 proc LoadContrastBias {} {
+    global icolorbar
     global dcolorbar
 
-    set fn [OpenFileDialog contrastbiasfbox]
+    set fn [OpenFileDialog contrastbiasfbox $icolorbar(top)]
     if {$fn == {}} {
 	return
     }
@@ -204,9 +211,10 @@ proc LoadContrastBias {} {
 }
 
 proc SaveContrastBias {} {
+    global icolorbar
     global dcolorbar
 
-    set fn [SaveFileDialog contrastbiasfbox]
+    set fn [SaveFileDialog contrastbiasfbox $icolorbar(top)]
     if {$fn == {}} {
 	return
     }
@@ -684,7 +692,9 @@ proc TicksDialog {} {
 }
 
 proc OpenColorTag {} {
-    LoadColorTag [OpenFileDialog colortagfbox]
+    global icolorbar
+    
+    LoadColorTag [OpenFileDialog colortagfbox $icolorbar(top)]
 }
 
 proc LoadColorTag {fn} {
@@ -705,9 +715,10 @@ proc LoadColorTag {fn} {
 }
 
 proc SaveColorTag {} {
+    global icolorbar
     global current
 
-    set fn [SaveFileDialog colortagfbox]
+    set fn [SaveFileDialog colortagfbox $icolorbar(top)]
     if {$fn == {}} {
 	return
     }
@@ -774,9 +785,8 @@ proc ColorTagDialog {x y} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed2(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed2(ok)} {
 	$current(colorbar) tag $ed2(id) $ed2(start) $ed2(stop) $ed2(color)
@@ -816,15 +826,15 @@ proc ColormapDialog {} {
     $mb add cascade -label [msgcat::mc {Colormap}] -menu $mb.colormap
     $mb add cascade -label [msgcat::mc {Color}] -menu $mb.color
 
-    menu $mb.file
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command LoadColormap -accelerator "${ds9(ctrl)}O"
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command SaveColormap -accelerator "${ds9(ctrl)}S"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Apply}] \
 	-command ApplyColormap
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load Colormap}]..." \
-	-command LoadColormap
-    $mb.file add command -label "[msgcat::mc {Save Colormap}]..." \
-	-command SaveColormap
-    $mb.file add separator
     $mb.file add command -label "[msgcat::mc {Download Colormap}]..." \
 	-command {HV cpt CPT-CITY http://soliton.vm.bytemark.co.uk/pub/cpt-city}
     $mb.file add separator
@@ -841,19 +851,19 @@ proc ColormapDialog {} {
 	-command DeleteColorTag
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command ColormapDestroyDialog
+	-command ColormapDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb icolorbar
 
     ColorMenu $mb.color colorbar tag {}
 
-    menu $mb.colormap
-    menu $mb.colormap.h5
-    menu $mb.colormap.matplotlib
-    menu $mb.colormap.cubehelix
-    menu $mb.colormap.gist
-    menu $mb.colormap.topo
-    menu $mb.colormap.user
+    ThemeMenu $mb.colormap
+    ThemeMenu $mb.colormap.h5
+    ThemeMenu $mb.colormap.matplotlib
+    ThemeMenu $mb.colormap.cubehelix
+    ThemeMenu $mb.colormap.gist
+    ThemeMenu $mb.colormap.topo
+    ThemeMenu $mb.colormap.user
 
     set id [colorbar list id]
 
@@ -923,6 +933,10 @@ proc ColormapDialog {} {
     ttk::separator $w.sep -orient horizontal
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
+
+    bind $w <<Open>> LoadColormap
+    bind $w <<Save>> SaveColormap
+    bind $w <<Close>> ColormapDestroyDialog
 }
 
 proc ColormapCreateMenu {varname which start stop} {
@@ -1025,9 +1039,9 @@ proc UpdateColorDialog {} {
 		base -
 		3d {
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Load Colormap}]..." -state normal
+			"[msgcat::mc {Open}]..." -state normal
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Save Colormap}]..." -state normal
+			"[msgcat::mc {Save}]..." -state normal
 		    for {set ii $icolorbar(start)} {$ii<$end} {incr ii} {
 			$icolorbar(mb).colormap entryconfig $ii -state normal
 		    }
@@ -1046,9 +1060,9 @@ proc UpdateColorDialog {} {
 		}
 		rgb {
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Load Colormap}]..." -state disabled
+			"[msgcat::mc {Open}]..." -state disabled
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Save Colormap}]..." -state disabled
+			"[msgcat::mc {Save}]..." -state disabled
 		    for {set ii $icolorbar(start)} {$ii<$end} {incr ii} {
 			$icolorbar(mb).colormap entryconfig $ii -state disabled
 		    }
@@ -1068,9 +1082,9 @@ proc UpdateColorDialog {} {
 	    }
 	} else {
 	    $icolorbar(mb).file entryconfig \
-		"[msgcat::mc {Load Colormap}]..." -state normal
+		"[msgcat::mc {Open}]..." -state normal
 	    $icolorbar(mb).file entryconfig \
-		"[msgcat::mc {Save Colormap}]..." -state normal
+		"[msgcat::mc {Save}]..." -state normal
 	    for {set ii $icolorbar(start)} {$ii<$end} {incr ii} {
 		$icolorbar(mb).colormap entryconfig $ii -state normal
 	    }
