@@ -65,6 +65,10 @@ proc ProcessCommandLineSecond {} {
 		incr i
 		set pds9(language,dir) [lindex $argv $i]
 	    }
+	    -samp {
+		incr i
+		ProcessSAMPFirstCmd argv i
+	    }
 	    -xpa {
 		incr i
 		ProcessXPAFirstCmd argv i
@@ -136,7 +140,11 @@ proc ProcessCommand {argv argc} {
 	    -array {set file(type) array}
 	    -asinh {set scale(type) asinh; ChangeScale}
 	    -bg -
-	    -background {incr i; ProcessBgCmd argv i}
+	    -background {
+		# backward compatibility prefs
+		incr i
+		ProcessBgCmd argv i
+	    }
 	    -backup {incr i; ProcessBackupCmd argv i}
 	    -bin {incr i; ProcessBinCmd argv i}
 	    -block {incr i; ProcessBlockCmd argv i}
@@ -183,6 +191,8 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -file -
 	    -fits {set file(type) fits; CommandFitsCmd argv i}
+	    -fp -
+	    -footprint {incr i; ProcessFootprintCmd argv i}
 	    -geometry {
 		# already processed
 	    }
@@ -294,7 +304,11 @@ proc ProcessCommand {argv argc} {
 		incr i
 	    }
 	    -nameserver {incr i; ProcessNRESCmd argv i}
-	    -nan {incr i; ProcessNanCmd argv i}
+	    -nan {
+		# backward compatibility prefs
+		incr i
+		ProcessNanCmd argv i
+	    }
 	    -nrrd {set file(type) nrrd}
 	    -nvss {incr i; ProcessNVSSCmd argv i}
 	    -orient {incr i; ProcessOrientCmd argv i}
@@ -319,7 +333,12 @@ proc ProcessCommand {argv argc} {
 	    -nopixeltable {PixelTableDestroyDialog}
 	    -plot {incr i; ProcessPlotCmd argv i {} {}}
 	    -png {set file(type) png}
-	    -precision {incr i; ProcessPrecisionCmd argv i}
+	    -precision {
+		# backward compatibility prefs
+		incr i
+		ProcessPrecisionCmd argv i
+	    }
+	    -prism {incr i; ProcessPrismCmd argv i}
 	    -port {incr i; set iis(port) [lindex $argv $i]}
 	    -inet_only -
 	    -port_only {
@@ -411,15 +430,20 @@ proc ProcessCommand {argv argc} {
 	    -source {incr i; ProcessSourceCmd argv i}
 	    -tcl {incr i; ; ProcessTclCmd argv i {} {}}
 	    -theme {
-		# backward compatibility
-		incr i; ProcessThemeCmd argv i
+		# backward compatibility prefs
+		incr i
+		ProcessThemeCmd argv i
+	    }
+	    -threads {
+		# backward compatibility prefs
+		incr i
+		ProcessThreadsCmd argv i
 	    }
-	    -threads {incr i; ProcessThreadsCmd argv i}
 	    -tif -
 	    -tiff {set file(type) tiff}
 	    -tile {incr i; ProcessTileCmd argv i}
 	    -title {
-		#already processed
+		# already processed
 		incr i
 	    }
 	    -unix {incr i; set iis(unix) [lindex $argv $i]}
