@@ -367,7 +367,7 @@ proc CubeDialog {} {
     $mb add cascade -label [msgcat::mc {Coordinate}] -menu $mb.coord
     $mb add cascade -label [msgcat::mc {Axes Order}] -menu $mb.axes
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {First}] -command CubeFirst
     $mb.file add command -label [msgcat::mc {Previous}] -command CubePrev
     $mb.file add command -label [msgcat::mc {Stop}] -command CubeStop
@@ -376,16 +376,18 @@ proc CubeDialog {} {
     $mb.file add command -label [msgcat::mc {Last}] -command CubeLast
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command CubeDestroyDialog
+	-command CubeDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb icube
 
-    menu $mb.blink
-    $mb.blink add radiobutton -label ".125 [msgcat::mc {Seconds}]" \
+    ThemeMenu $mb.blink
+    $mb.blink add radiobutton -label "1/16 [msgcat::mc {Seconds}]" \
+	-variable blink(interval) -value 62
+    $mb.blink add radiobutton -label "1/8 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 125
-    $mb.blink add radiobutton -label ".25 [msgcat::mc {Seconds}]" \
+    $mb.blink add radiobutton -label "1/4 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 250
-    $mb.blink add radiobutton -label ".5 [msgcat::mc {Seconds}]" \
+    $mb.blink add radiobutton -label "1/2 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 500
     $mb.blink add radiobutton -label "1 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 1000
@@ -395,10 +397,12 @@ proc CubeDialog {} {
 	-variable blink(interval) -value 4000
     $mb.blink add radiobutton -label "8 [msgcat::mc {Seconds}]" \
 	-variable blink(interval) -value 8000
+    $mb.blink add radiobutton -label "16 [msgcat::mc {Seconds}]" \
+	-variable blink(interval) -value 16000
 
     CoordMenu $mb.coord cube system 2 {} {} UpdateCubeDialog
 
-    menu $mb.axes
+    ThemeMenu $mb.axes
     $mb.axes add radiobutton -label {1 2 3} -variable cube(axes) \
 	-value 123 -command CubeAxes
     $mb.axes add radiobutton -label {1 3 2} -variable cube(axes) \
@@ -451,6 +455,8 @@ proc CubeDialog {} {
 
     set dcube(format) {%g}
 
+    bind $w <<Close>> CubeDestroyDialog
+
     UpdateCubeDialog
 }
 
@@ -865,10 +871,8 @@ proc CubeAxes {} {
     global rgb
 
     if {$current(frame) != {}} {
-	SetWatchCursor
 	RGBEvalLockCurrent rgb(lock,axes) \
 	    "$current(frame) cube axes $cube(axes)"
-	ResetWatchCursor
 
 	LockAxesCurrent
 	UpdateHeaderDialog
