@@ -38,7 +38,7 @@ proc EllipseDialog {varname} {
 
     # analysis
     $var(mb) add cascade -label [msgcat::mc {Analysis}] -menu $var(mb).analysis
-    menu $var(mb).analysis
+    ThemeMenu $var(mb).analysis
 
     MarkerAnalysisStatsDialog $varname
     MarkerAnalysisHistogramDialog $varname
