@@ -114,7 +114,8 @@ proc CreateNameNumberFrame {which type} {
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
 	-times $ds9(times) \
-	-fg $ds9(foreground) -bg $ds9(background)
+	-fg [ThemeTreeForeground] \
+	-bg [ThemeTreeBackground]
 
     $ds9(next) threads $ds9(threads)
 
@@ -144,7 +145,9 @@ proc CreateNameNumberFrame {which type} {
 	$pds9(prec,angle)
     
     $ds9(next) bg color $pds9(bg)
+    $ds9(next) bg color $pds9(bg,use)
     $ds9(next) nan color $pds9(nan)
+    $ds9(next) highlite color blue
 
     $ds9(next) iraf align $pds9(iraf)
 
@@ -377,7 +380,8 @@ proc BindEventsFrame {which} {
     $ds9(canvas) bind $which <Enter> [list EnterFrame $which %x %y]
     $ds9(canvas) bind $which <Leave> [list LeaveFrame $which]
 
-    $ds9(canvas) bind $which <Button-1> [list Button1Frame $which %x %y]
+    $ds9(canvas) bind $which <Button-1> \
+	[list Button1Frame $which %x %y]
     $ds9(canvas) bind $which <Shift-Button-1> \
 	[list ShiftButton1Frame $which %x %y]
     $ds9(canvas) bind $which <Control-Button-1> \
@@ -574,6 +578,7 @@ proc EnterFrame {which x y} {
 	    set y [lindex $coord 1]
 	}
 	catalog -
+	footprint -
 	pan -
 	zoom -
 	rotate -
@@ -590,7 +595,6 @@ proc EnterFrame {which x y} {
     UpdateGraphLayout $which
     UpdateGraphAxis $which
     UpdateGraphData $which $x $y canvas
-    UpdateMagnifier $which $x $y
 
     if {$view(magnifier)} {
 	# don't turn on the magnifier until we've finished the init process
@@ -601,6 +605,7 @@ proc EnterFrame {which x y} {
     }
 
     UpdateEditMenu
+    UpdateMagnifier $which $x $y
 }
 
 proc LeaveFrame {which} {
@@ -630,6 +635,7 @@ proc LeaveFrame {which} {
 	rotate -
 	crop -
 	catalog -
+	footprint -
 	examine -
 	iexam -
 	3d {
@@ -684,7 +690,8 @@ proc DoMotion {which x y cursor1 cursor2} {
     switch -- $current(mode) {
 	pointer -
 	region -
-	catalog {
+	catalog -
+	footprint {
 	    if {$which == $current(frame)} {
 		MarkerCursor $which $x $y $cursor1 $cursor2
 	    }
@@ -738,7 +745,6 @@ proc Button1Frame {which x y} {
 		set ds9(next) $which
 		GotoFrame
 	    }
-	    UpdateMagnifier $which $x $y
 	}
 	pointer -
 	region {
@@ -753,7 +759,6 @@ proc Button1Frame {which x y} {
 		set ds9(next) $which
 		GotoFrame
 	    }
-	    UpdateMagnifier $which $x $y
 	}
 	crosshair {
 	    CrosshairButton $which $x $y
@@ -764,21 +769,17 @@ proc Button1Frame {which x y} {
 	    UpdateGraphLayout $which
 	    UpdateGraphAxis $which
 	    UpdateGraphData $which $x $y canvas
-	    UpdateMagnifier $which $x $y
 	}
 	colorbar {ColorbarButton3 $x $y}
 	pan {
 	    PanButton $which $x $y
-	    UpdateMagnifier $which $x $y
 	}
 	zoom {
 	    ZoomButton $which $x $y
-	    UpdateMagnifier $which $x $y
 	}
 	rotate {RotateButton $which $x $y}
 	crop {
 	    CropButton $which $x $y
-	    UpdateMagnifier $which $x $y
 	}
 	catalog {
 	    if {$which == $current(frame)} {
@@ -792,8 +793,20 @@ proc Button1Frame {which x y} {
 		set ds9(next) $which
 		GotoFrame
 	    }
-	    UpdateMagnifier $which $x $y
 	}
+        footprint {
+            if {$which == $current(frame)} {
+                FPButton $which $x $y
+            } else {
+                # we need this cause MarkerMotion maybe called,                 
+                # and we don't want it                                          
+                set imarker(motion) none
+                set imarker(handle) -1
+
+                set ds9(next) $which
+                GotoFrame
+            }
+        }
 	examine {ExamineButton $which $x $y}
 	iexam {IExamButton $which $x $y}
 	3d {}
@@ -819,7 +832,6 @@ proc ShiftButton1Frame {which x y} {
 	    if {$which == $current(frame)} {
 		MarkerShift $which $x $y
 	    }
-	    UpdateMagnifier $which $x $y
 	}
 	crosshair {}
 	colorbar {}
@@ -828,14 +840,17 @@ proc ShiftButton1Frame {which x y} {
 	rotate -
 	crop {
 	    Crop3dButton $which $x $y 0
-	    UpdateMagnifier $which $x $y
 	}
 	catalog {
 	    if {$which == $current(frame)} {
 		CATShift $which $x $y
 	    }
-	    UpdateMagnifier $which $x $y
 	}
+        footprint {
+            if {$which == $current(frame)} {
+                FPShift $which $x $y
+            }
+        }
 	examine {}
 	iexam {}
 	3d {}
@@ -860,7 +875,8 @@ proc ControlButton1Frame {which x y} {
 	none {}
 	pointer -
 	region -
-	catalog {
+	catalog -
+	footprint {
 	    if {$which == $current(frame)} {
 		MarkerControl $which $x $y
 	    } else {
@@ -869,7 +885,6 @@ proc ControlButton1Frame {which x y} {
 		set imarker(motion) none
 		set imarker(handle) -1
 	    }
-	    UpdateMagnifier $which $x $y
 	}
 	crosshair -
 	colorbar -
@@ -878,7 +893,6 @@ proc ControlButton1Frame {which x y} {
 	rotate {}
 	crop {
 	    Crop3dButton $which $x $y 1
-	    UpdateMagnifier $which $x $y
 	}
 	examine {}
 	iexam {}
@@ -904,7 +918,8 @@ proc ControlShiftButton1Frame {which x y} {
 	none {}
 	pointer -
 	region -
-	catalog {
+	catalog -
+	footprint {
 	    if {$which == $current(frame)} {
 		MarkerControlShift $which $x $y
 	    } else {
@@ -913,7 +928,6 @@ proc ControlShiftButton1Frame {which x y} {
 		set imarker(motion) none
 		set imarker(handle) -1
 	    }
-	    UpdateMagnifier $which $x $y
 	}
 	crosshair -
 	colorbar -
@@ -943,7 +957,7 @@ proc Motion1Frame {which x y} {
     }
 
     switch -- $current(mode) {
-	none {UpdateMagnifier $which $x $y}
+	none {}
 	pointer -
 	region {
 	    if {$which == $current(frame)} {
@@ -953,7 +967,6 @@ proc Motion1Frame {which x y} {
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
 	    UpdateGraphData $which $x $y canvas
-	    UpdateMagnifier $which $x $y
 	}
 	crosshair {
 	    if {$ds9(b1)} {
@@ -963,7 +976,6 @@ proc Motion1Frame {which x y} {
 		UpdateInfoBox $which $x $y canvas
 		UpdatePixelTableDialog $which $x $y canvas
 		UpdateGraphData $which $x $y canvas
-		UpdateMagnifier $which $x $y
 	    }
 	}
 	colorbar {
@@ -974,10 +986,9 @@ proc Motion1Frame {which x y} {
 	pan {
 	    if {$ds9(b1)} {
 		PanMotion $which $x $y
-		UpdateMagnifier $which $x $y
 	    }
 	}
-	zoom {UpdateMagnifier $which $x $y}
+	zoom {}
 	rotate {
 	    if {$ds9(b1)} {
 		RotateMotion $which $x $y
@@ -993,8 +1004,6 @@ proc Motion1Frame {which x y} {
 	    if {$ds9(cb1)} {
 		Crop3dMotion $which $x $y 1
 	    }
-
-	    UpdateMagnifier $which $x $y
 	}
 	catalog {
 	    if {$which == $current(frame)} {
@@ -1004,8 +1013,16 @@ proc Motion1Frame {which x y} {
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
 	    UpdateGraphData $which $x $y canvas
-	    UpdateMagnifier $which $x $y
 	}
+        footprint {
+            if {$which == $current(frame)} {
+                FPMotion $which $x $y
+            }
+
+            UpdateInfoBox $which $x $y canvas
+            UpdatePixelTableDialog $which $x $y canvas
+            UpdateGraphData $which $x $y canvas
+        }
 	examine {}
 	iexam {}
 	3d {
@@ -1014,6 +1031,8 @@ proc Motion1Frame {which x y} {
 	    }
 	}
     }
+
+    UpdateMagnifier $which $x $y
 }
 
 proc Release1Frame {which x y} {
@@ -1081,6 +1100,11 @@ proc Release1Frame {which x y} {
 		CATRelease $which $x $y
 	    }
 	}
+        footprint {
+            if {$which == $current(frame)} {
+                FPRelease $which $x $y
+            }
+        }
 	examine {}
 	iexam {}
 	3d {}
@@ -1093,7 +1117,6 @@ proc Release1Frame {which x y} {
     set ds9(csb1) 0
 
     UpdateEditMenu
-    UpdateMagnifier $which $x $y
 }
 
 proc Double1Frame {which x y} {
@@ -1109,7 +1132,6 @@ proc Double1Frame {which x y} {
 	region {
 	    if {$which == $current(frame)} {
 		MarkerDouble $which $x $y
-		UpdateMagnifier $which $x $y
 	    }
 	}
 	none -
@@ -1120,6 +1142,7 @@ proc Double1Frame {which x y} {
 	rotate -
 	crop -
 	catalog -
+	footprint -
 	examine -
 	iexam {}
 	3d {3DDouble $which}
@@ -1146,13 +1169,13 @@ proc DoubleRelease1Frame {which x y} {
 	rotate -
 	crop -
 	catalog -
+	footprint -
 	examine -
 	iexam -
 	3d {}
     }
 
     UpdateEditMenu
-    UpdateMagnifier $which $x $y
 }
 
 proc Button2Frame {which x y} {
@@ -1185,6 +1208,7 @@ proc Motion2Frame {which x y} {
     }
 
     PanMotion $which $x $y
+    UpdateMagnifier $which $x $y
 }
 
 proc Release2Frame {which x y} {
@@ -1259,27 +1283,6 @@ proc MouseWheelFrame {X Y dd} {
 	puts stderr "MouseWheel $X $Y $dd"
     }
 
-    # macos returns main window coords in X,Y
-    switch $ds9(wm) {
-	x11 -
-	win32 {}
-	aqua {
-	    switch $view(layout) {
-		horizontal {
-		    set aa [winfo height $ds9(main)]
-		    set bb [winfo height $ds9(image)]
-		    set Y [expr $Y-$aa+$bb]
-		}
-		vertical {
-		    set aa [winfo width $ds9(main)]
-		    set bb [winfo width $ds9(image)]
-		    set X [expr $X-$aa+$bb]
-		}
-	    }
-	    
-	}
-    }
-
     set id [$ds9(canvas) find closest $X $Y]
     set which [lindex [$ds9(canvas) gettags $id] 0]
     if {[string equal -length 5 {Frame} $which]} {
@@ -1309,6 +1312,7 @@ proc KeyFrame {which K A xx yy} {
 	puts stderr "KeyFrame $which $K $A $xx $yy"
     }
 
+    # MacOS can sometime gerate a ?? modifier keyevent
     if {$K == {Control_R} ||
 	$K == {Control_L} ||
 	$K == {Meta_R} ||
@@ -1322,15 +1326,15 @@ proc KeyFrame {which K A xx yy} {
 	return
     }
 
+    if {$ds9(modifier)} {
+	return
+    }
+
     # modal bindings
     switch -- $current(mode) {
 	none {
 	    switch -- $K {
-		c {
-		    if {!$ds9(modifier)} {
-			DisplayCoordDialog $which $xx $yy
-		    }
-		}
+		c {DisplayCoordDialog $which $xx $yy}
 
 		plus {CubeNext}
 		minus {CubePrev}
@@ -1351,11 +1355,7 @@ proc KeyFrame {which K A xx yy} {
 	pointer -
 	region {
 	    switch -- $K {
-		c {
-		    if {!$ds9(modifier)} {
-			DisplayCoordDialog $which $xx $yy
-		    }
-		}
+		c {DisplayCoordDialog $which $xx $yy}
 
 		plus {CubeNext}
 		minus {CubePrev}
@@ -1385,11 +1385,7 @@ proc KeyFrame {which K A xx yy} {
 	}
 	crosshair {
 	    switch -- $K {
-		c {
-		    if {!$ds9(modifier)} {
-			DisplayCoordDialog $which $xx $yy
-		    }
-		}
+		c {DisplayCoordDialog $which $xx $yy}
 
 		plus {CubeNext}
 		minus {CubePrev}
@@ -1442,6 +1438,18 @@ proc KeyFrame {which K A xx yy} {
 	    }	    
 	    CATKey $which $K
 	}
+        footprint {                                                             
+            switch -- $K {                                                      
+                Up -                                                            
+                k {MarkerArrowKey $which 0 -1}                                  
+                Down -                                                          
+                j {MarkerArrowKey $which 0 1}                                   
+                Left -                                                          
+                h {MarkerArrowKey $which -1 0}                                  
+                Right -                                                         
+                l {MarkerArrowKey $which 1 0}                                   
+            }                                                                   
+        }                                                                       
 	iexam {IExamKey $which $K $xx $yy}
 	colorbar -
 	crop -
@@ -1456,16 +1464,14 @@ proc KeyFrame {which K A xx yy} {
 		h {3DArrowKey $which -1 0}
 		Right -
 		l {3DArrowKey $which 1 0}
-	    }
 
-	    z {Zoom 2 2}
-	    Z {Zoom .5 .5}
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
+	    }
 	}
     }
 
     # since most modes do zoom
-    UpdateMagnifier $which $xx $yy
-
     UpdateEditMenu
 }
 
@@ -1482,6 +1488,7 @@ proc KeyReleaseFrame {which K A xx yy} {
 	puts stderr "KeyReleaseFrame $which $K $A $xx $yy"
     }
 
+    # MacOS can sometime gerate a ?? modifier keyevent
     if {$K == {Control_R} ||
 	$K == {Control_L} ||
 	$K == {Meta_R} ||
@@ -1489,7 +1496,8 @@ proc KeyReleaseFrame {which K A xx yy} {
 	$K == {Alt_R} ||
 	$K == {Alt_L} ||
 	$K == {Super_R} ||
-	$K == {Super_L}} {
+	$K == {Super_L} ||
+	$K == {??}} {
 	set ds9(modifier) 0
     }
 }
@@ -1956,6 +1964,21 @@ proc FrameToFront {} {
 
     UpdateGraphLayout $which
     UpdateDS9
+
+    # Aqua has a problem with refreshing
+    switch $ds9(wm) {
+	x11 -
+	win32 {}
+	aqua {
+	    if {!$ds9(init)} {
+		global debug
+		if {$debug(tcl,idletasks)} {
+		    puts stderr "FrameToFront"
+		}
+		update idletasks
+	    }
+	}
+    }
 }
 
 proc TileDialog {} {
@@ -1985,10 +2008,11 @@ proc TileDialog {} {
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] -command TileApplyDialog
     $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command TileDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command TileDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb itile
 
@@ -2041,6 +2065,8 @@ proc TileDialog {} {
     grid rowconfigure $w 2 -weight 1
     grid rowconfigure $w 3 -weight 1
     grid columnconfigure $w 0 -weight 1
+
+    bind $w <<Close>> TileDestroyDialog
 }
 
 proc TileDestroyDialog {} {
