@@ -28,7 +28,8 @@ proc GridDefault {} {
     set grid(skyformat) sexagesimal
 
     set grid(grid) 1
-    set grid(grid,color) blue
+#    set grid(grid,color) blue
+    set grid(grid,color) cyan
     set grid(grid,width) 1
     set grid(grid,style) 0
     set grid(grid,gap1) {}
@@ -39,19 +40,22 @@ proc GridDefault {} {
     set grid(grid,gapunit3) {}
 
     set grid(axes) 1
-    set grid(axes,color) red
+#    set grid(axes,color) red
+    set grid(axes,color) cyan
     set grid(axes,width) 1
     set grid(axes,style) 0
     set grid(axes,type) interior
     set grid(axes,origin) lll
 
     set grid(tick) 1
-    set grid(tick,color) white
+#    set grid(tick,color) white
+    set grid(tick,color) cyan
     set grid(tick,width) 1
     set grid(tick,style) 0
 
     set grid(border) 1
-    set grid(border,color) blue
+#    set grid(border,color) blue
+    set grid(border,color) cyan
     set grid(border,width) 1
     set grid(border,style) 0
 
@@ -63,7 +67,8 @@ proc GridDefault {} {
     set grid(numlab,size) 10
     set grid(numlab,weight) normal
     set grid(numlab,slant) roman
-    set grid(numlab,color) green
+#    set grid(numlab,color) green
+    set grid(numlab,color) cyan
     set grid(numlab,gap1) {}
     set grid(numlab,gap2) {}
     set grid(numlab,gap3) {}
@@ -586,23 +591,24 @@ proc GridDialog {} {
     $mb add cascade -label [msgcat::mc {Border}] -menu $mb.border
 
     # File
-    menu $mb.file
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command GridLoadDialog -accelerator "${ds9(ctrl)}O"
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command GridSaveDialog -accelerator "${ds9(ctrl)}S"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Apply}] -command GridApplyDialog
     $mb.file add command -label [msgcat::mc {Reset}] -command GridResetDialog
     $mb.file add command -label [msgcat::mc {Clear}] -command GridClearDialog
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load Configuration}]..." \
-	-command GridLoadDialog
-    $mb.file add command -label "[msgcat::mc {Save Configuration}]..." \
-	-command GridSaveDialog
-    $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command GridDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command GridDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     # Edit
     EditMenu $mb igrid
 
     # Type
-    menu $mb.type
+    ThemeMenu $mb.type
     $mb.type add radiobutton -label [msgcat::mc {Analysis}] \
 	-variable grid(type) -value analysis -command GridApplyDialog
     $mb.type add radiobutton -label [msgcat::mc {Publication}] \
@@ -625,7 +631,7 @@ proc GridDialog {} {
     CoordMenu $mb.coord grid system 1 sky skyformat GridApplyDialog
 
     # Grid
-    menu $mb.grid
+    ThemeMenu $mb.grid
     $mb.grid add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(grid) -command GridApplyDialog
     $mb.grid add separator
@@ -636,7 +642,7 @@ proc GridDialog {} {
     GridCreateLineMenu $mb.grid.line grid,width grid,style
 
     # Axes
-    menu $mb.axes
+    ThemeMenu $mb.axes
     $mb.axes add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(axes) -command GridApplyDialog
     $mb.axes add separator
@@ -648,7 +654,7 @@ proc GridDialog {} {
     ColorMenu $mb.axes.color grid axes,color GridApplyDialog
     GridCreateLineMenu $mb.axes.line axes,width axes,style
 
-    menu $mb.axes.origin
+    ThemeMenu $mb.axes.origin
     $mb.axes.origin add radiobutton -label [msgcat::mc {Lower Left Front}] \
 	-variable grid(axes,origin) -value lll -command GridApplyDialog
     $mb.axes.origin add radiobutton -label [msgcat::mc {Lower Right Front}] \
@@ -668,7 +674,7 @@ proc GridDialog {} {
 	-variable grid(axes,origin) -value luu -command GridApplyDialog
 
     # Numerics
-    menu $mb.numlab
+    ThemeMenu $mb.numlab
     $mb.numlab add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(numlab) -command GridApplyDialog
     $mb.numlab add separator
@@ -683,7 +689,7 @@ proc GridDialog {} {
 	GridApplyDialog
 
     # Labels
-    menu $mb.textlab
+    ThemeMenu $mb.textlab
     $mb.textlab add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(textlab) -command GridApplyDialog
     $mb.textlab add separator
@@ -698,7 +704,7 @@ proc GridDialog {} {
 	GridApplyDialog
 
     # Tickmarks
-    menu $mb.tick
+    ThemeMenu $mb.tick
     $mb.tick add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(tick) -command GridApplyDialog
     $mb.tick add separator
@@ -711,7 +717,7 @@ proc GridDialog {} {
     GridCreateLineMenu $mb.tick.line tick,width tick,style
 
     # Title
-    menu $mb.title
+    ThemeMenu $mb.title
     $mb.title add checkbutton -label [msgcat::mc {Show}] \
 	 -variable grid(title) -command GridApplyDialog
     $mb.title add separator
@@ -724,7 +730,7 @@ proc GridDialog {} {
 	GridApplyDialog
 
     # Border
-    menu $mb.border
+    ThemeMenu $mb.border
     $mb.border add checkbutton -label [msgcat::mc {Show}] \
 	-variable grid(border) -command GridApplyDialog
     $mb.border add separator
@@ -804,8 +810,6 @@ proc GridDialog {} {
     pack $f.apply $f.reset $f.clear $f.close -side left -expand true \
 	-padx 2 -pady 4
 
-    bind $w <Return> "GridApplyDialog"
-
     # Fini
     grid $w.label -sticky news
     grid $w.param -sticky news
@@ -814,8 +818,11 @@ proc GridDialog {} {
     grid rowconfigure $w 1 -weight 1
     grid columnconfigure $w 0 -weight 1
 
-    # some window managers need a hint
-    raise $w
+    bind $w <Return> GridApplyDialog
+
+    bind $w <<Open>> GridLoadDialog
+    bind $w <<Save>> GridSaveDialog
+    bind $w <<Close>> GridDestroyDialog
 
     UpdateGridDialog
 }
@@ -988,34 +995,40 @@ proc GridCreateLineMenu {which width dash} {
 }
 
 proc GridLoadDialog {} {
-    GridLoad [OpenFileDialog gridfbox]
+    global igrid
+    
+    set fn [OpenFileDialog gridfbox $igrid(top)]
+    GridLoad $fn
 }
 
-proc GridLoad {filename} {
+proc GridLoad {fn} {
     global grid
 
-    if {$filename != {}} {
-	source $filename
+    if {$fn != {}} {
+	source $fn
+
+	# backward compatibility
+	FixFontVar grid(numlab,weight) grid(numlab,slant) grid(numlab,style)
+	FixFontVar grid(textlab,weight) grid(textlab,slant) grid(textlab,style)
+	FixFontVar grid(title,weight) grid(title,slant) grid(title,style)
+
+	set grid(view) 1
+	GridUpdateCurrent
     }
-
-    # backward compatibility
-    FixFontVar grid(numlab,weight) grid(numlab,slant) grid(numlab,style)
-    FixFontVar grid(textlab,weight) grid(textlab,slant) grid(textlab,style)
-    FixFontVar grid(title,weight) grid(title,slant) grid(title,style)
-
-    set grid(view) 1
-    GridUpdateCurrent
 }
 
 proc GridSaveDialog {} {
-    GridSave [SaveFileDialog gridfbox]
+    global igrid
+
+    set fn [SaveFileDialog gridfbox $igrid(top)]
+    GridSave $fn
 }
 
-proc GridSave {filename} {
+proc GridSave {fn} {
     global grid
 
-    if {$filename != {}} {
-	set file [open $filename w]
+    if {$fn != {}} {
+	set file [open $fn w]
 	puts $file "global grid"
 	puts $file "array set grid \{ [array get grid] \}"
 	close $file
