@@ -24,14 +24,12 @@ proc DisplayHeaderMenu {} {
     #  mosaic image cube xtension
 
     set cnt [$current(frame) get fits count]
+    set ll {}
 
     if {$cnt > 0} {
-	set slb(count) 0
-
 	# check for primary
 	set fn [$current(frame) get fits file name 1]
-	set xten \
-	    [string trim [$current(frame) get fits header 1 keyword {XTENSION}]]
+	set xten [string trim [$current(frame) get fits header 1 keyword {XTENSION}]]
 	if {$xten != {}} {
 	    set bb [string first {[} $fn]
 	    if {$bb>0} {
@@ -39,9 +37,7 @@ proc DisplayHeaderMenu {} {
 	    } else {
 		set pn "primary"
 	    }
-	    incr slb(count)
-	    set slb($slb(count),item) $pn
-	    set slb($slb(count),value) -1
+	    lappend ll [list -1 $pn]
 	}
 
 	set last {}
@@ -56,23 +52,79 @@ proc DisplayHeaderMenu {} {
 	    }
 	    
 	    if {$fn != $last} {
-		incr slb(count)
-		set slb($slb(count),item) $fn
-		set slb($slb(count),value) $ii
+		lappend ll [list $ii $fn]
 		set last $fn
 	    }
 	}
 
-	if {$slb(count) <= 1} {
+	if {[llength $ll] <= 1} {
 	    DisplayHeader 1 $fn
 	} else {
-	    if {[SLBDialog slb {Select Header} 40]} {
-		DisplayHeader $slb(value) $slb(item)
+	    set rr [DisplayHeaderListDialog $ll {Select Header} 40]
+	    if {$rr != {}} {
+		set ss [lindex $rr 0]
+		DisplayHeader [lindex $ss 0] [lindex $ss 1]
 	    }
 	}
     }
 }
 
+proc DisplayHeaderListDialog {ll title width} {
+    global ed
+
+    set w {.slb}
+
+    set ed(ok) 0
+
+    DialogCreate $w $title ed(ok)
+
+    # Lists
+    set f [ttk::frame $w.ed]
+
+    ttk::scrollbar $f.scroll -command "$f.box yview"
+    set ed(listbox) [ttk::treeview $f.box \
+			 -yscroll "$f.scroll set" \
+			 -selectmode browse \
+			 -show tree \
+			]
+
+    foreach ii $ll {
+	$ed(listbox) insert {} end -id $ii -text [lindex $ii 1]
+    }
+    $ed(listbox) selection set [list [lindex $ll 0]]
+
+    grid $f.box $f.scroll -sticky news
+    grid rowconfigure $f 0 -weight 1
+    grid columnconfigure $f 0 -weight 1
+
+    # Buttons
+    set f [ttk::frame $w.buttons]
+    ttk::button $f.ok -text [msgcat::mc {OK}] \
+	-command {set ed(ok) 1}
+    ttk::button $f.cancel -text [msgcat::mc {Cancel}] \
+	-command {set ed(ok) 0}
+    pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
+
+    # Fini
+    ttk::separator $w.sep -orient horizontal
+    pack $w.buttons $w.sep -side bottom -fill x
+    pack $w.ed -side top -fill both -expand true
+
+    bind $w <Double-1> {set ed(ok) 1}
+    bind $w <Return> {set ed(ok) 1}
+
+    DialogWait $w ed(ok) $w.buttons.ok
+
+    set rr {}
+    if {$ed(ok)} {
+	set rr [$ed(listbox) selection]
+    }
+
+    # must wait until now
+    destroy $w
+    return $rr
+}
+
 proc DisplayHeader {id title} {
     global current
     global ds9
@@ -85,11 +137,12 @@ proc DisplayHeader {id title} {
     if {[$frame has fits]} {
 	set hh [$frame get fits header $id]
     }
+
     SimpleTextDialog $varname $title 80 40 insert top $hh
 
     # create a special text tag for keywords
     upvar #0 $varname var
-    $var(text) tag configure keyword -foreground $ds9(gui,bold)
+    $var(text) tag configure keyword -foreground [ThemeBold]
     
     # color tag keywords
     set stop [$var(text) index end]
