@@ -13,7 +13,7 @@ proc HVDef {} {
 
 # Public
 
-proc HV {varname title url {init {}} {sync 0}} {
+proc HV {varname title url {init {}} {sync 0} {save 0}} {
     upvar #0 $varname var
     global $varname
 
@@ -42,7 +42,7 @@ proc HV {varname title url {init {}} {sync 0}} {
 	set var(status) {}
 	set var(sync) $sync
 	set var(frame) new
-	set var(save) 0
+	set var(save) $save
 	set var(title) "$title"
 	set var(copy) {}
 	set var(search) {}
@@ -79,7 +79,7 @@ proc HV {varname title url {init {}} {sync 0}} {
 	$mb add cascade -label [msgcat::mc {View}] -menu $mb.view
 	$mb add cascade -label [msgcat::mc {Frame}] -menu $mb.frame
 
-	menu $mb.file
+	ThemeMenu $mb.file
 	$mb.file add command -label [msgcat::mc {Open URL}] \
 	    -command "HVURLDialogCmd $varname"
 	$mb.file add command -label [msgcat::mc {Open File}] \
@@ -89,9 +89,9 @@ proc HV {varname title url {init {}} {sync 0}} {
 	    -command "HVClearCmd $varname"
 	$mb.file add separator
 	$mb.file add command -label [msgcat::mc {Close}] \
-	    -command "HVDestroy $varname"
+	    -command "HVDestroy $varname" -accelerator "${ds9(ctrl)}W"
 
-	menu $mb.edit
+	ThemeMenu $mb.edit
 	$mb.edit add command -label [msgcat::mc {Cut}] \
 	    -state disabled -accelerator "${ds9(ctrl)}X"
 	$mb.edit add command -label [msgcat::mc {Copy}] \
@@ -99,25 +99,15 @@ proc HV {varname title url {init {}} {sync 0}} {
 	$mb.edit add command -label [msgcat::mc {Paste}] \
 	    -state disabled -accelerator "${ds9(ctrl)}V"
 	$mb.edit add separator
-	switch $ds9(wm) {
-	    x11 -
-	    win32 {
-		$mb.edit add command -label "[msgcat::mc {Find}]..." \
-		    -command "HVFindCmd $varname" -accelerator "${ds9(ctrl)}F"
-	    }
-	    aqua {
-		# Known bug in Tk, can't have dialogs invoked by accelerator
-		$mb.edit add command -label "[msgcat::mc {Find}]..." \
-		    -command "HVFindCmd $varname"
-	    }
-	}
+	$mb.edit add command -label "[msgcat::mc {Find}]..." \
+	    -command "HVFindCmd $varname" -accelerator "${ds9(ctrl)}F"
 	$mb.edit add command -label [msgcat::mc {Find Next}] \
 	    -command "HVFindNextCmd $varname" -accelerator "${ds9(ctrl)}G"
 	$mb.edit add separator
 	$mb.edit add command -label [msgcat::mc {Clear Cache}] \
 	    -command "HVClearCache $varname"
 
-	menu $mb.view
+	ThemeMenu $mb.view
 	$mb.view add command -label [msgcat::mc {Back}] \
 	    -command "HVBackCmd $varname"
 	$mb.view add command -label [msgcat::mc {Forward}] \
@@ -131,7 +121,7 @@ proc HV {varname title url {init {}} {sync 0}} {
 	$mb.view add command -label [msgcat::mc {Page Source}] \
 	    -command "HVPageSourceCmd $varname"
 
-	menu $mb.frame 
+	ThemeMenu $mb.frame 
 	$mb.frame add checkbutton \
 	    -label [msgcat::mc {Save Image on Download}] \
 	    -variable ${varname}(save)
@@ -206,22 +196,22 @@ proc HV {varname title url {init {}} {sync 0}} {
 	bind $w <Right> "$f.html xview scroll 1 units"
 	bind $w <Left> "$f.html xview scroll -1 units"
 	bind $w <<Copy>> "HVCopyCmd $varname"
+
+	bind $w <<Find>> [list HVFindCmd $varname]
+	bind $w <<FindNext>> [list HVFindNextCmd $varname]
+
+	bind $w <<Close>> [list HVDestroy $varname]
+
 	switch $ds9(wm) {
 	    x11 {
 		bind $w <Button-4> "HVMouseWheel $varname 1"
 		bind $w <Button-5> "HVMouseWheel $varname -1"
-		bind $w <<Find>> [list HVFindCmd $varname]
-	    }
-	    aqua {
-		bind $w <MouseWheel> "HVMouseWheel $varname %D"
-		# Known bug in Tk, can't have dialogs invoked by accelerator
 	    }
+	    aqua -
 	    win32 {
 		bind $w <MouseWheel> "HVMouseWheel $varname %D"
-		bind $w <<Find>> [list HVFindCmd $varname]
 	    }
 	}
-	bind $w <<FindNext>> [list HVFindNextCmd $varname]
 
 	# Status
 	set f [ttk::frame $w.status]
@@ -244,6 +234,46 @@ proc HV {varname title url {init {}} {sync 0}} {
     }
 }
 
+proc HVDestroy {varname} {
+    upvar #0 $varname var
+    global $varname
+    global ihv
+
+    global debug
+    if {$debug(tcl,hv)} {
+	puts stderr "HVDestroy"
+    }
+
+    HVCancel $varname
+
+    # clear the widge and all images
+    $var(widget) clear
+
+    # clear image cache
+    foreach x [array names $varname "images,*"] {
+	image delete $var($x)
+	unset ${varname}($x)
+    }
+
+    # clear cache
+    HVClearCache $varname
+
+    # destroy the window and menubar
+    if {[winfo exists $var(top)]} {
+	destroy $var(top)
+	destroy $var(mb)
+    }
+
+    # delete it from the xpa list
+    set ii [lsearch $ihv(windows) $varname]
+    if {$ii>=0} {
+	set ihv(windows) [lreplace $ihv(windows) $ii $ii]
+    }
+
+    # clear varname
+    unset $varname
+}
+
 # Bindings
 
 proc HVMotion {varname x y} {
@@ -414,7 +444,7 @@ proc HVFileDialogCmd {varname} {
 
     global debug
 
-    set fn [OpenFileDialog hvhtmlfbox]
+    set fn [OpenFileDialog hvhtmlfbox $var(top)]
     if {"$fn" != {}} {
 	HVFileDialog $varname "$fn"
     }
@@ -740,53 +770,6 @@ proc HVAnalysisCancel {which i} {
 
 # Archive Servers
 
-proc HVArchChandraChaser {} {
-    global current
-
-    set coord {}
-    if {$current(frame) != {}} {
-	if {[$current(frame) has wcs celestial wcs]} {
-	    set coord [$current(frame) get fits center wcs fk5 degrees]
-	    set size \
-		[expr [lindex [$current(frame) get fits size wcs fk5 arcmin] 0]/2.]
-	}
-    }
-
-    set l {}
-    if {[string length $coord] != 0} {
-	lappend l "1 lon [lindex $coord 0]"
-	lappend l "1 lat [lindex $coord 1]"
-	lappend l "1 radius $size"
-    }
-
-    global hvchandrachaser
-    HV hvchandrachaser {Chandra Chaser} http://cda.harvard.edu/chaser/mainEntry.do $l
-}
-
-proc HVArchChandraPop {} {
-    global current
-
-    set coord {}
-    if {$current(frame) != {}} {
-	if {[$current(frame) has wcs celestial wcs]} {
-	    set coord [$current(frame) get fits center wcs fk5 degrees]
-	    set size \
-		[expr [lindex [$current(frame) get fits size wcs fk5 arcmin] 0]/2.]
-	}
-    }
-
-    set l {}
-    if {[string length $coord] != 0} {
-	lappend l "1 lon [lindex $coord 0]"
-	lappend l "1 lat [lindex $coord 1]"
-	lappend l "1 radius $size"
-	lappend l "1 searchBy position"
-    }
-
-    global hvchandrapop
-    HV hvchandrapop {Chandra Popular} http://cda.harvard.edu/pop/mainEntry.do $l
-}
-
 proc HVArchChandraFTP {} {
     global current
 
