@@ -40,46 +40,6 @@ proc HVCancel {varname} {
     }
 }
 
-proc HVDestroy {varname} {
-    upvar #0 $varname var
-    global $varname
-    global ihv
-
-    global debug
-    if {$debug(tcl,hv)} {
-	puts stderr "HVDestroy"
-    }
-
-    HVCancel $varname
-
-    # clear the widge and all images
-    $var(widget) clear
-
-    # clear image cache
-    foreach x [array names $varname "images,*"] {
-	image delete $var($x)
-	unset ${varname}($x)
-    }
-
-    # clear cache
-    HVClearCache $varname
-
-    # destroy the window and menubar
-    if {[winfo exists $var(top)]} {
-	destroy $var(top)
-	destroy $var(mb)
-    }
-
-    # delete it from the xpa list
-    set ii [lsearch $ihv(windows) $varname]
-    if {$ii>=0} {
-	set ihv(windows) [lreplace $ihv(windows) $ii $ii]
-    }
-
-    # clear varname
-    unset $varname
-}
-
 proc HVReset {varname} {
     upvar #0 $varname var
     global $varname
@@ -1174,13 +1134,26 @@ proc HVParseImg {varname} {
     }
 
     if {$var(save)} {
+	set fn [file tail $var(url)]
 	switch -- $var(mime) {
-	    "image/gif" {set fn [SaveFileDialog giffbox]}
-	    "image/jpeg" {set fn [SaveFileDialog jpegfbox]}
-	    "image/tiff" {set fn [SaveFileDialog tifffbox]}
-	    "image/png" {set fn [SaveFileDialog pngfbox]}
+	    "image/gif" {
+		FileLast giffbox $fn
+		set fn [SaveFileDialog giffbox $var(top)]
+	    }
+	    "image/jpeg" {
+		FileLast jpegfbox $fn
+		set fn [SaveFileDialog jpegfbox $var(top)]
+	    }
+	    "image/tiff" {
+		FileLast tifffbox $fn
+		set fn [SaveFileDialog tifffbox $var(top)]
+	    }
+	    "image/png" {
+		FileLast pngfbox $fn
+		set fn [SaveFileDialog pngfbox $var(top)]
+	    }
 	}
-	
+
 	if {[string length "$fn"] != 0} {
 	    if {![catch {file rename -force "$var(fn)" "$fn"}]} {
 		set var(fn) "$fn"
@@ -1209,15 +1182,16 @@ proc HVParseFITS {varname} {
     global debug
 
     if {$var(save)} {
+	set fn [file tail $var(url)]
 	switch -- $var(encoding) {
-	    gzip {FileLast savefitsfbox "ds9.fits.gz"}
-	    bzip2 {FileLast savefitsfbox "ds9.fits.bz2"}
-	    compress {FileLast savefitsfbox "ds9.fits.Z"}
-	    pack {FileLast savefitsfbox "ds9.fits.z"}
-	    default {FileLast savefitsfbox "ds9.fits"}
+	    gzip {FileLast savefitsfbox "$fn"}
+	    bzip2 {FileLast savefitsfbox "$fn"}
+	    compress {FileLast savefitsfbox "$fn"}
+	    pack {FileLast savefitsfbox "$fn"}
+	    default {FileLast savefitsfbox "$fn"}
 	}
 
-	set fn [SaveFileDialog savefitsfbox]
+	set fn [SaveFileDialog savefitsfbox $var(top)]
 	if {[string length "$fn"] != 0} {
 	    if {![catch {file rename -force "$var(fn)" "$fn"}]} {
 		set var(fn) "$fn"
@@ -1323,7 +1297,7 @@ proc HVParseSave {varname} {
 	set fn [file tail $r(path)]
     }
     FileLast savefitsfbox $fn
-    set fn [SaveFileDialog savefitsfbox]
+    set fn [SaveFileDialog savefitsfbox $var(top)]
     if {[string length "$fn"] != 0} {
 	if {![catch {file rename -force "$var(fn)" "$fn"}]} {
 	    set var(delete) 0
@@ -1494,7 +1468,7 @@ proc HVProgress {varname token totalsize currentsize} {
 
     global debug
     if {$debug(tcl,hv)} {
-	puts stderr "HVProgress:$varname"
+#	puts stderr "HVProgress:$varname"
     }
 
     if {$totalsize != 0} {
