@@ -119,28 +119,62 @@ proc CreateCanvas {} {
 
     set ds9(image) [ttk::frame $ds9(main).f]
     set ds9(canvas) [canvas $ds9(image).c -width $ww -height $hh \
-			 -highlightthickness 0 -insertofftime 0 \
-			 -bg $ds9(background)]
+			 -highlightthickness 0 \
+			 -insertofftime 0 \
+			 -bg [ThemeTreeBackground] \
+			]
     grid rowconfigure $ds9(image) 0 -weight 1
     grid columnconfigure $ds9(image) 0 -weight 1
     grid $ds9(canvas) -row 0 -column 0 -sticky news
 
     # extra space for window tab
+    set ds9(canvas,bottom) {}
     if {$canvas(gap,bottom)>0} {
-	set f [frame $ds9(image).b -width 1 -height $canvas(gap,bottom) \
-		   -bg $ds9(background)]
-	grid $f -row 1 -column 0 -sticky ew
+	# set background style to TreeView, not TFrame
+	set ds9(canvas,bottom) [ttk::frame $ds9(image).b \
+				    -width 1 \
+				    -height $canvas(gap,bottom) \
+				    -style Tree.TFrame \
+				   ]
+	grid $ds9(canvas,bottom) -row 1 -column 0 -sticky ew
     }
 	
     # needed to realize window so Layout routines will work
     grid $ds9(image)
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {bind $ds9(canvas) <<ThemeChanged>> {ThemeConfigCanvas %W}}
+	aqua {}
+    }
+}
+
+proc ThemeConfigCanvas {w} {
+    global ds9
+    
+    $w configure -bg [ThemeTreeBackground]
+
+    $w itemconfigure colorbar -fg [ThemeTreeForeground]
+    $w itemconfigure colorbar -bg [ThemeTreeBackground]
+
+    $w itemconfigure colorbarrgb -fg [ThemeTreeForeground]
+    $w itemconfigure colorbarrgb -bg [ThemeTreeBackground]
+
+    foreach ff $ds9(frames) {
+	$w itemconfigure $ff -fg [ThemeTreeForeground]
+	$w itemconfigure $ff -bg [ThemeTreeBackground]
+    }
+
+    # since graphs are created, but maybe not realized
+    # must update manually
+    ThemeConfigGraph $ds9(graph,horz)
+    ThemeConfigGraph $ds9(graph,vert)
 }
 
 proc InitCanvas {} {
     global ds9
 
     # Bindings
-
     bind $ds9(canvas) <Tab> [list NextFrame]
     bind $ds9(canvas) <Shift-Tab> [list PrevFrame]
     switch $ds9(wm) {
@@ -150,6 +184,8 @@ proc InitCanvas {} {
     }
 
     bind $ds9(canvas) <Configure> [list ConfigureView]
+
+    # keyboard focus
     switch $ds9(wm) {
 	x11 -
 	aqua {
@@ -368,20 +404,8 @@ proc LayoutViewAdjust {varname} {
 	# hh vertical: approx number of numerals to display
 	set hh 7
 
-	# can't trust 'tk scaling'
-	switch $ds9(wm) {
-	    x11 -
-	    win32 {
-		set scaling [tk scaling]
-		if {$scaling == Inf} {
-		    set scaling 1.334
-		}
-	    }
-	    aqua {set scaling 1.4}
-	}
-
 	set icolorbar(horizontal,height) \
-	    [expr int($colorbar(size) + $colorbar(font,size)*$scaling+$ww)]
+	    [expr int($colorbar(size) + $colorbar(font,size)*$ds9(scaling)+$ww)]
 
 	set icolorbar(vertical,width) \
 	    [expr $colorbar(size) + $colorbar(font,size)*$hh]
@@ -462,6 +486,10 @@ proc LayoutOrient {} {
     pack forget $ds9(magnifier)
 
     UpdateView
+    global debug
+    if {$debug(tcl,idletasks)} {
+	puts stderr "LayoutOrient update"
+    }
     update
 
     # restore original canvas size
@@ -661,12 +689,11 @@ proc TileOne {} {
     set xx 0
     set yy 0
 
-    foreach f $ds9(active) {
-	$f configure -x $xx -y $yy -width $ww -height $hh -anchor nw
+    foreach ff $ds9(active) {
+	$ff configure -x $xx -y $yy -width $ww -height $hh -anchor nw
     }
 
     # only show the current frame
-    $current(frame) show
     FrameToFront
 }
 
@@ -774,10 +801,9 @@ proc DisplayDefaultDialog {} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     $w.param.x select range 0 end
     DialogWait $w ed(ok) $w.param.x
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set canvas(width) $ed(x)
