@@ -4,31 +4,29 @@
 
 package provide DS9 1.0
 
-proc MacOSXOpenDocEvent {fc} {
+proc MacOSOpenDocEvent {} {
     global ds9
 
     if {$ds9(event,opendoc) != {}} {
-	foreach f $ds9(event,opendoc) {
+	foreach ff $ds9(event,opendoc) {
 	    MultiLoad
-	    LoadFitsFile $f {} {}
-	    FileLast fitsfbox $f
+	    LoadFitsFile $ff {} {}
+	    FileLast fitsfbox $ff
 	}
 	FinishLoad
     }
 }
 
-proc MacOSXPrintDocEvent {bye} {
+proc MacOSPrintDocEvent {bye} {
     global ds9
 
     if {$ds9(event,printdoc) != {}} {
-	set fc 0
-
-	foreach f $ds9(event,printdoc) {
+	foreach ff $ds9(event,printdoc) {
 	    RealizeDS9
-
+	    
 	    MultiLoad
-	    LoadFitsFile $f {} {}
-	    FileLast fitsfbox $f
+	    LoadFitsFile $ff {} {}
+	    FileLast fitsfbox $ff
 
 	    FinishLoad
 	    PostScript
@@ -41,7 +39,7 @@ proc MacOSXPrintDocEvent {bye} {
 }
 
 proc MacOSXGetLocale {} {
-    return [macosx locale]
+    return [macos locale]
 }
 
 proc MacOSXPrint {} {
@@ -52,7 +50,7 @@ proc MacOSXPrint {} {
 # need the colorbar levels updated
     UpdateColormapLevel
 
-    if {[catch {macosx pm print begin [winfo width $ds9(canvas)] [winfo height $ds9(canvas)] yes}]} {
+    if {[catch {macos pm print begin [winfo width $ds9(canvas)] [winfo height $ds9(canvas)] yes}]} {
 	Error "bad"
     } else {
 	Info "good"
@@ -60,27 +58,27 @@ proc MacOSXPrint {} {
 
     if {0} {
 	foreach f $ds9(frames) {
-	    $f macosx print
+	    $f macos print
 	}
-	colorbar macosx print
-	colorbarrgb macosx print
-	macosx pm print end
+	colorbar macos print
+	colorbarrgb macos print
+	macos pm print end
     }
 }
 
 proc MacOSXPrintPre {} {
     global ds9
 
-    if {[macosx pm print begin [winfo width $ds9(canvas)] [winfo height $ds9(canvas)] no]} {
+    if {[macos pm print begin [winfo width $ds9(canvas)] [winfo height $ds9(canvas)] no]} {
 	foreach f $ds9(frames) {
-	    $f macosx print
+	    $f macos print
 	}
-	colorbar macosx print
-	colorbarrgb macosx print
-	macosx pm print end
+	colorbar macos print
+	colorbarrgb macos print
+	macos pm print end
     }
 }
 
 proc MacOSXPageSetup {} {
-    macosx pm pagesetup
+    macos pm pagesetup
 }
