@@ -15,7 +15,10 @@ proc CreateMagnifier {} {
 			    -borderwidth 2 \
 			    -highlightthickness 0 \
 			    -insertofftime 0 \
-			    -takefocus 0]
+			    -takefocus 0 \
+			    -bg [ThemeTreeBackground] \
+			   ]
+
     $ds9(magnifier) create magnifier$ds9(visual) \
 	-width $imagnifier(size) \
 	-height $imagnifier(size) \
@@ -24,7 +27,19 @@ proc CreateMagnifier {} {
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
 	-times $ds9(times) \
-	-fg $ds9(foreground) -bg $ds9(background)
+	-fg [ThemeTreeForeground] \
+	-bg [ThemeTreeBackground]
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {bind $ds9(magnifier) <<ThemeChanged>> {ThemeConfigMagnifier %W}}
+	aqua {}
+    }
+}
+
+proc ThemeConfigMagnifier {w} {
+    $w configure -bg [ThemeTreeBackground]
+    $w itemconfigure magnifier -bg [ThemeTreeBackground]
 }
 
 proc MagnifierDef {} {
@@ -103,8 +118,8 @@ proc PrefsDialogMagnifier {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Magnifier}]
-    lappend dprefs(tabs) [ttk::frame $w.magnifier]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.magnifier] \
+	-text [msgcat::mc {Magnifier}]
 
     set f [ttk::labelframe $w.magnifier.param -text [msgcat::mc {Magnifier}]]
 
