@@ -15,12 +15,12 @@ proc MarkerDef {} {
     set imarker(motion) none
     set imarker(handle) -1
     set imarker(prefix,dialog) {mkr}
-    set imarker(prefix,plot3d) {plot3d}
-    set imarker(prefix,plot2d) {plot2d}
+    set imarker(prefix,plot3d) {mkrplot3d}
+    set imarker(prefix,plot2d) {mkrplot2d}
     set imarker(prefix,stats) {stats}
-    set imarker(prefix,radial) {radial}
-    set imarker(prefix,panda) {panda}
-    set imarker(prefix,histogram) {hist}
+    set imarker(prefix,radial) {mkrradial}
+    set imarker(prefix,panda) {mkrpanda}
+    set imarker(prefix,histogram) {mkrhist}
 
     set marker(show) 1
     set marker(show,text) 1
@@ -45,6 +45,9 @@ proc MarkerDef {} {
     set marker(font,slant) roman
     set marker(preserve) 0
 
+    set marker(default,use) 0
+    set marker(default,color) green
+
     set marker(plot2d) 0
     set marker(plot3d) 0
     set marker(stats) 0
@@ -850,13 +853,13 @@ proc MarkerDeleteKey {which x y} {
 		}
 	    } else {
 		# delete polygon/segment
-		$which marker delete
+		$which marker delete select
 		UpdateGroupDialog
 	    }
 	}
 	default {
 	    # delete marker
-	    $which marker delete
+	    $which marker delete select
 	    UpdateGroupDialog
 	}
     }
@@ -980,34 +983,24 @@ proc MarkerSelectInvert {} {
     UpdateEditMenu
 }
 
-proc MarkerDeleteSelect {} {
-    global current
-    
-    if {$current(frame) != {}} {
-	$current(frame) marker delete
-	UpdateGroupDialog
-    }
-
-    UpdateEditMenu
-}
-
-proc MarkerDeleteAllMenu {} {
-    global current
+proc MarkerDelete {select} {
     global pds9
 
     if {$pds9(confirm)} {
-	if {[tk_messageBox -type okcancel -icon question -message [msgcat::mc {Delete All Regions?}]] != {ok}} {
-	    return
+	if {[tk_messageBox -type okcancel -icon question -message [msgcat::mc {Delete Regions?}]] != {ok}} {
+	    return 0
 	}
     }
-    MarkerDeleteAll
+
+    MarkerDeleteSelect $select
+    return 1
 }
 
-proc MarkerDeleteAll {} {
+proc MarkerDeleteSelect {select} {
     global current
     
     if {$current(frame) != {}} {
-	$current(frame) marker delete all
+	$current(frame) marker delete $select
 	UpdateGroupDialog
     }
 
@@ -1015,15 +1008,9 @@ proc MarkerDeleteAll {} {
 }
 
 proc MarkerDeleteLoad {} {
-    global pds9
-
-    if {$pds9(confirm)} {
-	if {[tk_messageBox -type okcancel -icon question -message [msgcat::mc {Delete All Regions?}]] != {ok}} {
-	    return
-	}
+    if {[MarkerDelete {}]} {
+	MarkerLoad
     }
-    MarkerDeleteAll
-    MarkerLoad
 }
 
 proc MarkerColor {} {
@@ -1062,7 +1049,7 @@ proc MarkerFont {} {
     }
 }
 
-proc MarkerList {} {
+proc MarkerList {select} {
     global current
     global marker
 
@@ -1075,7 +1062,8 @@ proc MarkerList {} {
 
     if {[MarkerSaveDialog [msgcat::mc {List Regions}]]} {
 	SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
-	    [$current(frame) marker list $marker(format) $marker(system) \
+	    [$current(frame) marker list $select \
+		 $marker(format) $marker(system) \
 		 $marker(sky) $marker(skyformat) $marker(strip)]
     }
 }
@@ -1182,7 +1170,7 @@ proc MarkerLoadFile {filename which format sys sky} {
     if {$ll == "SIMPLE  ="} {
 	# ok, its fits
 	# try filename first
-	if {[catch {$which marker load fits "\{$filename\}" $marker(color) $marker(dashlist) $marker(width) "\{$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\}"}]} {
+	if {[catch {$which marker load fits "\{$filename\}" $marker(default,color)}]} {
 
 	    # reset errorInfo
 	    set errorInfo {}
@@ -1192,14 +1180,14 @@ proc MarkerLoadFile {filename which format sys sky} {
 	    if {$ext == {}} {
 		set regfilename "$base\[REGION\]"
 
-		if {[catch {$which marker load fits "\{$regfilename\}" $marker(color) $marker(dashlist) $marker(width) "\{$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\}"}]} {
+		if {[catch {$which marker load fits "\{$regfilename\}" $marker(default,color)}]} {
 
 		    # reset errorInfo
 		    set errorInfo {}
 
 		    # ok now try the first extension
 		    set regfilename "$base\[1\]"
-		    if {[catch {$which marker load fits "\{$regfilename\}" $marker(color) $marker(dashlist) $marker(width) "\{$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\}"}]} {
+		    if {[catch {$which marker load fits "\{$regfilename\}" $marker(default,color)}]} {
 			Error "[msgcat::mc {Unable to load region file}] $filename"
 			return -code error
 		    }
@@ -1211,7 +1199,7 @@ proc MarkerLoadFile {filename which format sys sky} {
 	}
     } else {
 	# no, its ascii
-	if {[catch {$which marker load $format "\{$filename\}" $sys $sky}]} {
+	if {[catch {$which marker load $format "\{$filename\}" $marker(default,use) $marker(default,color) $sys $sky}]} {
 	    Error "[msgcat::mc {Unable to load region file}] $filename"
 	    return -code error
 	}
@@ -1224,7 +1212,7 @@ proc MarkerLoadFile {filename which format sys sky} {
     UpdateGroupDialog
 }
 
-proc MarkerSave {} {
+proc MarkerSave {select} {
     global current
     global marker
 
@@ -1241,7 +1229,7 @@ proc MarkerSave {} {
     }
 
     if {[MarkerSaveDialog [msgcat::mc {Save Regions}]]} {
-	$current(frame) marker save "\{$filename\}" \
+	$current(frame) marker save $select "\{$filename\}" \
 	    $marker(format) $marker(system) $marker(sky) \
 	    $marker(skyformat) $marker(strip)
     }
@@ -1476,7 +1464,8 @@ proc RegionCmdLoad {} {
 	# xpa path
 	# fits regions files not supported  
 	$current(frame) marker load $marker(load,format) \
-	    $parse(sock) $marker(load,system) $marker(load,sky)
+	    $parse(sock) $marker(default,use) $marker(default,color) \
+	    $marker(load,system) $marker(load,sky)
 	UpdateGroupDialog
     } elseif {$parse(fn) != {}} {
 	# samp path
@@ -1499,7 +1488,7 @@ proc RegionCmdLoadFn {fn {all {0}}} {
 	$marker(load,format) $marker(load,system) $marker(load,sky)
 }
 
-proc RegionCmdSave {fn} {
+proc RegionCmdSave {fn select} {
     global marker
     global current
 
@@ -1510,12 +1499,12 @@ proc RegionCmdSave {fn} {
 	return
     }
 
-    $current(frame) marker save $fn $marker(format) \
+    $current(frame) marker save $select $fn $marker(format) \
 	$marker(system) $marker(sky) $marker(skyformat) $marker(strip)
     FileLast markerfbox $fn
 }
 
-proc RegionCmdList {} {
+proc RegionCmdList {select} {
     global marker
     global current
 
@@ -1527,7 +1516,7 @@ proc RegionCmdList {} {
     }
 
     SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
-	[$current(frame) marker list $marker(format) $marker(system) \
+	[$current(frame) marker list $select $marker(format) $marker(system) \
 	     $marker(sky) $marker(skyformat) $marker(strip)]
 }
 
