@@ -80,14 +80,14 @@ proc MarkerAnalysisHistogramCB {frame id} {
 	if {$bunit=={}} {
 	    set bunit {Values}
 	}
-	PlotDialog $vvarname [string totitle [$frame get marker $id type]]
+	PlotDialog $vvarname [string totitle [$frame get marker $id type]] true
 	PlotAddGraph $vvarname line
 	PlotTitle $vvarname Histogram $bunit Counts
 
 	set vvar(graph,ds,xdata) $xdata
 	set vvar(graph,ds,ydata) $ydata
-	set vvar(graph,ds,smooth) step
-	set vvar(graph,ds,fill) 1
+	set vvar(graph,ds,line,smooth) step
+	set vvar(graph,ds,line,fill) 1
 	PlotExternal $vvarname xy
     }
 
