@@ -30,7 +30,7 @@ proc MarkerAnalysisPlot2dDialog {varname} {
 	-label [msgcat::mc {Method}] \
 	-menu $var(mb).analysis.method
 
-    menu $var(mb).analysis.method
+    ThemeMenu $var(mb).analysis.method
     $var(mb).analysis.method add radiobutton \
 	-label [msgcat::mc {Average}] \
 	-variable ${varname}(method) -value average \
@@ -128,6 +128,7 @@ proc MarkerAnalysisPlot2dCB {frame id} {
     } elseif {[info exists vvar(system)]} {
     } else {
 	set vvar(system) $wcs(system)
+	AdjustCoordSystem $vvarname system
     }
 
     if {[info exists var(sky)]} {
@@ -165,7 +166,7 @@ proc MarkerAnalysisPlot2dCB {frame id} {
 	if {$vvar(bunit)=={}} {
 	    set vvar(bunit) {Counts}
 	}
-	PlotDialog $vvarname [string totitle [$frame get marker $id type]]
+	PlotDialog $vvarname [string totitle [$frame get marker $id type]] true
 	PlotAddGraph $vvarname line
 
 	MarkerAnalysisPlot2dAxisTitle $vvarname
