@@ -19,6 +19,7 @@ proc MaskDef {} {
     set mask(mark) nonzero
     set mask(low) 0
     set mask(high) 0
+    set mask(blend) screen
 
     array set pmask [array get mask]
 }
@@ -34,6 +35,15 @@ proc MaskMark {} {
     }
 }
 
+proc MaskBlend {} {
+    global mask
+    global current
+
+    if {$current(frame) != {}} {
+	$current(frame) mask blend $mask(blend)
+    }
+}
+
 proc MaskRange {} {
     global mask
     global current
@@ -100,11 +110,12 @@ proc MaskDialog {} {
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
     $mb add cascade -label [msgcat::mc {Align}] -menu $mb.align
+    $mb add cascade -label [msgcat::mc {Blend}] -menu $mb.blend
 
-    menu $mb.file
-    $mb.file add command -label "[msgcat::mc {Load}]..." \
-	-command [list OpenDialog fits mask]
-    $mb.file add cascade -label [msgcat::mc {Load as}] \
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command [list OpenDialog fits mask] -accelerator "${ds9(ctrl)}O"
+    $mb.file add cascade -label [msgcat::mc {Open as}] \
 	-menu $mb.file.open
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {Import}] \
@@ -113,9 +124,10 @@ proc MaskDialog {} {
     $mb.file add command -label [msgcat::mc {Apply}] -command MaskApplyDialog
     $mb.file add command -label [msgcat::mc {Clear}] -command MaskClear
     $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command MaskDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command MaskDestroyDialog -accelerator "${ds9(ctrl)}W"
 
-    menu $mb.file.open
+    ThemeMenu $mb.file.open
     $mb.file.open add command -label "[msgcat::mc {Mosaic WCS}]..." \
 	-command [list OpenDialog mosaicimagewcs mask]
     $mb.file.open add command -label "[msgcat::mc {Mosaic WCS Segment}]..." \
@@ -127,7 +139,7 @@ proc MaskDialog {} {
     $mb.file.open add command -label "[msgcat::mc {Mosaic WFPC2}]..." \
 	-command [list OpenDialog mosaicimagewfpc2 mask]
 
-    menu $mb.file.import
+    ThemeMenu $mb.file.import
     $mb.file.import add command -label "[msgcat::mc {Array}]..." \
 	-command [list ImportDialog array mask]
     $mb.file.import add command -label {NRRD} \
@@ -137,6 +149,16 @@ proc MaskDialog {} {
 
     CoordMenu $mb.align mask system 1 {} {} MaskSystem
 
+    ThemeMenu $mb.blend
+    $mb.blend add radiobutton -label [msgcat::mc {Source}] \
+	-variable mask(blend) -value source -command MaskBlend
+    $mb.blend add radiobutton -label [msgcat::mc {Screen}] \
+	-variable mask(blend) -value screen -command MaskBlend
+    $mb.blend add radiobutton -label [msgcat::mc {Darken}] \
+	-variable mask(blend) -value darken -command MaskBlend
+    $mb.blend add radiobutton -label [msgcat::mc {Lighten}] \
+	-variable mask(blend) -value lighten -command MaskBlend
+
     # Param
     set f [ttk::frame $w.param]
 
@@ -157,6 +179,9 @@ proc MaskDialog {} {
     ttk::separator $w.sep -orient horizontal
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
+
+    bind $w <<Open>> [list OpenDialog fits mask]
+    bind $w <<Close>> MaskDestroyDialog
 }
 
 proc MaskApplyDialog {} {
@@ -193,6 +218,7 @@ proc UpdateMaskMenu {} {
 
     set mask(color) [$current(frame) get mask color]
     set mask(mark) [$current(frame) get mask mark]
+    set mask(blend) [$current(frame) get mask blend]
     set range [$current(frame) get mask range]
     set mask(low) [lindex $range 0]
     set mask(high) [lindex $range 1]
@@ -227,42 +253,42 @@ proc MaskLoad {} {
 
 proc MaskParamsDialog {} {
     global mask
-    global ed
+    global ed2
 
     set w {.mskd}
 
-    set ed(ok) 0
-    set ed(color) $mask(color)
-    set ed(mark) $mask(mark)
-    set ed(low) $mask(low)
-    set ed(high) $mask(high)
+    set ed2(ok) 0
+    set ed2(color) $mask(color)
+    set ed2(mark) $mask(mark)
+    set ed2(low) $mask(low)
+    set ed2(high) $mask(high)
 
-    DialogCreate $w [msgcat::mc {Mask Parameters}] ed(ok)
+    DialogCreate $w [msgcat::mc {Mask Parameters}] ed2(ok)
 
     # Param
     set f [ttk::frame $w.param]
 
     ttk::label $f.colortitle -text [msgcat::mc {Color}]
-    ColorMenuButton $f.colorbutton ed color {}
+    ColorMenuButton $f.colorbutton ed2 color {}
 
     ttk::label $f.marktitle -text [msgcat::mc {Block Pixel}]
     set mb $f.markbutton.menu
-    ttk::menubutton $f.markbutton -textvariable ed(mark) -menu $mb
-    menu $mb
+    ttk::menubutton $f.markbutton -textvariable ed2(mark) -menu $mb
+    ThemeMenu $mb
     $mb add radiobutton -label [msgcat::mc {Zero}] \
-	-variable ed(mark) -value zero
+	-variable ed2(mark) -value zero
     $mb add radiobutton -label [msgcat::mc {Non-Zero}] \
-	-variable ed(mark) -value nonzero
+	-variable ed2(mark) -value nonzero
     $mb add radiobutton -label [msgcat::mc {NAN}] \
-	-variable ed(mark) -value nan
+	-variable ed2(mark) -value nan
     $mb add radiobutton -label [msgcat::mc {Non-NAN}] \
-	-variable ed(mark) -value nonnan
+	-variable ed2(mark) -value nonnan
     $mb add radiobutton -label [msgcat::mc {Range}] \
-	-variable ed(mark) -value range
+	-variable ed2(mark) -value range
 
     ttk::label $f.rangetitle -text [msgcat::mc {Range}]
-    ttk::entry $f.low -textvariable ed(low) -width 13
-    ttk::entry $f.high -textvariable ed(high) -width 13
+    ttk::entry $f.low -textvariable ed2(low) -width 13
+    ttk::entry $f.high -textvariable ed2(high) -width 13
 
     grid $f.colortitle $f.colorbutton -padx 2 -pady 2 -sticky w
     grid $f.marktitle $f.markbutton -padx 2 -pady 2 -sticky w
@@ -270,31 +296,30 @@ proc MaskParamsDialog {} {
 
     # Buttons
     set f [ttk::frame $w.buttons]
-    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
+    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed2(ok) 1} \
 	-default active 
-    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
+    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed2(ok) 0}
     pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
 
-    bind $w <Return> {set ed(ok) 1}
+    bind $w <Return> {set ed2(ok) 1}
 
     # Fini
     ttk::separator $w.sep -orient horizontal
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
-    DialogWait $w ed(ok)
-    DialogDismiss $w
+    DialogWait $w ed2(ok)
+    destroy $w
 
-    if {$ed(ok)} {
-	set mask(color) [string tolower $ed(color)]
-	set mask(mark) $ed(mark)
-	set mask(low) $ed(low)
-	set mask(high) $ed(high)
+    if {$ed2(ok)} {
+	set mask(color) [string tolower $ed2(color)]
+	set mask(mark) $ed2(mark)
+	set mask(low) $ed2(low)
+	set mask(high) $ed2(high)
     }
 
-    set rr $ed(ok)
-    unset ed
+    set rr $ed2(ok)
+    unset ed2
     return $rr
 }
 
