@@ -10,7 +10,7 @@ proc EditMainMenu {} {
     global ds9
     global current
 
-    menu $ds9(mb).edit
+    ThemeMenu $ds9(mb).edit
     $ds9(mb).edit add command -label [msgcat::mc {Undo}] -command UndoFrame \
 	-accelerator "${ds9(ctrl)}Z"
     $ds9(mb).edit add separator
@@ -22,9 +22,11 @@ proc EditMainMenu {} {
 	-accelerator "${ds9(ctrl)}V"
     $ds9(mb).edit add separator
     $ds9(mb).edit add radiobutton -label [msgcat::mc {None}] \
-	-variable current(mode) -value none -command ChangeMode
+	-variable current(mode) -value none -command ChangeMode \
+	-accelerator "${ds9(ctrl)}N"
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Region}] \
-	-variable current(mode) -value region -command ChangeMode
+	-variable current(mode) -value region -command ChangeMode \
+	-accelerator "${ds9(ctrl)}R"
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Crosshair}] \
 	-variable current(mode) -value crosshair -command ChangeMode
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Colorbar}] \
@@ -39,6 +41,8 @@ proc EditMainMenu {} {
 	-variable current(mode) -value crop -command ChangeMode
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Catalog}] \
 	-variable current(mode) -value catalog -command ChangeMode
+    $ds9(mb).edit add radiobutton -label [msgcat::mc {Footprint}] \
+	-variable current(mode) -value footprint -command ChangeMode
     $ds9(mb).edit add radiobutton -label [msgcat::mc {Examine}] \
 	-variable current(mode) -value examine -command ChangeMode
     $ds9(mb).edit add radiobutton -label [msgcat::mc {3D}] \
@@ -49,7 +53,8 @@ proc EditMainMenu {} {
 	win32 {
 	    $ds9(mb).edit add separator
 	    $ds9(mb).edit add command -label "[msgcat::mc {Preferences}]..." \
-		-command PrefsDialog
+		-command PrefsDialog -accelerator "${ds9(ctrl)},"
+
 	}
 	aqua {}
     }
@@ -59,6 +64,15 @@ proc EditMainMenu {} {
     bind $ds9(top) <<Cut>> CutFrame
     bind $ds9(top) <<Copy>> CopyFrame
     bind $ds9(top) <<Paste>> PasteFrame
+
+    bind $ds9(top) <<None>>  [list ChangeModeItem none]
+    bind $ds9(top) <<Region>> [list ChangeModeItem region]
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {bind $ds9(top) <<Pref>> PrefsDialog}
+	aqua {}
+    }
 }
 
 proc PrefsDialogEditMenu {w} {
@@ -72,7 +86,7 @@ proc PrefsDialogEditMenu {w} {
     grid $f.menu $f.buttonbar -padx 2 -pady 2
 
     set m $f.menu.menu
-    menu $m
+    ThemeMenu $m
     $m add radiobutton -label [msgcat::mc {None}] \
 	-variable pcurrent(mode) -value none
     $m add radiobutton -label [msgcat::mc {Region}] \
@@ -91,6 +105,8 @@ proc PrefsDialogEditMenu {w} {
 	-variable pcurrent(mode) -value crop
     $m add radiobutton -label [msgcat::mc {Catalog}] \
 	-variable pcurrent(mode) -value catalog
+    $m add radiobutton -label [msgcat::mc {Footprint}] \
+	-variable pcurrent(mode) -value footprint
     $m add radiobutton -label [msgcat::mc {Examine}] \
 	-variable pcurrent(mode) -value examine
     $m add radiobutton -label [msgcat::mc {3D}] \
@@ -118,6 +134,7 @@ proc ButtonsEditDef {} {
 	edit,rotate 1
 	edit,crop 1
 	edit,catalog 1
+	edit,footprint 1
 	edit,examine 1
 	edit,3d 1
 	edit,prefs 0
@@ -167,6 +184,9 @@ proc CreateButtonsEdit {} {
     RadioButton $ds9(buttons).edit.catalog \
 	[string tolower [msgcat::mc {Cat}]] \
 	current(mode) catalog ChangeMode
+    RadioButton $ds9(buttons).edit.footprint \
+        [string tolower [msgcat::mc {FP}]] \
+        current(mode) footprint ChangeMode
     RadioButton $ds9(buttons).edit.examine \
 	[string tolower [msgcat::mc {Exam}]] \
 	current(mode) examine ChangeMode
@@ -191,6 +211,7 @@ proc CreateButtonsEdit {} {
         $ds9(buttons).edit.rotate pbuttons(edit,rotate)
         $ds9(buttons).edit.crop pbuttons(edit,crop)
         $ds9(buttons).edit.catalog pbuttons(edit,catalog)
+        $ds9(buttons).edit.footprint pbuttons(edit,footprint)                   
         $ds9(buttons).edit.examine pbuttons(edit,examine)
         $ds9(buttons).edit.3d pbuttons(edit,3d)
         $ds9(buttons).edit.prefs pbuttons(edit,prefs)
@@ -205,7 +226,7 @@ proc PrefsDialogButtonbarEdit {f} {
     ttk::menubutton $f -text [msgcat::mc {Buttonbar}] -menu $f.menu
     
     set m $f.menu
-    menu $m
+    ThemeMenu $m
     $m add checkbutton -label [msgcat::mc {Undo}] \
 	-variable pbuttons(edit,undo) -command {UpdateButtons buttons(edit)}
     $m add separator
@@ -234,6 +255,8 @@ proc PrefsDialogButtonbarEdit {f} {
 	-variable pbuttons(edit,crop) -command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Catalog}] \
 	-variable pbuttons(edit,catalog) -command {UpdateButtons buttons(edit)}
+    $m add checkbutton -label [msgcat::mc {Footprint}] \
+	-variable pbuttons(edit,footprint) -command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {Examine}] \
 	-variable pbuttons(edit,examine) -command {UpdateButtons buttons(edit)}
     $m add checkbutton -label [msgcat::mc {3D}] \
@@ -307,6 +330,7 @@ proc UpdateEditMenu {} {
 	rotate -
 	crop -
 	catalog -
+	footprint -
 	examine -
 	iexam -
 	3d {$ds9(mb).edit entryconfig [msgcat::mc {Undo}] -state disabled}
