@@ -8,8 +8,12 @@ proc CreateMenuBar {} {
     global ds9
 
     # we need this first, before the configure command
-    menu $ds9(mb) 
-    AppleMenu $ds9(mb)
+    ThemeMenu $ds9(mb) 
+    switch $ds9(wm) {
+	x11 -
+	win32 {}
+	aqua {AppleMenu $ds9(mb)}
+    }
     $ds9(top) configure -menu $ds9(mb)
 
     $ds9(mb) add cascade -label [msgcat::mc {File}] -menu $ds9(mb).file
@@ -36,36 +40,206 @@ proc CreateMenuBar {} {
     WCSMainMenu
     AnalysisMainMenu
     HelpMainMenu
-}
-
-proc AppleMenu {mb} {
-    global ds9
 
     switch $ds9(wm) {
 	x11 -
-	win32 {}
-	aqua {
-	    # apple menu
-	    menu $mb.apple
-	    $mb add cascade -menu $mb.apple
-	    $mb.apple add command \
-		-label [msgcat::mc {About SAOImageDS9}] \
-		-command AboutBox
-#		-command ::tk::mac::standardAboutPanel
+	win32 {
+	    bind TFrame <<ThemeChanged>> {ThemeConfigTFrame %W}
+
+	    bind Menu <<ThemeChanged>> {ThemeConfigMenu %W}
+	    bind Text <<ThemeChanged>> {ThemeConfigText %W}
+	    bind Table <<ThemeChanged>> {ThemeConfigTable %W}
+	    bind Graph <<ThemeChanged>> {ThemeConfigPlot %W}
+	    bind Barchart <<ThemeChanged>> {ThemeConfigPlot %W}
+
+	    # for Obsvis
+	    bind Frame <<ThemeChanged>> {ThemeConfigBg %W}
+	    bind Labelframe <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Panedwindow <<ThemeChanged>> {ThemeConfigBg %W}
+	    bind Label <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Entry <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Button <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Radiobutton <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Checkbutton <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Menubutton <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Listbox <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Spinbox <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Scale <<ThemeChanged>> {ThemeConfigFgBg %W}
+	    bind Scrollbar <<ThemeChanged>> {ThemeConfigBg %W}
 	}
+	aqua {}
     }
 }
 
+proc ThemeMenu {w} {
+    global ds9
+
+    menu $w
+    switch $ds9(wm) {
+	x11 -
+	win32 {ThemeConfigMenu $w}
+	aqua {}
+    }
+
+    return $w
+}
+
+proc ThemeConfigFgBg {w} {
+    $w configure -fg [ThemeForeground]
+    $w configure -bg [ThemeBackground]
+}
+
+proc ThemeConfigBg {w} {
+    $w configure -bg [ThemeBackground]
+}
+
+proc ThemeConfigText {w} {
+    $w configure -fg [ThemeTreeForeground]
+    $w configure -bg [ThemeTreeBackground]
+
+    # create a special text tag for keywords
+    $w tag configure keyword -foreground [ThemeBold]
+}
+
+proc ThemeConfigTable {w} {
+    $w configure -fg [ThemeTreeForeground]
+    $w configure -bg [ThemeTreeBackground]
+
+    $w tag configure sel \
+	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
+    $w tag configure title -fg [ThemeForeground] -bg [ThemeBackground]
+
+    # pixel table
+    $w tag configure coord -foreground [ThemeBold]
+}
+
+proc ThemeConfigPlot {w} {
+    set varname [lindex [split $w {.}] 1]
+    if {$varname != {}} {
+	PlotUpdateAllElement $varname
+    }
+}
+
+# Theme Style Colors
+
+proc ThemeConfigTFrame {w} {
+    ttk::style configure Tree.TFrame -background \
+	[ttk::style lookup Treeview -background]
+}
+
+proc ThemeConfigMenu {w} {
+    global ds9
+
+    $w configure -fg [ttk::style lookup . -foreground]
+    $w configure -bg [ttk::style lookup . -background]
+
+    $w configure -selectcolor [ttk::style lookup . -foreground]
+
+    $w configure -activeforeground \
+	[ttk::style lookup TMenubutton -foreground active]
+    $w configure -activebackground \
+	[ttk::style lookup TMenubutton -background active]
+}
+
+proc ThemeChange {} {
+    global ds9
+    global pds9
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {ttk::style theme use $pds9(theme)}
+	aqua {}
+    }
+}
+
+proc ThemeForeground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup . -foreground]}
+	aqua {return systemTextColor}
+    }
+}
+
+proc ThemeBackground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup . -background]}
+	aqua {return systemTextBackgroundColor}
+    }
+}
+
+proc ThemeTreeForeground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup Treeview -foreground]}
+	aqua {return systemTextColor}
+    }
+}
+
+proc ThemeTreeBackground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup Treeview -background]}
+	aqua {return systemTextBackgroundColor}
+    }
+}
+
+proc ThemeSelectedForeground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup Treeview -foreground selected]}
+	aqua {return systemTextBackgroundColor}
+    }
+}
+
+proc ThemeSelectedBackground {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup Treeview -background selected]}
+	aqua {return systemControlAccentColor}
+    }
+}
+
+proc ThemeBold {} {
+    global ds9
+    
+    switch $ds9(wm) {
+	x11 -
+	win32 {return [ttk::style lookup Treeview -background selected]}
+	aqua {return systemControlAccentColor}
+    }
+}
+
+proc AppleMenu {mb} {
+    # apple menu
+    ThemeMenu $mb.apple
+    $mb add cascade -menu $mb.apple
+    $mb.apple add command -label [msgcat::mc {About SAOImageDS9}] \
+	-command AboutBox
+}
+
 # CoordMenu
 proc CoordMenu {w varname system other sky skyformat cmd} {
     upvar #0 $varname var
     global $varname
 
-    menu $w
+    ThemeMenu $w
     $w add radiobutton -label [msgcat::mc {WCS}] \
 	-variable ${varname}($system) -value wcs -command $cmd
     $w add cascade -label [msgcat::mc {Multiple WCS}] -menu $w.wcs
-    menu $w.wcs 
+    ThemeMenu $w.wcs
     foreach l {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	$w.wcs add radiobutton -label "[msgcat::mc {WCS}] $l" \
 	    -variable ${varname}($system) -value "wcs$l" -command $cmd
@@ -238,12 +412,12 @@ proc DistMenu {w varname system other format cmd} {
     upvar #0 $varname var
     global $varname
 
-    menu $w 
+    ThemeMenu $w
     $w add radiobutton -label [msgcat::mc {WCS}] \
 	-variable ${varname}($system) -value wcs -command $cmd
     $w add cascade -label [msgcat::mc {Multiple WCS}] \
 	-menu $w.wcs
-    menu $w.wcs 
+    ThemeMenu $w.wcs
     foreach l {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	$w.wcs add radiobutton -label "[msgcat::mc {WCS}] $l" \
 	    -variable ${varname}($system) -value "wcs$l" -command $cmd
@@ -376,7 +550,7 @@ proc EditMenu {mb varname} {
     global $varname
     global ds9
 
-    menu $mb.edit
+    ThemeMenu $mb.edit
     $mb.edit add command -label [msgcat::mc {Cut}] \
 	-command "EntryCut $var(top)" -accelerator "${ds9(ctrl)}X"
     $mb.edit add command -label [msgcat::mc {Copy}] \
@@ -390,7 +564,7 @@ proc ColorMenu {w varname color cmd} {
     upvar #0 $varname var
     global $varname
 
-    menu $w
+    ThemeMenu $w
     $w add radiobutton -label [msgcat::mc {Black}] \
 	-variable ${varname}($color) -value black -command $cmd
     $w add radiobutton -label [msgcat::mc {White}] \
@@ -434,7 +608,7 @@ proc FontMenu {w varname font size weight slant cmd} {
     upvar #0 $varname var
     global $varname
 
-    menu $w
+    ThemeMenu $w
     $w add radiobutton -label {Times} -variable ${varname}($font) \
 	-value times -command $cmd
     $w add radiobutton -label {Helvetica} -variable ${varname}($font) \
@@ -499,7 +673,7 @@ proc WidthDashMenu {w varname width dash cmd1 cmd2} {
     upvar #0 $varname var
     global $varname
 
-    menu $w
+    ThemeMenu $w
     $w add radiobutton -label {1} -variable ${varname}($width) \
 	-value 1 -command $cmd1
     $w add radiobutton -label {2} -variable ${varname}($width) \
@@ -530,8 +704,8 @@ proc PrefsDialogMenu {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Menus and Buttons}]
-    lappend dprefs(tabs) [ttk::frame $w.menu]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.menu] \
+	-text [msgcat::mc {Menus and Buttons}]
 
     PrefsDialogFileMenu $w.menu
     PrefsDialogEditMenu $w.menu
