@@ -15,6 +15,8 @@ proc MovieDef {} {
 
     set movie(type) gif
     set movie(action) slice
+    set movie(delay) 0
+
     set movie(num) 24
     set movie(az,from) 45
     set movie(az,to) -45
@@ -22,16 +24,20 @@ proc MovieDef {} {
     set movie(el,to) 30
     set movie(sl,from) 1
     set movie(sl,to) 1
+    set movie(zm,from) 1
+    set movie(zm,to) 1
     set movie(repeat) oscillate
     set movie(repeat,num) 0
 
     set movie(status) 0
     set movie(abort) 0
+    set movie(first) 0
 
     set movie(error) [msgcat::mc {An error has occurred while creating the image. Please be sure that the ds9 window is in the upper left corner of the default screen and the entire window is visible.}]
 }
 
 proc MovieDialog {} {
+    global imovie
     global movie
     global mpegfbox
     global giffbox
@@ -41,8 +47,9 @@ proc MovieDialog {} {
     set w {.movie}
 
     set ed(ok) 0
-    set ed(action) $movie(action)
     set ed(type) $movie(type)
+    set ed(action) $movie(action)
+    set ed(delay) $movie(delay)
 
     DialogCreate $w [msgcat::mc {Create Movie}] ed(ok)
 
@@ -79,6 +86,14 @@ proc MovieDialog {} {
 	3d {$f.3d configure -state normal}
     }
 
+    # Param
+    set f [ttk::labelframe $w.delay -text [msgcat::mc {Delay}]]
+
+    ttk::entry $f.delay -textvariable ed(delay) -width 7
+    ttk::label $f.tdelay -text [msgcat::mc {hundredths second}]
+
+    grid $f.delay $f.tdelay -padx 2 -pady 2 -sticky w
+
     # Buttons
     set f [ttk::frame $w.buttons]
     ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
@@ -91,19 +106,20 @@ proc MovieDialog {} {
     # Fini
     grid $w.type -sticky news
     grid $w.param -sticky news
+    grid $w.delay -sticky news
     grid $w.buttons -sticky ew
     grid rowconfigure $w 0 -weight 1
     grid rowconfigure $w 1 -weight 1
     grid columnconfigure $w 0 -weight 1
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set movie(action) $ed(action)
 	set movie(type) $ed(type)
-
+	set movie(delay) $ed(delay)
+	
 	switch $movie(type) {
 	    mpeg {set fn [SaveFileDialog mpegfbox]}
 	    gif {set fn [SaveFileDialog giffbox]}
@@ -134,24 +150,17 @@ proc MovieCreate {fn} {
     global current
     global saveimage
 
-    if {$fn == {} || ![$current(frame) has fits]} {
+    if {$fn == {}} {
 	return
     }
+    set movie(fn) $fn
 
     # besure we are on top
     raise $ds9(top)
 
-    # we need single mode
-    if {$ds9(display) != {single}} {
-	set modesav $ds9(display)
-	set current(display) single
-	DisplayMode
-    }
-
     # for darwin only
     set geom [MacOSPhotoFix $ds9(top) 0 1]
 
-    set movie(fn) $fn
     switch $movie(action) {
 	frame {MovieFrame}
 	slice {MovieSlice}
@@ -164,11 +173,6 @@ proc MovieCreate {fn} {
 	gif {agif close}
     }
 
-    if {[info exists modesav]} {
-	set current(display) $modesav
-	DisplayMode
-    }
-
     # reset if needed
     DarwinPhotoRestore $ds9(top) $geom
 }
@@ -178,6 +182,13 @@ proc MovieFrame {} {
     global current
     global movie
 
+    # we need single mode
+    if {$ds9(display) != {single}} {
+	set modesav $ds9(display)
+	set current(display) single
+	DisplayMode
+    }
+
     # loop thru all active frames
     set movie(first) 1
     set framesav $current(frame)
@@ -192,12 +203,25 @@ proc MovieFrame {} {
 
     set ds9(next) $framesav
     GotoFrame
+
+    if {[info exists modesav]} {
+	set current(display) $modesav
+	DisplayMode
+    }
 }
 
 proc MovieSlice {} {
+    global ds9
     global current
     global movie
 
+    # we need single mode
+    if {$ds9(display) != {single}} {
+	set modesav $ds9(display)
+	set current(display) single
+	DisplayMode
+    }
+
     set depth [$current(frame) get fits depth]
     set slice [$current(frame) get fits slice]
 
@@ -216,18 +240,48 @@ proc MovieSlice {} {
 
     # reset current slice
     $current(frame) update fits slice $slice
+
+    if {[info exists modesav]} {
+	set current(display) $modesav
+	DisplayMode
+    }
 }
 
 proc Movie3d {} {
+    global ds9
     global movie
     global current
 
-    set slice [$current(frame) get fits slice]
-    set vp [$current(frame) get 3d view]
+    # we need single or tile mode
+    if {$ds9(display) == {blink}} {
+	set modesav $ds9(display)
+	set current(display) single
+	DisplayMode
+    }
+
+    switch $ds9(display) {
+	single {
+	    set zoom [$current(frame) get zoom]
+	    set slice [$current(frame) get fits slice]
+	    set vp [$current(frame) get 3d view]
+	}
+	tile {
+	    $current(frame) highlite off
+	    foreach ff $ds9(active) {
+		set zoom($ff) [$ff get zoom]
+		set slice($ff) [$ff get fits slice]
+		set vp($ff) [$ff get 3d view]
+	    }
+	}
+	blink {
+	    # should not be here
+	}
+    }
 
     set azincr [expr 1.*($movie(az,to)-$movie(az,from))/$movie(num)]
     set elincr [expr 1.*($movie(el,to)-$movie(el,from))/$movie(num)]
     set slincr [expr 1.*($movie(sl,to)-$movie(sl,from))/$movie(num)]
+    set zmincr [expr 1.*($movie(zm,to)-$movie(zm,from))/$movie(num)]
 
     # loop over az/el/slice
     set movie(status) 0
@@ -237,6 +291,7 @@ proc Movie3d {} {
     set az $movie(az,from)
     set el $movie(el,from)
     set sl $movie(sl,from)
+    set zm $movie(zm,from)
 
     for {set rr 0} {$rr<=$movie(repeat,num)} {incr rr} {
 	for {set nn 0} {$nn<=$movie(num)} {incr nn} {
@@ -246,27 +301,52 @@ proc Movie3d {} {
 		break
 	    }
 	    set movie(status) [expr 1.*$nn/$movie(num)*100]
+
+	    global debug
+	    if {$debug(tcl,idletasks)} {
+		puts stderr "Movie3d"
+	    }
 	    update idletasks
 
-	    $current(frame) 3d view $az $el
-	    $current(frame) update fits slice [expr int($sl)]
+	    switch $ds9(display) {
+		single {
+		    $current(frame) zoom to $zm $zm
+		    $current(frame) 3d view $az $el
+		    $current(frame) update fits slice [expr int($sl)]
+		}
+		tile {
+		    foreach ff $ds9(active) {
+			$ff zoom to $zm $zm
+			$ff 3d view $az $el
+			$ff update fits slice [expr int($sl)]
+		    }
+		}
+		blink {
+		    # should not be here
+		}
+	    }
+
 	    if {[MoviePhoto]} {
 		break
 	    }
+
 	    set az [expr $az+$azincr]
 	    set el [expr $el+$elincr]
 	    set sl [expr $sl+$slincr]
+	    set zm [expr $zm+$zmincr]
 	}
 	switch $movie(repeat) {
 	    repeat {
 		set az $movie(az,from)
 		set el $movie(el,from)
 		set sl $movie(sl,from)
+		set zm $movie(zm,from)
 	    }
 	    oscillate {
 		set azincr [expr -$azincr]
 		set elincr [expr -$elincr]
 		set slincr [expr -$slincr]
+		set zmincr [expr -$zmincr]
 	    }
 	}
     }
@@ -274,10 +354,32 @@ proc Movie3d {} {
     MovieStatusDestroyDialog
 
     # reset
-    $current(frame) 3d view $vp
-    $current(frame) update fits slice $slice
+    switch $ds9(display) {
+	single {
+	    $current(frame) zoom to $zoom
+	    $current(frame) 3d view $vp
+	    $current(frame) update fits slice $slice
+	}
+	tile {
+	    $current(frame) highlite on
+	    foreach ff $ds9(active) {
+		$ff zoom to $zoom($ff)
+		$ff 3d view $vp($ff)
+		$ff update fits slice $slice($ff)
+	    }
+	}
+	blink {
+	    # should not be here
+	}
+    }
+
     Update3DDialog
     UpdateCubeDialog
+
+    if {[info exists modesav]} {
+	set current(display) $modesav
+	DisplayMode
+    }
 }
 
 # Support
@@ -299,7 +401,7 @@ proc MoviePhotoMPEG {} {
 
     # yes, we need this
     UpdateDS9
-    RealizeDS9 1
+    RealizeDS9
 
     set rr [catch {image create photo -format window -data $ds9(canvas)} ph]
     if {$rr} {
@@ -328,7 +430,7 @@ proc MoviePhotoGIF {} {
 
     # yes, we need this
     UpdateDS9
-    RealizeDS9 1
+    RealizeDS9
 
     set rr [catch {image create photo -format window -data $ds9(canvas)} ph]
     if {$rr} {
@@ -337,7 +439,8 @@ proc MoviePhotoGIF {} {
     }
 
     if {$movie(first)} {
-	agif create $movie(fn) [image width $ph] [image height $ph]
+	agif create $movie(fn) [image width $ph] [image height $ph] \
+	    $movie(delay)
 	set movie(first) 0
     }
     agif add $ph
@@ -361,6 +464,8 @@ proc Movie3dDialog {} {
     set ed2(el,to) $movie(el,to)
     set ed2(sl,from) [$current(frame) get fits slice]
     set ed2(sl,to) $ed2(sl,from)
+    set ed2(zm,from) [lindex [$current(frame) get zoom] 0]
+    set ed2(zm,to) $ed2(zm,from)
     set ed2(repeat) $movie(repeat)
     set ed2(repeat,num) $movie(repeat,num)
 
@@ -390,6 +495,12 @@ proc Movie3dDialog {} {
     ttk::label $f.tslto -text [msgcat::mc {To}]
     ttk::entry $f.slto -textvariable ed2(sl,to) -width 7
 
+    ttk::label $f.tzm -text [msgcat::mc {Zoom}]
+    ttk::label $f.tzmfrom -text [msgcat::mc {From}]
+    ttk::entry $f.zmfrom -textvariable ed2(zm,from) -width 7
+    ttk::label $f.tzmto -text [msgcat::mc {To}]
+    ttk::entry $f.zmto -textvariable ed2(zm,to) -width 7
+
     ttk::radiobutton $f.repeat -text [msgcat::mc {Repeat}] \
 	-variable ed2(repeat) -value repeat
     ttk::radiobutton $f.oscillate -text [msgcat::mc {Oscillate}] \
@@ -401,6 +512,7 @@ proc Movie3dDialog {} {
     grid $f.taz $f.tazfrom $f.azfrom $f.tazto $f.azto -padx 2 -pady 2 -sticky w
     grid $f.tel $f.telfrom $f.elfrom $f.telto $f.elto -padx 2 -pady 2 -sticky w
     grid $f.tsl $f.tslfrom $f.slfrom $f.tslto $f.slto -padx 2 -pady 2 -sticky w
+    grid $f.tzm $f.tzmfrom $f.zmfrom $f.tzmto $f.zmto -padx 2 -pady 2 -sticky w
     grid $f.oscillate x $f.repeatnum $f.ttimes -padx 2 -pady 2 -sticky w
     grid $f.repeat -padx 2 -pady 2 -sticky w
 
@@ -418,9 +530,8 @@ proc Movie3dDialog {} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed2(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed2(ok)} {
 	set movie(num) $ed2(num)
@@ -430,6 +541,8 @@ proc Movie3dDialog {} {
 	set movie(el,to) $ed2(el,to)
 	set movie(sl,from) $ed2(sl,from)
 	set movie(sl,to) $ed2(sl,to)
+	set movie(zm,from) $ed2(zm,from)
+	set movie(zm,to) $ed2(zm,to)
 	set movie(repeat) $ed2(repeat)
 	set movie(repeat,num) $ed2(repeat,num)
     }
