@@ -10,7 +10,7 @@ proc RegionMainMenu {} {
     global ds9
     global marker
 
-    menu $ds9(mb).region
+    ThemeMenu $ds9(mb).region
     $ds9(mb).region add command -label "[msgcat::mc {Get Information}]..." \
 	-command MarkerInfo
     $ds9(mb).region add separator
@@ -47,30 +47,34 @@ proc RegionMainMenu {} {
     $ds9(mb).region add command -label [msgcat::mc {Select All}] \
 	-command MarkerSelectAll -accelerator "${ds9(ctrl)}A"
     $ds9(mb).region add command -label [msgcat::mc {Select None}] \
-	-command MarkerUnselectAll
+	-command MarkerUnselectAll -accelerator "${ds9(shiftctrl)}A"
     $ds9(mb).region add command -label [msgcat::mc {Invert Selection}] \
 	-command MarkerSelectInvert
     $ds9(mb).region add separator
+    $ds9(mb).region add command -label [msgcat::mc {Save Selected Regions}] \
+	-command [list MarkerSave select]
+    $ds9(mb).region add command -label [msgcat::mc {List Selected Regions}] \
+	-command [list MarkerList select]
     $ds9(mb).region add command -label [msgcat::mc {Delete Selected Regions}] \
-	-command MarkerDeleteSelect
-    $ds9(mb).region add command -label [msgcat::mc {Delete All Regions}] \
-	-command MarkerDeleteAllMenu
+	-command [list MarkerDelete select]
     $ds9(mb).region add separator
-    $ds9(mb).region add command -label "[msgcat::mc {List Regions}]..." \
-	-command MarkerList
-    $ds9(mb).region add command -label "[msgcat::mc {Load Regions}]..." \
+    $ds9(mb).region add command -label "[msgcat::mc {Open Regions}]..." \
 	-command MarkerLoad
-    $ds9(mb).region add command \
-	-label "[msgcat::mc {Delete and Load Regions}]..." \
-	-command MarkerDeleteLoad
-    $ds9(mb).region add separator
     $ds9(mb).region add command -label "[msgcat::mc {Save Regions}]..." \
-	-command MarkerSave
+	-command [list MarkerSave {}]
+    $ds9(mb).region add command -label "[msgcat::mc {List Regions}]..." \
+	-command [list MarkerList {}]
+    $ds9(mb).region add command -label [msgcat::mc {Delete Regions}] \
+	-command [list MarkerDelete {}]
+    $ds9(mb).region add separator
+    $ds9(mb).region add command \
+	-label "[msgcat::mc {Delete and Open Regions}]..." \
+	-command MarkerDeleteLoad
     $ds9(mb).region add separator
     $ds9(mb).region add cascade -label [msgcat::mc {Region Parameters}] \
 	-menu $ds9(mb).region.params
 
-    menu $ds9(mb).region.shape
+    ThemeMenu $ds9(mb).region.shape
     $ds9(mb).region.shape add radiobutton -label [msgcat::mc {Circle}] \
 	-variable marker(shape) -value circle
     $ds9(mb).region.shape add radiobutton -label [msgcat::mc {Ellipse}] \
@@ -115,7 +119,7 @@ proc RegionMainMenu {} {
     $ds9(mb).region.shape add radiobutton -label [msgcat::mc {Box Panda}] \
 	-variable marker(shape) -value bpanda
 
-    menu $ds9(mb).region.shape.point
+    ThemeMenu $ds9(mb).region.shape.point
     $ds9(mb).region.shape.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable marker(shape) -value {circle point}
     $ds9(mb).region.shape.point add radiobutton -label [msgcat::mc {Box}] \
@@ -131,7 +135,7 @@ proc RegionMainMenu {} {
     $ds9(mb).region.shape.point add radiobutton -label [msgcat::mc {BoxCircle}]\
 	-variable marker(shape) -value {boxcircle point}
 
-    menu $ds9(mb).region.composite
+    ThemeMenu $ds9(mb).region.composite
     $ds9(mb).region.composite add command -label [msgcat::mc {Create}] \
 	-command CompositeCreate
     $ds9(mb).region.composite add command -label [msgcat::mc {Dissolve}] \
@@ -139,8 +143,8 @@ proc RegionMainMenu {} {
 
     CreateFOVMenu
 
-    menu $ds9(mb).region.template
-    $ds9(mb).region.template add command -label "[msgcat::mc {Load}]..." \
+    ThemeMenu $ds9(mb).region.template
+    $ds9(mb).region.template add command -label "[msgcat::mc {Open}]..." \
 	-command OpenTemplateMarker
     $ds9(mb).region.template add command -label "[msgcat::mc {Save}]..." \
 	-command SaveAsTemplateMarker
@@ -149,7 +153,7 @@ proc RegionMainMenu {} {
     WidthDashMenu $ds9(mb).region.width marker width dash \
 	MarkerWidth [list MarkerProp dash]
 
-    menu $ds9(mb).region.properties
+    ThemeMenu $ds9(mb).region.properties
     $ds9(mb).region.properties add checkbutton \
 	-label [msgcat::mc {Fixed in Size}] \
 	-variable marker(fixed) -command {MarkerProp fixed}
@@ -184,7 +188,7 @@ proc RegionMainMenu {} {
     FontMenu $ds9(mb).region.font marker font font,size font,weight \
 	font,slant MarkerFont
 
-    menu $ds9(mb).region.params
+    ThemeMenu $ds9(mb).region.params
     $ds9(mb).region.params add checkbutton \
 	-label [msgcat::mc {Show}] \
 	-variable marker(show) -command MarkerShow
@@ -208,6 +212,7 @@ proc RegionMainMenu {} {
 
     # Bindings
     bind $ds9(top) <<SelectAll>> MarkerSelectAll
+    bind $ds9(top) <<SelectNone>> MarkerUnselectAll
 }
 
 proc PrefsDialogRegionMenu {w} {
@@ -219,7 +224,7 @@ proc PrefsDialogRegionMenu {w} {
     grid $f.menu $f.buttonbar -padx 2 -pady 2 -sticky w
 
     set m $f.menu.menu
-    menu $m
+    ThemeMenu $m
     $m add cascade -label [msgcat::mc {Shape}] -menu $m.shape
     $m add separator
     $m add cascade -label [msgcat::mc {Color}] -menu $m.color
@@ -229,7 +234,7 @@ proc PrefsDialogRegionMenu {w} {
     $m add separator
     $m add cascade -label [msgcat::mc {Region Parameters}] -menu $m.params
 
-    menu $m.shape
+    ThemeMenu $m.shape
     $m.shape add radiobutton -label [msgcat::mc {Circle}] \
 	-variable pmarker(shape) -value circle
     $m.shape add radiobutton -label [msgcat::mc {Ellipse}] \
@@ -272,7 +277,7 @@ proc PrefsDialogRegionMenu {w} {
     $m.shape add radiobutton -label [msgcat::mc {Box Panda}] \
 	-variable pmarker(shape) -value bpanda
 
-    menu $m.shape.point
+    ThemeMenu $m.shape.point
     $m.shape.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable pmarker(shape) -value {circle point}
     $m.shape.point add radiobutton -label [msgcat::mc {Box}] \
@@ -291,7 +296,7 @@ proc PrefsDialogRegionMenu {w} {
     ColorMenu $m.color pmarker color {}
     WidthDashMenu $m.width pmarker width dash {} {}
 
-    menu $m.properties
+    ThemeMenu $m.properties
     $m.properties add checkbutton -label [msgcat::mc {Fixed in Size}] \
 	-variable pmarker(fixed)
     $m.properties add separator
@@ -316,7 +321,7 @@ proc PrefsDialogRegionMenu {w} {
 
     FontMenu $m.font pmarker font font,size font,weight font,slant {}
 
-    menu $m.params
+    ThemeMenu $m.params
     $m.params add checkbutton -label [msgcat::mc {Show}] \
 	-variable pmarker(show)
     $m.params add checkbutton -label [msgcat::mc {Show Text}] \
@@ -333,8 +338,8 @@ proc PrefsDialogRegion {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Region}]
-    lappend dprefs(tabs) [ttk::frame $w.region]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.region] \
+	-text [msgcat::mc {Region}]
 
     # Format
     set f [ttk::labelframe $w.region.format -text [msgcat::mc {Default Format}]]
@@ -344,7 +349,7 @@ proc PrefsDialogRegion {} {
 
     grid $f.format -padx 2 -pady 2 -sticky w
 
-    menu $f.format.menu
+    ThemeMenu $f.format.menu
     $f.format.menu add radiobutton -label {DS9/Funtools} \
 	-variable pmarker(format) -value ds9
     $f.format.menu add radiobutton -label {XML} \
@@ -369,7 +374,7 @@ proc PrefsDialogRegion {} {
 
     grid $f.dformat -padx 2 -pady 2 -sticky w
 
-    menu $f.dformat.menu
+    ThemeMenu $f.dformat.menu
     $f.dformat.menu add radiobutton -label {Degrees} \
 	-variable pmarker(dformat) -value degrees
     $f.dformat.menu add radiobutton -label {ArcMin} \
@@ -387,7 +392,7 @@ proc PrefsDialogRegion {} {
 
     grid $f.title $f.epsilon -padx 2 -pady 2 -sticky w
 
-    menu $f.epsilon.menu
+    ThemeMenu $f.epsilon.menu
     $f.epsilon.menu add radiobutton -label {2} -variable pmarker(epsilon) \
 	-value 2 -command MarkerEpsilon
     $f.epsilon.menu add radiobutton -label {3} -variable pmarker(epsilon) \
@@ -491,8 +496,8 @@ proc PrefsDialogAnnulus {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Annulus}]
-    lappend dprefs(tabs) [ttk::frame $w.annulus]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.annulus] \
+	-text [msgcat::mc {Annulus}]
 
     # Annulus
     set f [ttk::labelframe $w.annulus.annulus -text [msgcat::mc {Annulus}]]
@@ -568,8 +573,8 @@ proc PrefsDialogPanda {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Panda}]
-    lappend dprefs(tabs) [ttk::frame $w.panda]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.panda] \
+	-text [msgcat::mc {Panda}]
 
     # Panda
     set f [ttk::labelframe $w.panda.panda -text [msgcat::mc {Panda}]]
@@ -707,18 +712,19 @@ proc ButtonsRegionDef {} {
 	region,centroid 0
 	region,front 1
 	region,back 1
+	region,newgroup 0
+	region,group 0
 	region,all 1
 	region,none 1
 	region,invert 0
-	region,delete 1
-	region,deleteall 0
-	region,newgroup 0
-	region,group 0
-	region,list 1
+	region,saveselect 0
+	region,listselect 0
+	region,deleteselect 0
 	region,load 1
-	region,deleteload 0
 	region,save 1
-	region,mask 0
+	region,list 1
+	region,delete 1
+	region,deleteload 0
 	region,show 0
 	region,showtext 0
 	region,autocentroid 0
@@ -806,35 +812,37 @@ proc CreateButtonsRegion {} {
     ButtonButton $ds9(buttons).region.back \
 	[string tolower [msgcat::mc {Back}]] MarkerBack
 
+    ButtonButton $ds9(buttons).region.newgroup \
+	[string tolower [msgcat::mc {New Group}]] GroupCreate
+    ButtonButton $ds9(buttons).region.group \
+	[string tolower [msgcat::mc {Groups}]] GroupDialog
+
     ButtonButton $ds9(buttons).region.all \
 	[string tolower [msgcat::mc {All}]] MarkerSelectAll
     ButtonButton $ds9(buttons).region.none \
 	[string tolower [msgcat::mc {None}]] MarkerUnselectAll
     ButtonButton $ds9(buttons).region.invert \
 	[string tolower [msgcat::mc {Invert}]] MarkerSelectInvert
-    ButtonButton $ds9(buttons).region.delete \
-	[string tolower [msgcat::mc {Delete}]] MarkerDeleteSelect
-    ButtonButton $ds9(buttons).region.deleteall \
-	[string tolower [msgcat::mc {Delete All}]] MarkerDeleteAllMenu
 
-    ButtonButton $ds9(buttons).region.newgroup \
-	[string tolower [msgcat::mc {New Group}]] GroupCreate
-    ButtonButton $ds9(buttons).region.group \
-	[string tolower [msgcat::mc {Groups}]] GroupDialog
+    ButtonButton $ds9(buttons).region.saveselect \
+	[string tolower [msgcat::mc {Save Select}]] [list MarkerSave select]
+    ButtonButton $ds9(buttons).region.listselect \
+	[string tolower [msgcat::mc {List Select}]] [list MarkerList select]
+    ButtonButton $ds9(buttons).region.deleteselect \
+	[string tolower [msgcat::mc {Delete Select}]] [list MarkerDelete select]
 
-    ButtonButton $ds9(buttons).region.list \
-	[string tolower [msgcat::mc {List}]] MarkerList
     ButtonButton $ds9(buttons).region.load \
-	[string tolower [msgcat::mc {Load}]] MarkerLoad
+	[string tolower [msgcat::mc {Open}]] MarkerLoad
+    ButtonButton $ds9(buttons).region.save \
+	[string tolower [msgcat::mc {Save}]] [list MarkerSave {}]
+    ButtonButton $ds9(buttons).region.list \
+	[string tolower [msgcat::mc {List}]] [list MarkerList {}]
+    ButtonButton $ds9(buttons).region.delete \
+	[string tolower [msgcat::mc {Delete}]] [list MarkerDelete {}]
+    
     ButtonButton $ds9(buttons).region.deleteload \
 	[string tolower [msgcat::mc {Delete Load}]] MarkerDeleteLoad
 
-    ButtonButton $ds9(buttons).region.save \
-	[string tolower [msgcat::mc {Save}]] MarkerSave
-    
-    ButtonButton $ds9(buttons).region.mask \
-	[string tolower [msgcat::mc {Mask}]] MarkerMask
-
     CheckButton $ds9(buttons).region.show \
 	[string tolower [msgcat::mc {Show}]] \
 	marker(show) MarkerShow
@@ -872,18 +880,19 @@ proc CreateButtonsRegion {} {
         $ds9(buttons).region.centroid pbuttons(region,centroid)
         $ds9(buttons).region.front pbuttons(region,front)
         $ds9(buttons).region.back pbuttons(region,back)
+        $ds9(buttons).region.newgroup pbuttons(region,newgroup)
+        $ds9(buttons).region.group pbuttons(region,group)
         $ds9(buttons).region.all pbuttons(region,all)
         $ds9(buttons).region.none pbuttons(region,none)
         $ds9(buttons).region.invert pbuttons(region,invert)
-        $ds9(buttons).region.delete pbuttons(region,delete)
-        $ds9(buttons).region.deleteall pbuttons(region,deleteall)
-        $ds9(buttons).region.newgroup pbuttons(region,newgroup)
-        $ds9(buttons).region.group pbuttons(region,group)
-        $ds9(buttons).region.list pbuttons(region,list)
+        $ds9(buttons).region.saveselect pbuttons(region,saveselect)
+        $ds9(buttons).region.listselect pbuttons(region,listselect)
+        $ds9(buttons).region.deleteselect pbuttons(region,deleteselect)
         $ds9(buttons).region.load pbuttons(region,load)
-        $ds9(buttons).region.deleteload pbuttons(region,deleteload)
         $ds9(buttons).region.save pbuttons(region,save)
-        $ds9(buttons).region.mask pbuttons(region,mask)
+        $ds9(buttons).region.list pbuttons(region,list)
+        $ds9(buttons).region.delete pbuttons(region,delete)
+        $ds9(buttons).region.deleteload pbuttons(region,deleteload)
         $ds9(buttons).region.show pbuttons(region,show)
         $ds9(buttons).region.showtext pbuttons(region,showtext)
         $ds9(buttons).region.autocentroid pbuttons(region,autocentroid)
@@ -897,7 +906,7 @@ proc PrefsDialogButtonbarRegion {f} {
     ttk::menubutton $f -text [msgcat::mc {Buttonbar}] -menu $f.menu
     
     set m $f.menu
-    menu $m
+    ThemeMenu $m
     $m add checkbutton -label "[msgcat::mc {Get Information}]..." \
 	-variable pbuttons(region,info) \
 	-command {UpdateButtons buttons(region)}
@@ -916,6 +925,13 @@ proc PrefsDialogButtonbarRegion {f} {
 	-variable pbuttons(region,back) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
+    $m add checkbutton -label [msgcat::mc {New Group}] \
+	-variable pbuttons(region,newgroup) \
+	-command {UpdateButtons buttons(region)}
+    $m add checkbutton -label "[msgcat::mc {Groups}]..." \
+	-variable pbuttons(region,group) \
+	-command {UpdateButtons buttons(region)}
+    $m add separator
     $m add checkbutton -label [msgcat::mc {Select All}] \
 	-variable pbuttons(region,all) \
 	-command {UpdateButtons buttons(region)}
@@ -926,37 +942,36 @@ proc PrefsDialogButtonbarRegion {f} {
 	-variable pbuttons(region,invert) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
+    $m add checkbutton -label [msgcat::mc {Save Selected Regions}] \
+	-variable pbuttons(region,saveselect) \
+	-command {UpdateButtons buttons(region)}
+    $m add checkbutton -label [msgcat::mc {List Selected Regions}] \
+	-variable pbuttons(region,listselect) \
+	-command {UpdateButtons buttons(region)}
     $m add checkbutton -label [msgcat::mc {Delete Selected Regions}] \
-	-variable pbuttons(region,delete) \
-	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {Delete All Regions}] \
-	-variable pbuttons(region,deleteall) \
+	-variable pbuttons(region,deleteselect) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
-    $m add checkbutton -label [msgcat::mc {New Group}] \
-	-variable pbuttons(region,newgroup) \
+    $m add checkbutton -label "[msgcat::mc {Open Regions}]..." \
+	-variable pbuttons(region,load) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {Groups}]..." \
-	-variable pbuttons(region,group) \
+    $m add checkbutton -label "[msgcat::mc {Save Regions}]..." \
+	-variable pbuttons(region,save) \
 	-command {UpdateButtons buttons(region)}
-    $m add separator
     $m add checkbutton -label "[msgcat::mc {List Regions}]..." \
 	-variable pbuttons(region,list) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {Load Regions}]..." \
-	-variable pbuttons(region,load) \
-	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {Delete and Load Regions}]..." \
-	-variable pbuttons(region,deleteload) \
+    $m add checkbutton -label [msgcat::mc {Delete Regions}] \
+	-variable pbuttons(region,delete) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Save Regions}]..." \
-	-variable pbuttons(region,save) \
+    $m add checkbutton -label "[msgcat::mc {Delete and Open Regions}]..." \
+	-variable pbuttons(region,deleteload) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
     $m add cascade -label [msgcat::mc {Region Parameters}] -menu $m.params
 
-    menu $m.shape
+    ThemeMenu $m.shape
     $m.shape add checkbutton -label [msgcat::mc {Circle}] \
 	-variable pbuttons(region,circle) \
 	-command {UpdateButtons buttons(region)}
@@ -1016,7 +1031,7 @@ proc PrefsDialogButtonbarRegion {f} {
 	-variable pbuttons(region,bpanda) \
 	-command {UpdateButtons buttons(region)}
 
-    menu $m.composite
+    ThemeMenu $m.composite
     $m.composite add checkbutton -label [msgcat::mc {Create}] \
 	-variable pbuttons(region,create) \
 	-command {UpdateButtons buttons(region)}
@@ -1024,15 +1039,15 @@ proc PrefsDialogButtonbarRegion {f} {
 	-variable pbuttons(region,dissolve) \
 	-command {UpdateButtons buttons(region)}
 
-    menu $m.template
-    $m.template add checkbutton -label "[msgcat::mc {Load}]..." \
+    ThemeMenu $m.template
+    $m.template add checkbutton -label "[msgcat::mc {Open}]..." \
 	-variable pbuttons(region,loadtemplate) \
 	-command {UpdateButtons buttons(region)}
     $m.template add checkbutton -label "[msgcat::mc {Save}]..." \
 	-variable pbuttons(region,savetemplate) \
 	-command {UpdateButtons buttons(region)}
 
-    menu $m.params
+    ThemeMenu $m.params
     $m.params add checkbutton -label [msgcat::mc {Show}] \
 	-variable pbuttons(region,show) \
 	-command {UpdateButtons buttons(region)}
@@ -1139,12 +1154,14 @@ proc UpdateRegionMenu {} {
 	    $mm entryconfig [msgcat::mc {Invert Selection}] -state normal
 
 	    $mm entryconfig [msgcat::mc {Delete Selected Regions}] -state normal
-	    $mm entryconfig [msgcat::mc {Delete All Regions}] -state normal
 
-	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Load Regions}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Delete and Load Regions}]..." -state normal
+	    $mm entryconfig "[msgcat::mc {Open Regions}]..." -state normal
 	    $mm entryconfig "[msgcat::mc {Save Regions}]..." -state normal
+	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state normal
+	    $mm entryconfig [msgcat::mc {Delete Regions}] -state normal
+
+	    $mm entryconfig "[msgcat::mc {Delete and Open Regions}]..." \
+		-state normal
 
 	    $bb.info configure -state normal
 
@@ -1165,13 +1182,16 @@ proc UpdateRegionMenu {} {
 	    $bb.none configure -state normal
 	    $bb.invert configure -state normal
 
-	    $bb.delete configure -state normal
-	    $bb.deleteall configure -state normal
+	    $bb.saveselect configure -state normal
+	    $bb.listselect configure -state normal
+	    $bb.deleteselect configure -state normal
 
-	    $bb.list configure -state normal
 	    $bb.load configure -state normal
-	    $bb.deleteload configure -state normal
 	    $bb.save configure -state normal
+	    $bb.list configure -state normal
+	    $bb.delete configure -state normal
+
+	    $bb.deleteload configure -state normal
 	} else {
 	    $mm entryconfig "[msgcat::mc {Get Information}]..." -state disabled
 
@@ -1191,12 +1211,13 @@ proc UpdateRegionMenu {} {
 	    $mm entryconfig [msgcat::mc {Invert Selection}] -state disabled
 
 	    $mm entryconfig [msgcat::mc {Delete Selected Regions}] -state disabled
-	    $mm entryconfig [msgcat::mc {Delete All Regions}] -state disabled
 
-	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Load Regions}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Delete and Load Regions}]..." -state disabled
+	    $mm entryconfig "[msgcat::mc {Open Regions}]..." -state disabled
 	    $mm entryconfig "[msgcat::mc {Save Regions}]..." -state disabled
+	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state disabled
+	    $mm entryconfig [msgcat::mc {Delete Regions}] -state disabled
+
+	    $mm entryconfig "[msgcat::mc {Delete and Open Regions}]..." -state disabled
 
 	    $bb.info configure -state disabled
 
@@ -1217,13 +1238,16 @@ proc UpdateRegionMenu {} {
 	    $bb.none configure -state disabled
 	    $bb.invert configure -state disabled
 
-	    $bb.delete configure -state disabled
-	    $bb.deleteall configure -state disabled
+	    $bb.saveselect configure -state disabled
+	    $bb.listselect configure -state disabled
+	    $bb.deleteselect configure -state disabled
 
-	    $bb.list configure -state disabled
 	    $bb.load configure -state disabled
-	    $bb.deleteload configure -state disabled
 	    $bb.save configure -state disabled
+	    $bb.list configure -state disabled
+	    $bb.delete configure -state disabled
+
+	    $bb.deleteload configure -state disabled
 	}
     } else {
 	$ds9(mb) entryconfig [msgcat::mc {Region}] -state disabled
