@@ -9,16 +9,16 @@ package provide DS9 1.0
 proc ZoomMainMenu {} {
     global ds9
 
-    menu $ds9(mb).zoom
+    ThemeMenu $ds9(mb).zoom
     $ds9(mb).zoom add command -label [msgcat::mc {Center Image}] \
 	-command CenterCurrentFrame
     $ds9(mb).zoom add checkbutton -label [msgcat::mc {Align}] \
 	-variable current(align) -command AlignWCSFrame
     $ds9(mb).zoom add separator
     $ds9(mb).zoom add command -label [msgcat::mc {Zoom In}] \
-	-command {Zoom 2 2}
+	-command {Zoom 2 2} -accelerator "${ds9(ctrl)}+"
     $ds9(mb).zoom add command -label [msgcat::mc {Zoom Out}] \
-	-command {Zoom .5 .5}
+	-command {Zoom .5 .5} -accelerator "${ds9(ctrl)}-"
     $ds9(mb).zoom add command -label [msgcat::mc {Zoom Fit}] \
 	-command ZoomToFit
     $ds9(mb).zoom add separator
@@ -69,6 +69,9 @@ proc ZoomMainMenu {} {
     $ds9(mb).zoom add command \
 	-label "[msgcat::mc {Pan Zoom Rotate Parameters}]..." \
 	-command PanZoomDialog
+
+    bind $ds9(top) <<ZoomIn>> [list Zoom 2 2]
+    bind $ds9(top) <<ZoomOut>> [list Zoom .5 .5]
 }
 
 proc PrefsDialogZoomMenu {w} {
@@ -80,7 +83,7 @@ proc PrefsDialogZoomMenu {w} {
     grid $f.menu $f.buttonbar -padx 2 -pady 2
     
     set m $f.menu.menu
-    menu $m
+    ThemeMenu $m
     $m add checkbutton -label [msgcat::mc {Align}] \
 	-variable pcurrent(align)
     $m add separator
@@ -133,8 +136,8 @@ proc PrefsDialogZoom {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Zoom}]
-    lappend dprefs(tabs) [ttk::frame $w.zoom]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.zoom] \
+	-text [msgcat::mc {Pan Zoom}]
 
     # PanZoom
     set f [ttk::labelframe $w.zoom.panzoom -text [msgcat::mc {Pan Zoom}]]
@@ -309,7 +312,7 @@ proc PrefsDialogButtonbarZoom {f} {
     ttk::menubutton $f -text [msgcat::mc {Buttonbar}] -menu $f.menu
     
     set m $f.menu
-    menu $m
+    ThemeMenu $m
     $m add checkbutton -label [msgcat::mc {Center Image}] \
 	-variable pbuttons(zoom,center) -command {UpdateButtons buttons(zoom)}
     $m add checkbutton -label [msgcat::mc {Align}] \
