@@ -76,7 +76,7 @@ proc MosaicWCSDialog {varname} {
     ttk::menubutton $f.sys -textvariable ed(label) \
 	-menu $f.sys.m -width 10
 
-    menu $f.sys.m
+    ThemeMenu $f.sys.m
     $f.sys.m add radiobutton -label [msgcat::mc {WCS}] \
 	-variable ed(sys) -value "wcs" -command [list set ed(label) WCS]
     $f.sys.m add separator
@@ -103,9 +103,8 @@ proc MosaicWCSDialog {varname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set var $ed(sys)
