@@ -77,9 +77,8 @@ proc PSPageSetup {} {
     grid rowconfigure $w 1 -weight 1
     grid columnconfigure $w 0 -weight 1
 
-    DialogCenter $w
     DialogWait $w ed(ok) $w.buttons.ok 
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	array set ps [array get ed]
@@ -95,8 +94,8 @@ proc PrefsDialogPageSetup {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Page Setup}]
-    lappend dprefs(tabs) [ttk::frame $w.pagesetup]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.pagesetup] \
+	-text [msgcat::mc {Page Setup}]
 
     # Layout
     set f [ttk::labelframe $w.pagesetup.layout -text {Layout}]
