@@ -53,14 +53,14 @@ proc PixelTableDialog {} {
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
     $mb add cascade -label [msgcat::mc {Size}] -menu $mb.size
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command PixelTableSaveDialog
+	-command PixelTableSaveDialog -accelerator "${ds9(ctrl)}S"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command PixelTableDestroyDialog
+	-command PixelTableDestroyDialog -accelerator "${ds9(ctrl)}W"
 
-    menu $mb.edit
+    ThemeMenu $mb.edit
     $mb.edit add command -label [msgcat::mc {Cut}] \
 	-state disabled -accelerator "${ds9(ctrl)}X"
     $mb.edit add command -label [msgcat::mc {Copy}] \
@@ -68,7 +68,7 @@ proc PixelTableDialog {} {
     $mb.edit add command -label [msgcat::mc {Paste}] \
 	-state disabled -accelerator "${ds9(ctrl)}V"
 
-    menu $mb.size
+    ThemeMenu $mb.size
     for {set ii 3} {$ii<=$ipixel(max)} {incr ii 2} {
 	$mb.size add radiobutton -label "${ii}x${ii}" -variable pixel(size) \
 	    -value $ii -command PixelTableConfigure
@@ -82,12 +82,14 @@ proc PixelTableDialog {} {
 			 -variable dpixel \
 			 -usecommand 0 \
 			 -maxwidth 1200 \
-			 -fg $ds9(gui,fg) -bg $ds9(gui,bg) \
+			 -resizeborders none \
+			 -fg [ThemeTreeForeground] \
+			 -bg [ThemeTreeBackground] \
 			]
     
     $dpixel(tbl) tag col coord 0
     $dpixel(tbl) tag row coord 0
-    $dpixel(tbl) tag configure coord -foreground $ds9(gui,bold)
+    $dpixel(tbl) tag configure coord -foreground [ThemeBold]
     $dpixel(tbl) tag configure center -foreground red
 
     grid $f.t -sticky news
@@ -106,6 +108,9 @@ proc PixelTableDialog {} {
 
     selection handle $w PixelTableExportSelection
 
+    bind $w <<Save>> PixelTableSaveDialog
+    bind $w <<Close>> PixelTableDestroyDialog
+
     PixelTableConfigure
 
     # dummy info
@@ -155,7 +160,9 @@ proc PixelTableClearDialog {} {
 }
 
 proc PixelTableSaveDialog {} {
-    set filename [SaveFileDialog pixelfbox]
+    global ipixel
+    
+    set filename [SaveFileDialog pixelfbox $ipixel(top)]
 
     if {$filename != {}} {
 	set file [open $filename w]
@@ -233,8 +240,8 @@ proc PrefsDialogPixelTable {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Pixel Table}]
-    lappend dprefs(tabs) [ttk::frame $w.pixel]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.pixel] \
+	-text [msgcat::mc {Pixel Table}]
 
     set f [ttk::labelframe $w.pixel.param -text [msgcat::mc {Pixel Table}]]
 
@@ -246,7 +253,7 @@ proc PrefsDialogPixelTable {} {
 
     global ipixel
     set m $f.size.menu
-    menu $m
+    ThemeMenu $m
     for {set ii 3} {$ii<=$ipixel(max)} {incr ii 2} {
 	$m add radiobutton -label "${ii}x${ii}" -variable ppixel(size) \
 	    -value $ii -command [list PrefsDialogPixelTableButtonCmd $ii]
