@@ -4,7 +4,8 @@
 
 package provide DS9 1.0
 
-proc PlotDialog {varname wtt} {
+# used by backup (need the hidden param)
+proc PlotDialog {varname wtt {theme true}} {
     upvar #0 $varname var
     global $varname
 
@@ -17,10 +18,17 @@ proc PlotDialog {varname wtt} {
 
     # add it to our xpa list
     global iap
-    lappend iap(windows) $varname
+    lappend iap(plots) $varname
 
+    # plot window
     set var(top) ".${varname}"
     set var(mb) ".${varname}mb"
+    set var(tt) $wtt
+
+    # gui tool
+    set var(gui,top) ".${varname}gui"
+    set var(gui,mb) ".${varname}guimb"
+
     set var(stats) 0
     set var(list) 0
 
@@ -30,7 +38,11 @@ proc PlotDialog {varname wtt} {
     set var(graphs) {}
     set var(seq) 0
 
-    array set $varname [array get pap]
+    # set canvas vars
+    array set $varname [array get pap "canvas,*"]
+    if {!$theme} {
+	set var(canvas,theme) 0
+    }	
 
     # create window
     Toplevel $var(top) $var(mb) 7 $wtt [list PlotDestroy $varname]
@@ -38,12 +50,13 @@ proc PlotDialog {varname wtt} {
 
     $var(mb) add cascade -label [msgcat::mc {File}] -menu $var(mb).file
     $var(mb) add cascade -label [msgcat::mc {Edit}] -menu $var(mb).edit
-    $var(mb) add cascade -label [msgcat::mc {Canvas}] -menu $var(mb).canvas
+    $var(mb) add cascade -label [msgcat::mc {Control Panel}] -menu $var(mb).gui
+    $var(mb) add cascade -label [msgcat::mc {Plot}] -menu $var(mb).canvas
     $var(mb) add cascade -label [msgcat::mc {Graph}] -menu $var(mb).graph
     $var(mb) add cascade -label [msgcat::mc {Data}] -menu $var(mb).dataline
 
     # File
-    menu $var(mb).file
+    ThemeMenu $var(mb).file
     $var(mb).file add command -label "[msgcat::mc {Load Data}]..." \
 	-command [list PlotLoadData $varname]
     $var(mb).file add command -label "[msgcat::mc {Save Data}]..." \
@@ -52,21 +65,29 @@ proc PlotDialog {varname wtt} {
     $var(mb).file add cascade -label [msgcat::mc {Export}] \
 	-menu $var(mb).file.export
     $var(mb).file add separator
-    $var(mb).file add command -label "[msgcat::mc {Load Configuration}]..." \
-	-command [list PlotLoadConfig $varname]
-    $var(mb).file add command -label "[msgcat::mc {Save Configuration}]..." \
-	-command [list PlotSaveConfig $varname]
+    $var(mb).file add command -label [msgcat::mc {Statistics}] \
+       -command "set ${varname}(stats) 1; PlotStats $varname"
+    $var(mb).file add command -label [msgcat::mc {List Data}] \
+       -command "set ${varname}(list) 1; PlotList $varname"
+    $var(mb).file add separator
+    $var(mb).file add command -label "[msgcat::mc {Backup}]..." \
+	-command [list PlotBackupDialog $varname]
+    $var(mb).file add command -label "[msgcat::mc {Restore}]..." \
+	-command [list PlotRestoreDialog $varname]
     $var(mb).file add separator
     $var(mb).file add command \
 	-label "[msgcat::mc {Page Setup}]..." \
-	-command PSPageSetup
+	-command PSPageSetup -accelerator "${ds9(shiftctrl)}P"
     $var(mb).file add command -label "[msgcat::mc {Print}]..." \
-	-command [list PlotPSPrint $varname]
+	-command [list PlotPSPrint $varname] -accelerator "${ds9(ctrl)}P"
+
     $var(mb).file add separator
     $var(mb).file add command -label [msgcat::mc {Close}] \
-	-command [list PlotDestroy $varname]
+	-command [list PlotDestroy $varname] -accelerator "${ds9(ctrl)}W"
 
-    menu $var(mb).file.export
+    ThemeMenu $var(mb).file.export
+    $var(mb).file.export add command -label {EPS...} \
+	-command [list PlotExportDialog $varname eps]
     $var(mb).file.export add command -label {GIF...} \
 	-command [list PlotExportDialog $varname gif]
     $var(mb).file.export add command -label {TIFF...} \
@@ -76,15 +97,13 @@ proc PlotDialog {varname wtt} {
     $var(mb).file.export add command -label {PNG...} \
 	-command [list PlotExportDialog $varname png]
 
-    menu $var(mb).edit
+    ThemeMenu $var(mb).edit
     $var(mb).edit add command -label [msgcat::mc {Cut}] \
 	-state disabled -accelerator "${ds9(ctrl)}X"
     $var(mb).edit add command -label [msgcat::mc {Copy}] \
 	-state disabled -accelerator "${ds9(ctrl)}C"
     $var(mb).edit add command -label [msgcat::mc {Paste}] \
 	-state disabled -accelerator "${ds9(ctrl)}V"
-    $var(mb).edit add command -label [msgcat::mc {Clear}] \
-	-state disabled
     $var(mb).edit add separator
     $var(mb).edit add radiobutton -label [msgcat::mc {Pointer}] \
 	-variable ${varname}(mode) -value pointer \
@@ -94,7 +113,7 @@ proc PlotDialog {varname wtt} {
 	-command [list PlotChangeMode $varname]
 
     # Canvas
-    menu $var(mb).canvas
+    ThemeMenu $var(mb).canvas
 
     $var(mb).canvas add cascade -label [msgcat::mc {Select Graph}] \
 	-menu $var(mb).canvas.select
@@ -119,6 +138,10 @@ proc PlotDialog {varname wtt} {
 	-menu $var(mb).canvas.legend
 
     $var(mb).canvas add separator
+    $var(mb).canvas add checkbutton -label [msgcat::mc {Use Theme Colors}] \
+	-variable ${varname}(canvas,theme) \
+	-command [list PlotUpdateAllElement $varname]
+    $var(mb).canvas add separator
     $var(mb).canvas add cascade -label [msgcat::mc {Forground}] \
 	-menu $var(mb).canvas.fg
     $var(mb).canvas add cascade -label [msgcat::mc {Background}] \
@@ -126,9 +149,9 @@ proc PlotDialog {varname wtt} {
     $var(mb).canvas add cascade -label [msgcat::mc {Grid}] \
 	-menu $var(mb).canvas.grid
 
-    menu $var(mb).canvas.select
+    ThemeMenu $var(mb).canvas.select
 
-    menu $var(mb).canvas.graph
+    ThemeMenu $var(mb).canvas.graph
     $var(mb).canvas.graph add command -label [msgcat::mc {Line}] \
 	-command [list PlotAddGraph $varname line]
     $var(mb).canvas.graph add command -label [msgcat::mc {Bar}] \
@@ -136,19 +159,19 @@ proc PlotDialog {varname wtt} {
     $var(mb).canvas.graph add command -label [msgcat::mc {Scatter}] \
 	-command [list PlotAddGraph $varname scatter]
 
-    menu $var(mb).canvas.layout
+    ThemeMenu $var(mb).canvas.layout
     $var(mb).canvas.layout add radiobutton -label [msgcat::mc {Grid}] \
-	-variable ${varname}(layout) -value grid \
+	-variable ${varname}(canvas,layout) -value grid \
 	-command [list PlotChangeLayout $varname]
     $var(mb).canvas.layout add radiobutton -label [msgcat::mc {Row}] \
-	-variable ${varname}(layout) -value row \
+	-variable ${varname}(canvas,layout) -value row \
 	-command [list PlotChangeLayout $varname]
     $var(mb).canvas.layout add radiobutton -label [msgcat::mc {Column}] \
-	-variable ${varname}(layout) -value column \
+	-variable ${varname}(canvas,layout) -value column \
 	-command [list PlotChangeLayout $varname]
     $var(mb).canvas.layout add separator
     $var(mb).canvas.layout add radiobutton -label [msgcat::mc {Strip}] \
-	-variable ${varname}(layout) -value strip \
+	-variable ${varname}(canvas,layout) -value strip \
 	-command [list PlotChangeLayout $varname]
     $var(mb).canvas.layout add separator
     $var(mb).canvas.layout add command \
@@ -156,32 +179,35 @@ proc PlotDialog {varname wtt} {
 	-command [list PlotStripDialog $varname]
 
     FontMenu $var(mb).canvas.title \
-	$varname graph,title,family graph,title,size graph,title,weight \
-	graph,title,slant [list PlotUpdateCanvas $varname]
+	$varname canvas,title,family canvas,title,size \
+	canvas,title,weight canvas,title,slant \
+	[list PlotUpdateCanvasElement $varname]
     FontMenu $var(mb).canvas.textlab \
-	$varname axis,title,family axis,title,size axis,title,weight \
-	axis,title,slant [list PlotUpdateCanvas $varname]
+	$varname canvas,axis,title,family canvas,axis,title,size \
+	canvas,axis,title,weight canvas,axis,title,slant \
+	[list PlotUpdateCanvasElement $varname]
     FontMenu $var(mb).canvas.numlab \
-	$varname axis,font,family axis,font,size axis,font,weight \
-	axis,font,slant [list PlotUpdateCanvas $varname]
+	$varname canvas,axis,font,family canvas,axis,font,size \
+	canvas,axis,font,weight canvas,axis,font,slant \
+	[list PlotUpdateCanvasElement $varname]
     FontMenu $var(mb).canvas.legendtitle \
-	$varname legend,title,family legend,title,size legend,title,weight \
-	legend,title,slant [list PlotUpdateCanvas $varname]
+	$varname canvas,legend,title,family canvas,legend,title,size \
+	canvas,legend,title,weight canvas,legend,title,slant \
+	[list PlotUpdateCanvasElement $varname]
     FontMenu $var(mb).canvas.legend \
-	$varname legend,font,family legend,font,size legend,font,weight \
-	legend,font,slant [list PlotUpdateCanvas $varname]
+	$varname canvas,legend,font,family canvas,legend,font,size \
+	canvas,legend,font,weight canvas,legend,font,slant \
+	[list PlotUpdateCanvasElement $varname]
 
-    PlotColorMenu $var(mb).canvas.fg $varname foreground \
-	[list PlotUpdateCanvas $varname]
-
-    PlotColorMenu $var(mb).canvas.bg $varname background \
-	[list PlotUpdateCanvas $varname]
-
-    PlotColorMenu $var(mb).canvas.grid $varname grid,color \
-	[list PlotUpdateCanvas $varname]
+    ColorMenu $var(mb).canvas.fg $varname canvas,foreground \
+	[list PlotUpdateCanvasElement $varname]
+    ColorMenu $var(mb).canvas.bg $varname canvas,background \
+	[list PlotUpdateAllElement $varname]
+    ColorMenu $var(mb).canvas.grid $varname canvas,grid,color \
+	[list PlotUpdateCanvasElement $varname]
 
     # Graph
-    menu $var(mb).graph
+    ThemeMenu $var(mb).graph
 
     $var(mb).graph add cascade -label [msgcat::mc {Select Dataset}] \
 	-menu $var(mb).graph.select
@@ -191,50 +217,44 @@ proc PlotDialog {varname wtt} {
     $var(mb).graph add command -label [msgcat::mc {Delete Dataset}] \
 	-command [list PlotDeleteDataSetCurrent $varname]
     $var(mb).graph add separator
-    $var(mb).graph add command -label [msgcat::mc {Statistics}] \
-	-command "set ${varname}(stats) 1; PlotStats $varname"
-    $var(mb).graph add command -label [msgcat::mc {List Data}] \
-	-command "set ${varname}(list) 1; PlotList $varname"
-    $var(mb).graph add separator
-
-    $var(mb).graph add cascade -label [msgcat::mc {Axes}] \
-	-menu $var(mb).graph.axes
     $var(mb).graph add cascade -label [msgcat::mc {Legend}] \
 	-menu $var(mb).graph.legend
     $var(mb).graph add separator
-    $var(mb).graph add cascade -label [msgcat::mc {Bar Mode}] \
-	-menu $var(mb).graph.barmode
+    $var(mb).graph add cascade -label [msgcat::mc {X Axis}] \
+	-menu $var(mb).graph.xaxis
+    $var(mb).graph add cascade -label [msgcat::mc {Y Axis}] \
+	-menu $var(mb).graph.yaxis
     $var(mb).graph add separator
+    $var(mb).graph add command -label "[msgcat::mc {Axes Range}]..." \
+	-command [list PlotRangeDialog $varname]
     $var(mb).graph add command -label "[msgcat::mc {Titles}]..." \
 	-command [list PlotGraphTitleDialog $varname]
 
-    menu $var(mb).graph.select
+    ThemeMenu $var(mb).graph.select
 
-    menu $var(mb).graph.axes
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {X Grid}] \
-	-variable ${varname}(graph,axis,x,grid) \
-	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {X Log}] \
+    ThemeMenu $var(mb).graph.xaxis
+    $var(mb).graph.xaxis add checkbutton -label [msgcat::mc {Log}] \
 	-variable ${varname}(graph,axis,x,log) \
 	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {X Flip}] \
+    $var(mb).graph.xaxis add checkbutton -label [msgcat::mc {Flip}] \
 	-variable ${varname}(graph,axis,x,flip) \
 	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add separator
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {Y Grid}] \
-	-variable ${varname}(graph,axis,y,grid) \
+    $var(mb).graph.xaxis add checkbutton -label [msgcat::mc {Grid}] \
+	-variable ${varname}(graph,axis,x,grid) \
 	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {Y Log}] \
+
+    ThemeMenu $var(mb).graph.yaxis
+    $var(mb).graph.yaxis add checkbutton -label [msgcat::mc {Log}] \
 	-variable ${varname}(graph,axis,y,log) \
 	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add checkbutton -label [msgcat::mc {Y Flip}] \
+    $var(mb).graph.yaxis add checkbutton -label [msgcat::mc {Flip}] \
 	-variable ${varname}(graph,axis,y,flip) \
 	-command [list PlotChangeAxis $varname]
-    $var(mb).graph.axes add separator
-    $var(mb).graph.axes add command -label "[msgcat::mc {Range}]..." \
-	-command [list PlotRangeDialog $varname]
+    $var(mb).graph.yaxis add checkbutton -label [msgcat::mc {Grid}] \
+	-variable ${varname}(graph,axis,y,grid) \
+	-command [list PlotChangeAxis $varname]
 
-    menu $var(mb).graph.legend
+    ThemeMenu $var(mb).graph.legend
     $var(mb).graph.legend add checkbutton -label [msgcat::mc {Show}] \
 	-variable ${varname}(graph,legend) \
 	-command [list PlotChangeLegend $varname]
@@ -255,23 +275,18 @@ proc PlotDialog {varname wtt} {
 	-variable ${varname}(graph,legend,position) -value plotarea \
 	-command [list PlotChangeLegend $varname]
 
-    menu $var(mb).graph.barmode
-    $var(mb).graph.barmode add radiobutton -label [msgcat::mc {Normal}] \
-	-variable ${varname}(bar,mode) -value normal \
-	-command [list PlotUpdateGraph $varname]
-    $var(mb).graph.barmode add radiobutton -label [msgcat::mc {Stacked}] \
-	-variable ${varname}(bar,mode) -value stacked \
-	-command [list PlotUpdateGraph $varname]
-    $var(mb).graph.barmode add radiobutton -label [msgcat::mc {Aligned}] \
-	-variable ${varname}(bar,mode) -value aligned \
-	-command [list PlotUpdateGraph $varname]
-    $var(mb).graph.barmode add radiobutton -label [msgcat::mc {Overlap}] \
-	-variable ${varname}(bar,mode) -value overlap \
-	-command [list PlotUpdateGraph $varname]
-
     PlotLineMenus $varname
     PlotBarMenus $varname
     PlotScatterMenus $varname
+
+    # GUI
+    ThemeMenu $var(mb).gui
+    $var(mb).gui add command -label [msgcat::mc {Open}] \
+	-command [list PlotGUI $varname]
+
+    bind $var(top) <<Close>> [list PlotDestroy $varname]
+    bind $var(top) <<PageSetup>> PSPageSetup
+    bind $var(top) <<Print>> [list PlotPSPrint $varname]
 }
 
 proc PlotDataFormatDialog {xarname} {
@@ -315,9 +330,8 @@ proc PlotDataFormatDialog {xarname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok) $w.param.xy
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set xar $ed(dim)
@@ -338,14 +352,14 @@ proc PlotStripDialog {varname} {
 
     set ed(ok) 0
 
-    set ed(layout,strip,scale) $var(layout,strip,scale)
+    set ed(canvas,layout,strip,scale) $var(canvas,layout,strip,scale)
 
     DialogCreate $w [msgcat::mc {Strip Parameters}] ed(ok)
 
     # Param
     set f [ttk::frame $w.param]
     ttk::label $f.t -text [msgcat::mc {Scale}]
-    ttk::entry $f.ww -textvariable ed(layout,strip,scale) -width 6
+    ttk::entry $f.ww -textvariable ed(canvas,layout,strip,scale) -width 6
     ttk::label $f.tt -text {%}
 
     grid $f.t $f.ww $f.tt -padx 2 -pady 2 -sticky w
@@ -364,12 +378,11 @@ proc PlotStripDialog {varname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok) $w.param.ww
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
-	set var(layout,strip,scale) $ed(layout,strip,scale)
+	set var(canvas,layout,strip,scale) $ed(canvas,layout,strip,scale)
 	PlotChangeLayout $varname
     }
     
@@ -438,9 +451,8 @@ proc PlotRangeDialog {varname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok) $w.param.xmin
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set var(graph,axis,x,auto) $ed(graph,axis,x,auto)
@@ -507,9 +519,8 @@ proc PlotGraphTitleDialog {varname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok) $w.param.title
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	set var(graph,title) $ed(graph,title)
@@ -559,9 +570,8 @@ proc DatasetNameDialog {varname} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok) $w.param.name
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	PlotDataSetName $varname $ed(name)
@@ -572,30 +582,6 @@ proc DatasetNameDialog {varname} {
     return $rr
 }
 
-proc PlotLineShapeMenu {which var} {
-    menu $which
-    $which add radiobutton -label [msgcat::mc {None}] \
-	-variable $var -value none
-    $which add radiobutton -label [msgcat::mc {Circle}] \
-	-variable $var -value circle
-    $which add radiobutton -label [msgcat::mc {Square}] \
-	-variable $var -value square
-    $which add radiobutton -label [msgcat::mc {Diamond}] \
-	-variable $var -value diamond
-    $which add radiobutton -label [msgcat::mc {Plus}] \
-	-variable $var -value plus
-    $which add radiobutton -label [msgcat::mc {Cross}] \
-	-variable $var -value cross
-    $which add radiobutton -label [msgcat::mc {Simple Plus}] \
-	-variable $var -value splus
-    $which add radiobutton -label [msgcat::mc {Simple Cross}] \
-	-variable $var -value scross
-    $which add radiobutton -label [msgcat::mc {Triangle}] \
-	-variable $var -value triangle
-    $which add radiobutton -label [msgcat::mc {Arrow}] \
-	-variable $var -value arrow
-}
-
 proc PlotExportDialog {varname format} {
     upvar #0 $varname var
     global $varname
@@ -607,15 +593,17 @@ proc PlotExportDialog {varname format} {
     global iap
 
     switch -- $format {
-	gif {set fn [SaveFileDialog giffbox]}
-	jpeg {set fn [SaveFileDialog jpegfbox]}
-	tiff {set fn [SaveFileDialog tifffbox]}
-	png {set fn [SaveFileDialog pngfbox]}
+	eps {set fn [SaveFileDialog epsfbox $var(top)]}
+	gif {set fn [SaveFileDialog giffbox $var(top)]}
+	jpeg {set fn [SaveFileDialog jpegfbox $var(top)]}
+	tiff {set fn [SaveFileDialog tifffbox $var(top)]}
+	png {set fn [SaveFileDialog pngfbox $var(top)]}
     }
 
     if {$fn != {}} {
 	set ok 1
 	switch -- $format {
+	    eps {}
 	    gif {}
 	    jpeg {set ok [JPEGExportDialog iap(jpeg,quality)]}
 	    tiff {set ok [TIFFExportDialog iap(tiff,compress)]}
@@ -641,9 +629,28 @@ proc PlotExport {varname fn format} {
 
     # be sure we are on top
     raise $var(top)
+
     # and realized
+    global debug
+    if {$debug(tcl,idletasks)} {
+	puts stderr "PlotExport update"
+    }
     update
 
+    switch -- $format {
+	eps {PlotEPS $varname $fn}
+	gif -
+	tiff -
+	jpeg -
+	png {PlotExportPhoto $varname $fn $format}
+    }
+}
+
+proc PlotExportPhoto {varname fn format} {
+    upvar #0 $varname var
+    global $varname
+    global iap
+
     # for darwin only
     set geom [MacOSPhotoFix $var(top) 0 0]
 
@@ -682,32 +689,41 @@ proc PlotUpdateMenus {varname} {
     # Canvas
 
     # Graph
-    switch $var(layout) {
+    switch $var(canvas,layout) {
 	grid -
 	row -
 	column {
-	    $var(mb).graph.axes entryconfig [msgcat::mc {X Grid}] -state normal
-	    $var(mb).graph.axes entryconfig [msgcat::mc {X Log}] -state normal
-	    $var(mb).graph.axes entryconfig [msgcat::mc {X Flip}] -state normal
+	    $var(mb).graph.xaxis entryconfig [msgcat::mc {Log}] -state normal
+	    $var(mb).graph.xaxis entryconfig [msgcat::mc {Flip}] -state normal
+	    $var(mb).graph.xaxis entryconfig [msgcat::mc {Grid}] -state normal
+
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Log}] -state normal
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Flip}] -state normal
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Grid}] -state normal
 	}
 	strip {
 	    set cc $var(graph,current)
 	    set first [lindex $var(graphs) 0]
 	    if {$cc == $first} {
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Grid}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Log}] \
 		    -state normal
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Log}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Flip}] \
 		    -state normal
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Flip}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Grid}] \
 		    -state normal
+
 	    } else {
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Grid}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Log}] \
 		    -state disabled
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Log}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Flip}] \
 		    -state disabled
-		$var(mb).graph.axes entryconfig [msgcat::mc {X Flip}] \
+		$var(mb).graph.xaxis entryconfig [msgcat::mc {Grid}] \
 		    -state disabled
 	    }
+
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Log}] -state normal
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Flip}] -state normal
+	    $var(mb).graph.yaxis entryconfig [msgcat::mc {Grid}] -state normal
 	}
     }
 
@@ -719,14 +735,8 @@ proc PlotUpdateMenus {varname} {
     } else {
 	$var(mb).graph entryconfig [msgcat::mc {Duplicate Dataset}] \
 	    -state normal
-
-	if {!$var(graph,ds,manage)} {
-	    $var(mb).graph entryconfig [msgcat::mc {Delete Dataset}] \
-		-state disabled
-	} else {
-	    $var(mb).graph entryconfig [msgcat::mc {Delete Dataset}] \
-		-state normal
-	}
+	$var(mb).graph entryconfig [msgcat::mc {Delete Dataset}] \
+	    -state normal
     }
 
     $var(mb).graph.select delete 0 end
@@ -753,10 +763,4 @@ proc PlotUpdateMenus {varname} {
 		-menu $var(mb).datascatter
 	}
     }
-
-    if {[llength $var(graph,dss)] == 0} {
-	$var(mb) entryconfig [msgcat::mc {Data}] -state disabled
-    } else {
-	$var(mb) entryconfig [msgcat::mc {Data}] -state normal
-    }
 }
