@@ -39,10 +39,6 @@ proc PSPrint {} {
 proc PostScript {} {
     global ds9
     global ps
-    global view
-    global canvas
-    global colorbar
-    global current
 
     # we need to be realized
     RealizeDS9
@@ -158,11 +154,6 @@ proc PostScript {} {
 
 proc EPS {fn} {
     global ds9
-    global ps
-    global view
-    global canvas
-    global colorbar
-    global current
 
     # we need to be realized
     RealizeDS9
@@ -171,7 +162,7 @@ proc EPS {fn} {
 
     set color rgb
     set level 2
-    set resolution 72
+    set resolution 96
 
     # Page size
     set width [winfo width $ds9(canvas)]
@@ -186,6 +177,7 @@ proc EPS {fn} {
     set options { -colormode color}
 
     append options " -pagex 0 -pagey 0 -pageanchor sw"
+
     if ($width>$height) {
 	append options " -pagewidth $width"
     } else {
@@ -274,7 +266,7 @@ proc PSPrintDialog {which} {
     ttk::label $f.tname -text [msgcat::mc {Name}]
     ttk::entry $f.name -textvariable ed(filename) -width 20
     ttk::button $f.browse -text [msgcat::mc {Browse}] \
-	-command "PSPrintBrowse ed(filename)"
+	-command "PSPrintBrowse ed(filename) $w"
 
     grid $f.printer $f.tcmd $f.cmd -padx 2 -pady 2 -sticky ew
     grid $f.file $f.tname $f.name $f.browse -padx 2 -pady 2 -sticky ew
@@ -298,7 +290,21 @@ proc PSPrintDialog {which} {
     ttk::radiobutton $f.level3 -text "[msgcat::mc {Level}] 3" \
 	-variable ed(level) -value 3
     ttk::label $f.dpi -text [msgcat::mc {DPI}]
-    tk_optionMenu $f.resolution ed(resolution) 72 Screen 96 144 150 225 300 600 1200
+
+    set m $f.resolution
+    set mm $m.menu
+    ttk::menubutton $m -textvariable ed(resolution) -menu $mm
+    ThemeMenu $mm
+    $mm add radiobutton -label "72" -variable ed(resolution) -value 72
+    $mm add radiobutton -label [msgcat::mc {Screen}] \
+	-variable ed(resolution) -value 96
+    $mm add radiobutton -label "96" -variable ed(resolution) -value 96
+    $mm add radiobutton -label "144" -variable ed(resolution) -value 144
+    $mm add radiobutton -label "150" -variable ed(resolution) -value 150
+    $mm add radiobutton -label "225" -variable ed(resolution) -value 255
+    $mm add radiobutton -label "300" -variable ed(resolution) -value 300
+    $mm add radiobutton -label "600" -variable ed(resolution) -value 600
+    $mm add radiobutton -label "1200" -variable ed(resolution) -value 1200
 
     grid $f.color $f.rgb $f.cmyk $f.gray -padx 2 -pady 2 -sticky w
     grid $f.level $f.level3 $f.level2 $f.level1 -padx 2 -pady 2 -sticky w
@@ -321,9 +327,8 @@ proc PSPrintDialog {which} {
     grid rowconfigure $w 1 -weight 1
     grid columnconfigure $w 0 -weight 1
 
-    DialogCenter $w
     DialogWait $w ed(ok) $w.buttons.ok
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	array set ps [array get ed]
@@ -334,156 +339,11 @@ proc PSPrintDialog {which} {
     return $rr
 }
 
-proc PSPrintBrowse {varname} {
+proc PSPrintBrowse {varname parent} {
     upvar $varname var
 
     FileLast pssavfbox $var
-    set var [SaveFileDialog pssavfbox]
-}
-
-# Used for plots
-proc PlotPrintDialog {} {
-    global ps
-    global ed
-
-    set ed(ok) 0
-    array set ed [array get ps]
-
-    set w {.print}
-
-    DialogCreate $w [msgcat::mc {Print}] ed(ok)
-
-    # PrintTo
-    set f [ttk::labelframe $w.pt -text [msgcat::mc {Print To}]]
-
-    ttk::radiobutton $f.printer -text [msgcat::mc {Printer}] \
-	-variable ed(dest) -value printer
-    ttk::label $f.tcmd -text [msgcat::mc {Command}]
-    ttk::entry $f.cmd -textvariable ed(cmd) -width 20
-
-    ttk::radiobutton $f.file -text [msgcat::mc {File}] \
-	-variable ed(dest) -value file
-    ttk::label $f.tname -text [msgcat::mc {Name}]
-    ttk::entry $f.name -textvariable ed(filename) -width 20
-    ttk::button $f.browse -text [msgcat::mc {Browse}] \
-	-command "PlotPrintBrowse ed(filename)"
-
-    grid $f.printer $f.tcmd $f.cmd -padx 2 -pady 2 -sticky ew
-    grid $f.file $f.tname $f.name $f.browse -padx 2 -pady 2 -sticky ew
-    grid columnconfigure $f 2 -weight 1
-
-    # Options
-    set f [ttk::labelframe $w.ps -text [msgcat::mc {Postscript}]]
-
-    ttk::label $f.color -text [msgcat::mc {Color}]
-    ttk::radiobutton $f.rgb -text [msgcat::mc {RGB}] \
-	-variable ed(color) -value rgb 
-    ttk::radiobutton $f.gray -text [msgcat::mc {Grayscale}] \
-	-variable ed(color) -value gray 
-
-    grid $f.color $f.rgb $f.gray -padx 2 -pady 2 -sticky w
-
-    # Buttons
-    set f [ttk::frame $w.buttons]
-    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
-	-default active
-    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
-    pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
-
-    bind $w <Return> {set ed(ok) 1}
-
-    # Fini
-    grid $w.pt -sticky news
-    grid $w.ps -sticky news
-    grid $w.buttons -sticky ew
-    grid rowconfigure $w 0 -weight 1
-    grid rowconfigure $w 1 -weight 1
-    grid columnconfigure $w 0 -weight 1
-
-    DialogCenter $w
-    DialogWait $w ed(ok) $w.buttons.ok
-    DialogDismiss $w
-
-    if {$ed(ok)} {
-	array set ps [array get ed]
-    }
-
-    set rr $ed(ok)
-    unset ed
-    return $rr
-}
-
-proc PlotPrintBrowse {varname} {
-    upvar $varname var
-
-    FileLast apsavfbox $var
-    set var [SaveFileDialog apsavfbox]
-}
-
-# Used for SimpleText and Catalog
-proc PRPrintDialog {} {
-    global ps
-    global ed
-
-    set ed(ok) 0
-    array set ed [array get ps]
-
-    set w {.print}
-
-    DialogCreate $w [msgcat::mc {Print}] ed(ok)
-
-    # PrintTo
-    set f [ttk::labelframe $w.pt -text [msgcat::mc {Print To}]]
-
-    ttk::radiobutton $f.printer -text [msgcat::mc {Printer}] \
-	-variable ed(dest) -value printer
-    ttk::label $f.tcmd -text [msgcat::mc {Command}]
-    ttk::entry $f.cmd -textvariable ed(cmd) -width 20
-
-    ttk::radiobutton $f.file -text [msgcat::mc {File}] \
-	-variable ed(dest) -value file
-    ttk::label $f.tname -text [msgcat::mc {Name}]
-    ttk::entry $f.name -textvariable ed(filename,txt) -width 20
-    ttk::button $f.browse -text [msgcat::mc {Browse}] \
-	-command "PRPrintBrowse ed(filename,txt)"
-
-    grid $f.printer $f.tcmd $f.cmd -padx 2 -pady 2 -sticky ew
-    grid $f.file $f.tname $f.name $f.browse -padx 2 -pady 2 -sticky ew
-    grid columnconfigure $f 2 -weight 1
-
-    # Buttons
-    set f [ttk::frame $w.buttons]
-    ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
-	-default active
-    ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
-    pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
-
-    bind $w <Return> {set ed(ok) 1}
-
-    # Fini
-    grid $w.pt -sticky news
-    grid $w.buttons -sticky ew
-    grid rowconfigure $w 0 -weight 1
-    grid columnconfigure $w 0 -weight 1
-
-    DialogCenter $w
-    DialogWait $w ed(ok) $w.buttons.ok
-    DialogDismiss $w
-
-    if {$ed(ok)} {
-	array set ps [array get ed]
-    }
-
-    set rr $ed(ok)
-    unset ed
-    return $rr
-}
-
-proc PRPrintBrowse {varname} {
-    upvar $varname var
-
-    FileLast prsavfbox $var
-    set var [SaveFileDialog prsavfbox]
+    set var [SaveFileDialog pssavfbox $parent]
 }
 
 proc PrefsDialogPrint {} {
@@ -491,8 +351,8 @@ proc PrefsDialogPrint {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {Postscript}]
-    lappend dprefs(tabs) [ttk::frame $w.print]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.print] \
+	-text [msgcat::mc {Postscript}]
 
     # PrintTo
     set f [ttk::labelframe $w.print.printto -text [msgcat::mc {Print To}]]
@@ -530,7 +390,21 @@ proc PrefsDialogPrint {} {
     ttk::radiobutton $f.level3 -text "[msgcat::mc {Level}] 3" \
 	-variable pps(level) -value 3
     ttk::label $f.dpi -text [msgcat::mc {DPI}]
-    tk_optionMenu $f.resolution pps(resolution) 72 Screen 96 144 150 225 300 600 1200
+
+    set m $f.resolution
+    set mm $m.menu
+    ttk::menubutton $m -textvariable pps(resolution) -menu $mm
+    ThemeMenu $mm
+    $mm add radiobutton -label "72" -variable pps(resolution) -value 72
+    $mm add radiobutton -label [msgcat::mc {Screen}] \
+	-variable pps(resolution) -value 96
+    $mm add radiobutton -label "96" -variable pps(resolution) -value 96
+    $mm add radiobutton -label "144" -variable pps(resolution) -value 144
+    $mm add radiobutton -label "150" -variable pps(resolution) -value 150
+    $mm add radiobutton -label "225" -variable pps(resolution) -value 255
+    $mm add radiobutton -label "300" -variable pps(resolution) -value 300
+    $mm add radiobutton -label "600" -variable pps(resolution) -value 600
+    $mm add radiobutton -label "1200" -variable pps(resolution) -value 1200
 
     grid $f.color $f.rgb $f.cmyk $f.gray -padx 2 -pady 2 -sticky w
     grid $f.level $f.level3 $f.level2 $f.level1 -padx 2 -pady 2 -sticky w
