@@ -11,11 +11,8 @@ proc SAMPDef {} {
 }
 
 proc InitSAMP {} {
-    global pds9
-
-    if {$pds9(samp)} {
-	catch {SAMPConnect 0}
-    }
+    SAMPConnect 0
+#    catch {SAMPConnect 0}
 }
 
 # Cmds
@@ -392,7 +389,7 @@ proc SAMPSendTableLoadVotable {id varname} {
 
     # save votable
     set fn [tmpnam {.samp}]
-    CATSaveFn $varname $fn VOTWrite
+    TBLSaveFn $varname $fn VOTWrite
 
     # cmd
     catch {unset sampmap}
@@ -988,7 +985,7 @@ proc samp.client.receiveCall {args} {
 	    SAMPReplySimple $msgid "http://ds9.si.edu"
 	}
 	x-samp.releasenotes.url {
-	    SAMPReplySimple $msgid OK "http://ds9.si.edu/doc/release/r8.0.html"
+	    SAMPReplySimple $msgid OK "http://ds9.si.edu/doc/release/r8.1.html"
 	}
 	x-samp.faq.url {
 	    SAMPReplySimple $msgid OK "http://ds9.si.edu/doc/faq.html"
@@ -1701,6 +1698,16 @@ proc SAMPDelTmpFiles {} {
 
 # Cmds
 
+proc ProcessSAMPFirstCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    sampfirst::YY_FLUSH_BUFFER
+    sampfirst::yy_scan_string [lrange $var $i end]
+    sampfirst::yyparse
+    incr i [expr $sampfirst::yycnt-1]
+}
+
 proc ProcessSAMPCmd {varname iname} {
     upvar $varname var
     upvar $iname i
