@@ -76,10 +76,8 @@ proc ChangeScale {} {
 	    return {}
 	}
 
-	SetWatchCursor
 	RGBEvalLockCurrent rgb(lock,scale) [list $current(frame) colorscale log $scale(log)]
 	RGBEvalLockCurrent rgb(lock,scale) [list $current(frame) colorscale $scale(type)]
-	ResetWatchCursor
 	UpdateScale
     }
 }
@@ -94,9 +92,7 @@ proc ChangeScaleMode {} {
 	    return {}
 	}
 
-	SetWatchCursor
 	RGBEvalLockCurrent rgb(lock,scale) [list $current(frame) clip mode $scale(mode)]
-	ResetWatchCursor
 	UpdateScale
     }
 }
@@ -128,9 +124,7 @@ proc ChangeScaleScope {} {
 	    return {}
 	}
 
-	SetWatchCursor
 	RGBEvalLockCurrent rgb(lock,scale) [list $current(frame) clip scope $scale(scope)]
-	ResetWatchCursor
 	UpdateScale
     }
 }
@@ -147,6 +141,17 @@ proc ChangeMinMax {} {
     }
 }
 
+proc RescanMinMax {} {
+    global current
+    global minmax
+    global rgb
+
+    if {$current(frame) != {}} {
+	RGBEvalLockCurrent rgb(lock,scale) [list $current(frame) clip minmax rescan]
+	UpdateScale
+    }
+}
+
 proc ChangeZScale {} {
     global current
     global zscale
@@ -208,14 +213,15 @@ proc ScaleDialog {} {
     $mb add cascade -label [msgcat::mc {Parameters}] -menu $mb.param
     $mb add cascade -label [msgcat::mc {Graph}] -menu $mb.graph
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] -command ScaleApplyDialog
     $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command ScaleDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command ScaleDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb iscale
 
-    menu $mb.scale
+    ThemeMenu $mb.scale
     $mb.scale add radiobutton -label [msgcat::mc {Linear}] \
 	-variable scale(type) -command ChangeScale -value linear
     $mb.scale add radiobutton -label [msgcat::mc {Log}] \
@@ -236,7 +242,7 @@ proc ScaleDialog {} {
     $mb.scale add command -label "[msgcat::mc {Log Exponent}]..." \
 	-command ScaleLogDialog
 
-    menu $mb.limit
+    ThemeMenu $mb.limit
     $mb.limit add radiobutton -label [msgcat::mc {Min Max}] \
 	-variable scale(mode) -command ChangeScaleMode -value minmax
     $mb.limit add separator
@@ -264,13 +270,13 @@ proc ScaleDialog {} {
     $mb.limit add radiobutton -label [msgcat::mc {User}] \
 	-variable scale(mode) -command ChangeScaleMode -value user
 
-    menu $mb.scope 
+    ThemeMenu $mb.scope 
     $mb.scope add radiobutton -label [msgcat::mc {Global}] \
 	-variable scale(scope) -command ChangeScaleScope -value global
     $mb.scope add radiobutton -label [msgcat::mc {Local}] \
 	-variable scale(scope) -command ChangeScaleScope -value local
 
-    menu $mb.minmax 
+    ThemeMenu $mb.minmax 
     $mb.minmax add radiobutton -label [msgcat::mc {Scan}] \
 	-variable minmax(mode) -value scan -command ChangeMinMax
     $mb.minmax add radiobutton -label [msgcat::mc {Sample}] \
@@ -283,13 +289,13 @@ proc ScaleDialog {} {
     $mb.minmax add command -label "[msgcat::mc {Sample Parameters}]..." \
 	-command MinMaxDialog
 
-    menu $mb.param 
+    ThemeMenu $mb.param 
     $mb.param add checkbutton -label "[msgcat::mc {Use}] DATASEC" \
 	-variable scale(datasec) -command ChangeDATASEC
     $mb.param add separator
     $mb.param add command -label {ZScale...} -command ZScaleDialog
 
-    menu $mb.graph 
+    ThemeMenu $mb.graph 
     $mb.graph add radiobutton -label [msgcat::mc {Linear}] \
 	-value linear -variable scale(yaxis) -command ScaleYAxisDialog
     $mb.graph add radiobutton -label [msgcat::mc {Log}] \
@@ -300,40 +306,50 @@ proc ScaleDialog {} {
     $mb.graph add radiobutton -label [msgcat::mc {Current Range}] \
 	-value current -variable scale(xaxis) -command ScaleXAxisDialog
 
-    # Param
-    set f [ttk::frame $w.param]
-
     # Graph
+    set f [ttk::frame $w.ch]
+
     set dscale(hist) [blt::graph $f.chart \
-			  -foreground $ds9(gui,fg) \
-			  -background $ds9(gui,bg) \
-			  -plotbackground $ds9(gui,bg) \
 			  -width 500 \
 			  -height 200 \
 			  -title [msgcat::mc {Pixel Distribution}] \
 			  -font [font actual TkDefaultFont] \
 			  -plotrelief groove \
 			  -plotborderwidth 2 \
+			  -foreground [ThemeTreeForeground] \
+			  -background [ThemeTreeBackground] \
+			  -plotbackground [ThemeTreeBackground] \
 			 ]
 
     $dscale(hist) legend configure -hide yes
 
-    $dscale(hist) xaxis configure -hide yes -grid no -ticklength 3 \
+    $dscale(hist) xaxis configure \
+	-hide yes \
+	-grid no \
+	-ticklength 3 \
 	-tickfont [font actual TkDefaultFont] \
-	-bg $ds9(gui,bg) -color $ds9(gui,fg) \
-	-titlecolor $ds9(gui,fg)
+	-bg [ThemeTreeBackground] \
+	-color [ThemeTreeForeground] \
+	-titlecolor [ThemeTreeForeground]
 
-    $dscale(hist) yaxis configure -hide yes -grid yes -ticklength 3 \
+    $dscale(hist) yaxis configure \
+	-hide yes \
+	-grid yes \
+	-ticklength 3 \
 	-tickfont [font actual TkDefaultFont] \
-	-bg $ds9(gui,bg) -color $ds9(gui,fg) \
-	-titlecolor $ds9(gui,fg)
+	-bg [ThemeTreeBackground] \
+	-color [ThemeTreeForeground] \
+	-titlecolor [ThemeTreeForeground]
 
     set dscale(xdata) histX
     set dscale(ydata) histY
     blt::vector create $dscale(xdata) $dscale(ydata)
-    $dscale(hist) element create bar1 -smooth step  \
-	-xdata $dscale(xdata) -ydata $dscale(ydata) \
-	-areabackground $ds9(gui,fg) -color $ds9(gui,fg)
+    $dscale(hist) element create bar1 \
+	-smooth step  \
+	-xdata $dscale(xdata) \
+	-ydata $dscale(ydata) \
+	-areabackground [ThemeTreeForeground] \
+	-color [ThemeTreeForeground]
 
     # Cut Lines
     $dscale(hist) marker bind min <B1-Motion> \
@@ -342,12 +358,20 @@ proc ScaleDialog {} {
 	[list ScaleMotionDialog %x %y dscale(max)]
     $dscale(hist) marker bind up <ButtonRelease-1> ScaleReleaseDialog
 
-    set dscale(histmin) [$dscale(hist) marker create line -element bar1 \
-			     -outline red -bindtags [list min up]]
-    set dscale(histmax) [$dscale(hist) marker create line -element bar1 \
-			     -outline green -bindtags [list max up]]
+    set dscale(histmin) [$dscale(hist) marker create line \
+			     -element bar1 \
+			     -outline red \
+			     -bindtags [list min up] \
+			    ]
+    set dscale(histmax) [$dscale(hist) marker create line \
+			     -element bar1 \
+			     -outline green \
+			     -bindtags [list max up] \
+			    ]
 
     # Cut Levels
+    set f [ttk::frame $w.param]
+
     ttk::label $f.title -text [msgcat::mc {Limits}]
     ttk::label $f.ltitle -text [msgcat::mc {Low}]
     ttk::entry $f.lvalue -textvariable dscale(min) -width 13
@@ -365,13 +389,35 @@ proc ScaleDialog {} {
     pack $f.apply $f.close -side left -expand true -padx 2 -pady 4
 
     # Fini
+    pack $w.ch -side top -fill both -expand true
     ttk::separator $w.sep -orient horizontal
-    pack $w.buttons $w.sep -side bottom -fill x
-    pack $w.param -side top -fill both -expand true
+    ttk::separator $w.sep2 -orient horizontal
+    pack $w.buttons $w.sep2 $w.param $w.sep -side bottom -fill x
+
+    bind $w <<Close>> ScaleDestroyDialog
+
+    switch $ds9(wm) {
+	x11 -
+	win32 {bind $dscale(hist) <<ThemeChanged>> {ThemeConfigScale %W}}
+	aqua {}
+    }
 
     UpdateScaleDialog
 }
 
+proc ThemeConfigScale {w} {
+    $w configure -foreground [ThemeTreeForeground] \
+	-background [ThemeTreeBackground] -plotbackground [ThemeTreeBackground]
+
+    $w xaxis configure -bg [ThemeTreeBackground] -color [ThemeTreeForeground] \
+	-titlecolor [ThemeTreeForeground]
+    $w yaxis configure -bg [ThemeTreeBackground] -color [ThemeTreeForeground] \
+	-titlecolor [ThemeTreeForeground]
+
+    $w element configure bar1 -areabackground [ThemeTreeForeground] \
+	-color [ThemeTreeForeground]
+}
+
 proc ScaleApplyDialog {} {
     global scale
     global dscale
@@ -623,9 +669,8 @@ proc MinMaxDialog {} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	if {$ed(sample) == 0} {
@@ -674,9 +719,8 @@ proc ZScaleDialog {} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w 
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     if {$ed(ok)} {
 	if {$ed(line) == 0} {
@@ -741,8 +785,8 @@ proc MatchScaleLimits {which} {
     global rgb
     global scale
 
-    set limits [$which get clip]
     set mode user
+    set limits [$which get clip]
     set type [$which get colorscale]
     set log  [$which get colorscale log]
     set scope [$which get clip scope]
@@ -752,18 +796,17 @@ proc MatchScaleLimits {which} {
     set zssample [$which get clip zscale sample]
     set zsline [$which get clip zscale line]
 
+    # do all frames as we are changing mode to user
     foreach ff $ds9(frames) {
-	if {$ff != $which} {
-	    RGBEvalLock rgb(lock,scalelimits) $ff [list $ff colorscale $type]
-	    RGBEvalLock rgb(lock,scalelimits) $ff [list $ff colorscale log $log]
-	    RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip user $limits]
-	    RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip mode $mode]
-	    RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip scope $scope]
-	    RGBEvalLock rgb(lock,scalelimits) $ff \
-		[list $ff clip minmax $mmsample $mmmode]
-	    RGBEvalLock rgb(lock,scalelimits) $ff \
-		[list $ff clip zscale $zscontrast $zssample $zsline]
-	}
+	RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip mode $mode]
+	RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip user $limits]
+	RGBEvalLock rgb(lock,scalelimits) $ff [list $ff colorscale $type]
+	RGBEvalLock rgb(lock,scalelimits) $ff [list $ff colorscale log $log]
+	RGBEvalLock rgb(lock,scalelimits) $ff [list $ff clip scope $scope]
+	RGBEvalLock rgb(lock,scalelimits) $ff \
+	    [list $ff clip minmax $mmsample $mmmode]
+	RGBEvalLock rgb(lock,scalelimits) $ff \
+	    [list $ff clip zscale $zscontrast $zssample $zsline]
     }
 }
 
