@@ -5,7 +5,7 @@
 package provide DS9 1.0
 
 # used by backup
-proc SIADialog {varname title url opts method action} {
+proc SIADialog {varname title url opts action} {
     global sia
     global isia
     global psia
@@ -18,7 +18,7 @@ proc SIADialog {varname title url opts method action} {
 
     global debug
     if {$debug(tcl,sia)} {
-	puts stderr "SIADialog $varname:$title:$url:$opts:$action:$method"
+	puts stderr "SIADialog $varname:$title:$url:$opts:$action:"
     }
 
     # main dialog
@@ -38,9 +38,11 @@ proc SIADialog {varname title url opts method action} {
     # AR variables
     ARInit $varname SIAServer
 
-    # IMG variables
-    set var(proc,done) SIADone
+    # procs
+    set var(proc,process) SIAProcess
+    set var(proc,load) SIALoad
     set var(proc,error) SIAError
+    set var(proc,done) SIADone
 
     # SIA variables
     lappend isia(sias) $varname
@@ -58,7 +60,6 @@ proc SIADialog {varname title url opts method action} {
     set var(url) $url
     set var(title) $title
     set var(opts) $opts
-    set var(method) $method
 
     # create the window
     set w $var(top)
@@ -73,9 +74,9 @@ proc SIADialog {varname title url opts method action} {
     $mb add cascade -label [msgcat::mc {Preferences}] -menu $mb.prefs
 
     # file
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label "[msgcat::mc {Save}]..." \
-	-command [list CATSaveVOTFile $varname]
+	-command [list TBLSaveVOTFile $varname] -accelerator "${ds9(ctrl)}S"
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {Export}] -menu $mb.file.export
     $mb.file add separator
@@ -96,24 +97,24 @@ proc SIADialog {varname title url opts method action} {
 	-command [list SIACrosshair $varname]
     $mb.file add separator
     $mb.file add command -label "[msgcat::mc {Print}]..." \
-	-command [list CATPrint $varname]
+	-command [list TBLPrint $varname] -accelerator "${ds9(ctrl)}P"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command [list SIADestroy $varname]
+	-command [list SIADestroy $varname] -accelerator "${ds9(ctrl)}W"
 
     # Export
-    menu $mb.file.export
+    ThemeMenu $mb.file.export
     $mb.file.export add command -label "[msgcat::mc {Starbase}]..." \
-	-command [list CATSaveSBFile $varname]
+	-command [list TBLSaveRDBFile $varname]
     $mb.file.export add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
-	-command [list CATSaveTSVFile $varname]
+	-command [list TBLSaveTSVFile $varname]
 
     # edit
-    menu $mb.edit
+    ThemeMenu $mb.edit
     $mb.edit add command -label [msgcat::mc {Cut}] \
-	-command "CATCut $varname" -accelerator "${ds9(ctrl)}X"
+	-command "TBLCut $varname" -accelerator "${ds9(ctrl)}X"
     $mb.edit add command -label [msgcat::mc {Copy}] \
-	-command "CATCopy $varname" -accelerator "${ds9(ctrl)}C"
+	-command "TBLCopy $varname" -accelerator "${ds9(ctrl)}C"
     $mb.edit add command -label [msgcat::mc {Paste}] \
 	-command "EntryPaste $var(top)" -accelerator "${ds9(ctrl)}V"
     $mb.edit add separator
@@ -121,7 +122,7 @@ proc SIADialog {varname title url opts method action} {
 	-command [list ARClear $varname]
 
     # prefs
-    menu $mb.prefs
+    ThemeMenu $mb.prefs
     $mb.prefs add checkbutton -label [msgcat::mc {Save Image on Download}] \
 	-variable ${varname}(save)
     $mb.prefs add separator
@@ -142,7 +143,7 @@ proc SIADialog {varname title url opts method action} {
     ttk::entry $f.y -textvariable ${varname}(y) -width 14
 
     CoordMenuButton $f.coord $varname system 0 sky skyformat \
-	[list SIAWCSMenuUpdate $varname]
+	[list TBLWCSMenuUpdate $varname]
     CoordMenuEnable $f.coord.menu $varname system sky skyformat
 
     ttk::label $f.rtitle -text [msgcat::mc {Radius}]
@@ -179,6 +180,7 @@ proc SIADialog {varname title url opts method action} {
 		      -maxwidth 300 \
 		      -maxheight 300 \
 		      -titlerows 1 \
+		      -resizeborders col \
 		      -xscrollcommand [list $f.xscroll set]\
 		      -yscrollcommand [list $f.yscroll set]\
 		      -selecttype row \
@@ -186,9 +188,14 @@ proc SIADialog {varname title url opts method action} {
 		      -anchor w \
 		      -font [font actual TkDefaultFont] \
 		      -browsecommand [list SIASelectCmd $varname %s %S] \
-		      -fg $ds9(gui,fg) -bg $ds9(gui,bg) \
+		      -fg [ThemeTreeForeground] \
+		      -bg [ThemeTreeBackground] \
 		     ]
 
+    $var(tbl) tag configure sel \
+	-fg [ThemeSelectedForeground] -bg [ThemeSelectedBackground]
+    $var(tbl) tag configure title -fg [ThemeForeground] -bg [ThemeBackground]
+
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] -orient vertical
     ttk::scrollbar $f.xscroll -command [list $var(tbl) xview] -orient horizontal
 
@@ -197,6 +204,8 @@ proc SIADialog {varname title url opts method action} {
     grid rowconfigure $f 0 -weight 1
     grid columnconfigure $f 0 -weight 1
 
+    TBLBindMouseWheel $varname
+
     # Status
     set f [ttk::frame $w.status]
 
@@ -233,6 +242,10 @@ proc SIADialog {varname title url opts method action} {
     pack $w.obj $w.param -side top -fill x
     pack $w.tbl -side top -fill both -expand true
 
+    bind $w <<Save>> [list TBLSaveVOTFile $varname]
+    bind $w <<Close>> [list SIADestroy $varname]
+    bind $w <<Print>> [list TBLPrint $varname]
+
     ARCoord $varname
     SIAUpdate $varname
     SIADialogUpdate $varname
@@ -253,11 +266,6 @@ proc SIAApply {varname sync} {
     upvar #0 $varname var
     global $varname
 
-    global debug
-    if {$debug(tcl,sia)} {
-	puts stderr "SIAApply $varname $sync"
-    }
-
     set var(sync) $sync
     ARApply $varname
     $var(mb).file entryconfig [msgcat::mc {Load}] -state disabled
@@ -266,7 +274,7 @@ proc SIAApply {varname sync} {
     if {$var(name) != {}} {
 	set var(sky) fk5
 	CoordMenuButtonCmd $varname system sky {}
-	SIAWCSMenuUpdate $varname
+	TBLWCSMenuUpdate $varname
 
 	NSVRServer $varname
     } else {
@@ -274,6 +282,64 @@ proc SIAApply {varname sync} {
     }
 }
 
+proc SIAServer {varname} {
+    upvar #0 $varname var
+    global $varname
+    global current
+
+    global debug
+    if {$debug(tcl,image)} {
+	puts stderr "SIAServer $varname"
+    }
+
+    if {($var(x) != {}) && ($var(y) != {}) && ($var(radius) != {})} {
+	ARStatus $varname [msgcat::mc {Contacting Server}]
+	SIAVOT $varname
+    } else {
+	eval [list $var(proc,error) $varname [msgcat::mc {Please specify radius and either name or (ra,dec)}]]
+    }
+}
+
+proc SIAVOT {varname} {
+    upvar #0 $varname var
+    global $varname
+
+    global debug
+    if {$debug(tcl,sia)} {
+	puts stderr "SIAVOT $varname"
+    }
+
+    # coord (degrees)
+    switch $var(skyformat) {
+	degrees {
+	    set xx $var(x)
+	    set yy $var(y)
+	}
+	sexagesimal {
+	    set xx [h2d [Sex2H $var(x)]]
+	    set yy [Sex2D $var(y)]
+	}
+    }
+
+    # radius (degrees)
+    switch $var(rformat) {
+	degrees {
+	    set rr $var(radius)
+	}
+	arcmin {
+	    set rr [expr $var(radius)/60.]
+	}
+	arcsec {
+	    set rr [expr $var(radius)/60./60.]
+	}
+    }
+
+    # query
+    set query "$var(opts)[http::formatQuery POS "$xx,$yy" SIZE $rr FORMAT image/fits]"
+
+    SIALoad $varname $var(url) $query
+}
+
 proc SIADestroy {varname} {
     upvar #0 $varname var
     global $varname
@@ -346,7 +412,7 @@ proc SIADialogUpdate {varname} {
     }
 
     # do we have a db?
-    if {[CATValidDB $var(tbldb)]} {
+    if {[TBLValidDB $var(tbldb)]} {
 	$var(mb).file entryconfig [msgcat::mc {Clear}] -state normal
 	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state normal
 
@@ -371,7 +437,7 @@ proc SIAImageCmd {varname} {
     }
 
     global $var(tbldb)
-    if {![CATValidDB $var(tbldb)]} {
+    if {![TBLValidDB $var(tbldb)]} {
 	return
     }
 
@@ -396,7 +462,7 @@ proc SIAImageCmd {varname} {
 	    http -
 	    https {
 		if {$var(save)} {
-		    set var(fn) [SaveFileDialog savefitsfbox]
+		    set var(fn) [SaveFileDialog savefitsfbox $var(top)]
 		    if {$var(fn) == {}} {
 			SIADone $varname
 			return
@@ -408,7 +474,7 @@ proc SIAImageCmd {varname} {
 		IMGSVRGetURL $varname $url {}
 	    }
 	    default {
-		SIAError $varname "$r(scheme) [msgcat::mc {Not Supported}]"
+		eval [list $var(proc,error) $varname "$r(scheme) [msgcat::mc {Not Supported}]"]
 		return
 	    }
 	}
@@ -426,57 +492,6 @@ proc SIASelectCmd {varname ss rc} {
     }
 }
 
-proc SIAVOT {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    global debug
-    if {$debug(tcl,sia)} {
-	puts stderr "SIAVOT $varname"
-    }
-
-    # coord (degrees)
-    switch $var(skyformat) {
-	degrees {
-	    set xx $var(x)
-	    set yy $var(y)
-	}
-	sexagesimal {
-	    set xx [h2d [Sex2H $var(x)]]
-	    set yy [Sex2D $var(y)]
-	}
-    }
-
-    # radius (degrees)
-    switch $var(rformat) {
-	degrees {
-	    set rr $var(radius)
-	}
-	arcmin {
-	    set rr [expr $var(radius)/60.]
-	}
-	arcsec {
-	    set rr [expr $var(radius)/60./60.]
-	}
-    }
-
-    # query
-    set query "$var(opts)[http::formatQuery POS "$xx,$yy" SIZE $rr FORMAT image/fits]"
-
-    SIALoad $varname $var(url) $query
-}
-
-proc SIAWCSMenuUpdate {varname} {
-    upvar #0 $varname var
-    global $varname
-
-    ARCoord $varname
-
-    set var(psystem) $var(system)
-    set var(psky) $var(sky)
-    CoordMenuButtonCmd $varname psystem psky {}
-}
-
 proc SIAUpdate {varname} {
     upvar #0 $varname var
     global $varname
@@ -543,20 +558,3 @@ proc SIACrosshair {varname} {
     }
 }
 
-proc SIAServer {varname} {
-    upvar #0 $varname var
-    global $varname
-    global current
-
-    global debug
-    if {$debug(tcl,image)} {
-	puts stderr "SIAServer $varname"
-    }
-
-    if {($var(x) != {}) && ($var(y) != {}) && ($var(radius) != {})} {
-	ARStatus $varname [msgcat::mc {Contacting Image Server}]
-	SIAVOT $varname
-    } else {
-	SIAError $varname [msgcat::mc {Please specify radius and either name or (ra,dec)}]
-    }
-}
