@@ -6,10 +6,6 @@ package provide DS9 1.0
 
 # do this after the language has been defined and the prefs sourced
 proc InitDialogBox {} {
-    global ds9
-    global pds9
-    global env
-
     global fitsurl
     set fitsurl {}
 
@@ -136,6 +132,41 @@ proc InitDialogBox {} {
 			     [list {MPEG} {*.mpg}] \
 			    ]
 
+    global votfbox
+    set votfbox(file) {ds9.xml}
+    set votfbox(dir) {}
+    set votfbox(types) [list \
+			       [list [::msgcat::mc {VOT}] {*.xml}] \
+			       [list [::msgcat::mc {VOT}] {*.vot}] \
+			       [list [::msgcat::mc {VOT}] {*.votable}] \
+			      ]
+
+    global rdbfbox
+    set rdbfbox(file) {ds9.rdb}
+    set rdbfbox(dir) {}
+    set rdbfbox(types) [list \
+			    [list [::msgcat::mc {RDB}] {*.cat}] \
+			    [list [::msgcat::mc {RDB}] {*.rdb}] \
+			   ]
+
+    global tsvfbox
+    set tsvfbox(file) {ds9.tsv}
+    set tsvfbox(dir) {}
+    set tsvfbox(types) [list \
+			       [list [::msgcat::mc {TSV}] {*.tsv}] \
+			       [list [::msgcat::mc {TSV}] {*.csv}] \
+			      ]
+
+    global catfitsfbox
+    set catfitsfbox(file) {cat.fits}
+    set catfitsfbox(dir) {}
+    set catfitsfbox(types) [list \
+				 [list {FITS} {*.fits}] \
+				 [list {FITS} {*.fit}] \
+				 [list {FITS} {*.fts}] \
+				 [list {FITS} {*.fits.gz}] \
+				]
+
     global pixelfbox
     set pixelfbox(file) {ds9.pix}
     set pixelfbox(dir) {}
@@ -235,31 +266,6 @@ proc InitDialogBox {} {
 			     [list {GRD} {*.grd}] \
 			    ]
 
-    global catfbox
-    set catfbox(file) {ds9.cat}
-    set catfbox(dir) {}
-    set catfbox(types) [list \
-			    [list [::msgcat::mc {Catalog}] {*.cat}] \
-			    [list [::msgcat::mc {Catalog}] {*.rdb}] \
-			   ]
-
-    global cattsvfbox
-    set cattsvfbox(file) {ds9.tsv}
-    set cattsvfbox(dir) {}
-    set cattsvfbox(types) [list \
-			       [list [::msgcat::mc {Catalog}] {*.tsv}] \
-			       [list [::msgcat::mc {Catalog}] {*.csv}] \
-			      ]
-
-    global catvotfbox
-    set catvotfbox(file) {ds9.xml}
-    set catvotfbox(dir) {}
-    set catvotfbox(types) [list \
-			       [list [::msgcat::mc {Catalog}] {*.xml}] \
-			       [list [::msgcat::mc {Catalog}] {*.vot}] \
-			       [list [::msgcat::mc {Catalog}] {*.votable}] \
-			      ]
-
     global catfltfbox
     set catfltfbox(file) {ds9.flt}
     set catfltfbox(dir) {}
@@ -301,7 +307,7 @@ proc InitDialogBox {} {
     set analysisparamfbox(dir) {}
     # MacOS needs a default file type
     set analysisparamfbox(types) [list \
-				      [list [::msgcat::mc {Analysis}] {*.dat}]\
+				      [list [::msgcat::mc {All}] {}]\
 				     ]
 
     global apsavfbox
@@ -361,6 +367,13 @@ proc InitDialogBox {} {
 			       [list {BCK} {*.bck}] \
 			      ]
 
+    global plotbackupfbox
+    set plotbackupfbox(file) {ds9.plb}
+    set plotbackupfbox(dir) {}
+    set plotbackupfbox(types) [list \
+			       [list {PLB} {*.plb}] \
+			      ]
+
 }
 
 proc SetFileLast {format item} {
@@ -435,27 +448,38 @@ proc ExtToFormat {fn} {
 }
 
 # used by backup
-proc OpenFileDialog {varname} {
-    return [FileDialog $varname tk_getOpenFile]
+proc OpenFileDialog {varname {parent {}}} {
+    global ds9
+
+    if {$parent == {}} {
+	set parent $ds9(top)
+    }
+
+    return [FileDialog $varname tk_getOpenFile $parent]
 }
 
-proc SaveFileDialog {varname} {
-    return [FileDialog $varname tk_getSaveFile]
+proc SaveFileDialog {varname {parent {}}} {
+    global ds9
+
+    if {$parent == {}} {
+	set parent $ds9(top)
+    }
+
+    return [FileDialog $varname tk_getSaveFile $parent]
 }
 
-proc FileDialog {varname which} {
+proc FileDialog {varname which parent} {
     global pds9
 
     switch -- $pds9(dialog) {
-	motif {return [FileDialogMotif $varname $which]}
-	windows {return [FileDialogWindows $varname $which]}
-	native {return [FileDialogNative $varname $which]}
+	motif {return [FileDialogMotif $varname $which $parent]}
+	windows {return [FileDialogWindows $varname $which $parent]}
+	native {return [FileDialogNative $varname $which $parent]}
     }
 }
 
-proc FileDialogMotif {varname which} {
+proc FileDialogMotif {varname which parent} {
     upvar #0 $varname var
-    global ds9
     global pds9
 
     switch -- $which {
@@ -474,7 +498,7 @@ proc FileDialogMotif {varname which} {
 		    -filetypes $types \
 		    -initialdir $var(dir) \
 		    -initialfile $var(file) \
-		    -parent $ds9(top)]
+		    -parent $parent]
 
     if {$result != {}} {
 	set var(file) [file tail $result]
@@ -484,9 +508,8 @@ proc FileDialogMotif {varname which} {
     return $result
 }
 
-proc FileDialogWindows {varname which} {
+proc FileDialogWindows {varname which parent} {
     upvar #0 $varname var
-    global ds9
     global pds9
 
     switch -- $which {
@@ -504,7 +527,7 @@ proc FileDialogWindows {varname which} {
 		    -filetypes $types \
 		    -initialdir $var(dir) \
 		    -initialfile $var(file) \
-		    -parent $ds9(top)]
+		    -parent $parent]
 
     if {$result != {}} {
 	set var(file) [file tail $result]
@@ -514,9 +537,8 @@ proc FileDialogWindows {varname which} {
     return $result
 }
 
-proc FileDialogNative {varname which} {
+proc FileDialogNative {varname which parent} {
     upvar #0 $varname var
-    global ds9
     global pds9
 
     if {$pds9(dialog,all)} {
@@ -529,17 +551,17 @@ proc FileDialogNative {varname which} {
 		    -filetypes $types \
 		    -initialdir $var(dir) \
 		    -initialfile $var(file) \
-		    -parent $ds9(top)} result]} {
+		    -parent $parent} result]} {
 
 	# must have a bad file name, just clear and try again
 	set var(file) {}
 	set var(dir) {}
 	if {[catch {$which \
 			-filetypes $types \
-			-parent $ds9(top)} result]} {
+			-parent $parent} result]} {
 
 	    #ok, something is really wrong
-	    catch {$which -parent $ds9(top)} result
+	    catch {$which -parent $parent} result
 	}
     }
 
