@@ -154,6 +154,7 @@ proc UpdateMain {} {
 	pointer -
 	region -
 	catalog -
+	footprint -
 	colorbar -
 	pan -
 	zoom -
@@ -249,12 +250,10 @@ proc ProcessCmdFontStyle {varname key value {cmd {}}} {
 
 proc ProcessCmdCVAR0 {cmd} {
     global cvarname
-    eval $cmd $cvarname
-}
 
-proc ProcessCmdCVAROpt {cmd opt} {
-    global cvarname
-    eval $cmd $cvarname {$opt}
+    if {$cvarname != {}} {
+	eval $cmd $cvarname
+    }
 }
 
 proc ProcessCmdCVAR {key value {cmd {}}} {
@@ -262,7 +261,7 @@ proc ProcessCmdCVAR {key value {cmd {}}} {
     upvar #0 $cvarname cvar
 
     set cvar($key) $value
-    if {$cmd != {}} {
+    if {$cmd != {} && $cvarname != {}} {
 	eval $cmd $cvarname
     }
 }
@@ -273,7 +272,7 @@ proc ProcessCmdCVAR2 {key value key2 value2 {cmd {}}} {
 
     set cvar($key) $value
     set cvar($key2) $value2
-    if {$cmd != {}} {
+    if {$cmd != {} && $cvarname != {}} {
 	eval $cmd $cvarname
     }
 }
@@ -285,7 +284,7 @@ proc ProcessCmdCVAR3 {key value key2 value2 key3 value3 {cmd {}}} {
     set cvar($key) $value
     set cvar($key2) $value2
     set cvar($key3) $value3
-    if {$cmd != {}} {
+    if {$cmd != {} && $cvarname != {}} {
 	eval $cmd $cvarname
     }
 }
@@ -298,35 +297,71 @@ proc ProcessCmdCVAR4 {key value key2 value2 key3 value3 key4 value4 {cmd {}}} {
     set cvar($key2) $value2
     set cvar($key3) $value3
     set cvar($key4) $value4
-    if {$cmd != {}} {
+    if {$cmd != {} && $cvarname != {}} {
 	eval $cmd $cvarname
     }
 }
 
+proc ProcessCmdCVAR5 {key value key2 value2 key3 value3
+		      key4 value4 key5 value5 {cmd {}}} {
+    global cvarname
+    upvar #0 $cvarname cvar
+
+    set cvar($key) $value
+    set cvar($key2) $value2
+    set cvar($key3) $value3
+    set cvar($key4) $value4
+    set cvar($key5) $value5
+    if {$cmd != {} && $cvarname != {}} {
+	eval $cmd $cvarname
+    }
+}
+
+proc ProcessCmdCVAR6 {key value key2 value2 key3 value3
+		      key4 value4 key5 value5 key6 value6 {cmd {}}} {
+    global cvarname
+    upvar #0 $cvarname cvar
+
+    set cvar($key) $value
+    set cvar($key2) $value2
+    set cvar($key3) $value3
+    set cvar($key4) $value4
+    set cvar($key5) $value5
+    set cvar($key6) $value6
+    if {$cmd != {} && $cvarname != {}} {
+	eval $cmd $cvarname
+    }
+}
+
+proc ProcessCmdCVAROpt {cmd opt} {
+    global cvarname
+
+    if {$cvarname != {}} {
+	eval $cmd $cvarname {$opt}
+    }
+}
+
 proc ProcessSendCmd {cmd} {
     global parse
     $parse(proc) $parse(id) "[$cmd]"
 }
 
+proc ProcessSendCmdYesNo {varname key} {
+    upvar #0 $varname var
+    global $varname
+
+    global parse
+    $parse(proc) $parse(id) "[ToYesNo $var($key)]"
+}
+
 proc ProcessSendCmdCVAR {cmd} {
     global cvarname
     upvar #0 $cvarname cvar
 
     global parse
-    $parse(proc) $parse(id) "[$cmd $cvarname]"
-}
-
-proc ProcessSendCmdTxt {rr} {
-    global parse
-    $parse(proc) $parse(id) "$rr\n"
-}
-
-proc ProcessSendCmdGet {varname key} {
-    upvar #0 $varname var
-    global $varname
-
-    global parse
-    $parse(proc) $parse(id) "$var($key)\n"
+    if {$cmd != {} && $cvarname != {}} {
+	$parse(proc) $parse(id) "[$cmd $cvarname]"
+    }
 }
 
 proc ProcessSendCmdCVARGet {key} {
@@ -337,6 +372,22 @@ proc ProcessSendCmdCVARGet {key} {
     $parse(proc) $parse(id) "$cvar($key)\n"
 }
 
+proc ProcessSendCmdCVARGetYesNo {key} {
+    global cvarname
+    upvar #0 $cvarname cvar
+
+    global parse
+    $parse(proc) $parse(id) [ToYesNo $cvar($key)]
+}
+
+proc ProcessSendCmdGet {varname key} {
+    upvar #0 $varname var
+    global $varname
+
+    global parse
+    $parse(proc) $parse(id) "$var($key)\n"
+}
+
 proc ProcessSendCmdGet2 {varname key key2} {
     upvar #0 $varname var
     global $varname
@@ -353,28 +404,12 @@ proc ProcessSendCmdGet3 {varname key key2 key3} {
     $parse(proc) $parse(id) "$var($key) $var($key2) $var($key3)\n"
 }
 
-proc ProcessSendCmdGet6 {varname key key2 key3 key4 key5 key6} {
+proc ProcessSendCmdGet9 {varname key key2 key3 key4 key5 key6 key7 key8 key9} {
     upvar #0 $varname var
     global $varname
 
     global parse
-    $parse(proc) $parse(id) "$var($key) $var($key2) $var($key3) $var($key4) $var($key5) $var($key6)\n"
-}
-
-proc ProcessSendCmdYesNo {varname key} {
-    upvar #0 $varname var
-    global $varname
-
-    global parse
-    $parse(proc) $parse(id) [ToYesNo $var($key)]
-}
-
-proc ProcessSendCmdCVARYesNo {key} {
-    global cvarname
-    upvar #0 $cvarname cvar
-
-    global parse
-    $parse(proc) $parse(id) [ToYesNo $cvar($key)]
+    $parse(proc) $parse(id) "$var($key) $var($key2) $var($key3) $var($key4) $var($key5) $var($key6) $var($key7) $var($key8) $var($key9)\n"
 }
 
 proc ProcessSendCmdCurrent {cmd} {
@@ -395,6 +430,11 @@ proc ProcessSendCmdCurrentYesNo {cmd} {
     }
 }
 
+proc ProcessSendCmdTxt {rr} {
+    global parse
+    $parse(proc) $parse(id) "$rr\n"
+}
+
 proc ProcessSendCmdSend {ext cmd} {
     global parse
     global current
@@ -417,37 +457,6 @@ proc ProcessSend {proc id sock fn ext rr} {
     }
 }
 
-proc Toplevel {w mb style title proc} {
-    global ds9
-
-    toplevel $w
-    switch $ds9(wm) {
-	x11 {}
-	aqua {
-	    switch $style {
-		6 {::tk::unsupported::MacWindowStyle style $w document "closeBox collapseBox"}
-		7 {::tk::unsupported::MacWindowStyle style $w document "closeBox fullZoom collapseBox resizable"}
-	    }
-	}
-	win32 {}
-    }
-
-    wm title $w $title
-    wm iconname $w $title
-    wm group $w $ds9(top)
-    wm protocol $w WM_DELETE_WINDOW $proc
-
-    # we need this first, before the configure command
-    menu $mb
-    AppleMenu $mb
-    $w configure -menu $mb
-
-    global pds9
-    if {$pds9(dialog,center)} {
-	DialogCenter $w
-    }
-}
-
 proc SourceInitFileDir {ext} {
     global ds9
     
@@ -700,25 +709,20 @@ proc ProcessRealizeDS9 {} {
     }
 }
 
-proc RealizeDS9 {{preserve 0}} {
+proc RealizeDS9 {} {
     # this has to come first, to realize the canvas
     global debug
     if {$debug(tcl,idletasks)} {
 	puts stderr "RealizeDS9"
     }
 
-    # update all frames
     global ds9
     foreach ff $ds9(frames) {
-	if {$preserve} {
-	    $ff 3d preserve
-	}
-	$ff update now
+	# get all frames ready
+	$ff update
     }
 
-# idletasks fails for windows. we need to process all events to make
-# sure all windows are realized
-#    update idletasks
+    # now all update all at once
     update
 }
 
@@ -777,35 +781,6 @@ proc SetCursor {cursor} {
     }
 }
 
-proc SetWatchCursor {} {
-    global ds9
-    global icursor
-
-    # we don't want to update during initialization
-    if {$ds9(init)} {
-	return
-    }
-
-    set icursor(save) [$ds9(canvas) cget -cursor]
-    $ds9(canvas) configure -cursor {}
-    $ds9(main) configure -cursor watch
-
-    update
-}
-
-proc ResetWatchCursor {} {
-    global ds9
-    global icursor
-
-    # we don't want to update during initialization
-    if {$ds9(init)} {
-	return
-    }
-
-    $ds9(main) configure -cursor {}
-    $ds9(canvas) configure -cursor $icursor(save)
-}
-
 proc CursorTimer {} {
     global ds9
     global icursor
@@ -842,7 +817,7 @@ proc AboutBox {} {
     DialogCreate $w [msgcat::mc {About SAOImageDS9}] ed(ok)
 
     # Param
-    set f [frame $w.param -background white]
+    set f [ttk::frame $w.param]
     canvas $f.c -background white -height 450 -width 500
     pack $f.c -fill both -expand true
     
@@ -864,9 +839,8 @@ proc AboutBox {} {
     pack $w.buttons $w.sep -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
-    DialogCenter $w
     DialogWait $w ed(ok)
-    DialogDismiss $w
+    destroy $w
 
     image delete $ed(sun)
     unset ed
@@ -926,18 +900,13 @@ proc OpenConsole {} {
 	set ::tkcon::OPT(exec) {}
 	set ::tkcon::OPT(font) [font actual TkFixedFont]
 	
-	set ::tkcon::COLOR(bg) $ds9(gui,bg)
-#	set ::tkcon::COLOR(blink) $ds9(gui,fg)
-	set ::tkcon::COLOR(cursor) $ds9(gui,fg)
-#	set ::tkcon::COLOR(disabled) $ds9(gui,bg)
-#	set ::tkcon::COLOR(proc) $ds9(gui,bg)
-#	set ::tkcon::COLOR(var) $ds9(gui,bg)
-	set ::tkcon::COLOR(prompt) $ds9(gui,fg)
-	set ::tkcon::COLOR(stdin) $ds9(gui,fg)
-	set ::tkcon::COLOR(stdout) $ds9(gui,fg)
-	set ::tkcon::COLOR(stderr) $ds9(gui,fg)
-
 	tkcon::Init
+
+	switch $ds9(wm) {
+	    x11 -
+	    win32 {bind $::tkcon::PRIV(curtab) <<ThemeChanged>> {break}}
+	    aqua {}
+	}
     }
 }
 
@@ -959,10 +928,6 @@ proc ChangeMode {} {
     global ds9
     global current
 
-    bind $ds9(canvas) <Button-1> {}
-    bind $ds9(canvas) <B1-Motion> {}
-    bind $ds9(canvas) <ButtonRelease-1> {}
-
     foreach ff $ds9(frames) {
 	$ff crosshair off
 	$ff marker catalog unselect all
@@ -981,7 +946,8 @@ proc ChangeMode {} {
 	none -
 	pointer -
 	region -
-	catalog {SetCursor {}}
+	catalog -
+	footprint {SetCursor {}}
 	crosshair {
 	    foreach ff $ds9(frames) {
 		$ff crosshair on
@@ -999,6 +965,13 @@ proc ChangeMode {} {
     }
 }
 
+proc ChangeModeItem {which} {
+    global current
+
+    set current(mode) $which
+    ChangeMode
+}
+
 # Font procs
 
 proc InitDefaultFont {} {
@@ -1062,9 +1035,15 @@ proc SetDefaultFont {which} {
     }
 
     if {$which} {
+	global icat
+	global isia
+	global ifp
+
 	UpdateScaleDialogFont
 	UpdateGraphFont
-	CATUpdateFont
+	TBLUpdateFont $icat(cats)
+	TBLUpdateFont $isia(sias)
+	TBLUpdateFont $ifp(fps)
     }
 }
 
@@ -1087,6 +1066,7 @@ proc PrefsBgColor {} {
 
     foreach ff $ds9(frames) {
 	$ff bg color $pds9(bg)
+	$ff bg color $pds9(bg,use)
     }
 }
 
@@ -1411,6 +1391,7 @@ proc DS9Backup {ch which} {
     puts $ch "$which precision $pds9(prec,linear) $pds9(prec,deg) $pds9(prec,hms) $pds9(prec,dms) $pds9(prec,len,linear) $pds9(prec,len,deg) $pds9(prec,len,arcmin) $pds9(prec,len,arcsec) $pds9(prec,angle)"
 
     puts $ch "$which bg color $pds9(bg)"
+    puts $ch "$which bg color $pds9(bg,use)"
     puts $ch "$which nan color $pds9(nan)"
 }
 
@@ -1446,6 +1427,12 @@ proc ProcessSendPrefsCmd {proc id param {sock {}} {fn {}}} {
     prefssend::yyparse
 }
 
+proc PrefsSendCmdPrecision {} {
+    global parse
+
+    ProcessSendPrecisionCmd $parse(proc) $parse(id) {}
+}
+
 proc ProcessPrecisionCmd {varname iname} {
     upvar $varname var
     upvar $iname i
@@ -1458,6 +1445,7 @@ proc ProcessPrecisionCmd {varname iname} {
 
 proc ProcessSendPrecisionCmd {proc id param {sock {}} {fn {}}} {
     global pds9
+
     $proc $id "$pds9(prec,linear) $pds9(prec,deg) $pds9(prec,hms) $pds9(prec,dms) $pds9(prec,len,linear) $pds9(prec,len,deg) $pds9(prec,len,arcmin) $pds9(prec,len,arcsec) $pds9(prec,angle)\n"
 }
 
@@ -1553,8 +1541,9 @@ proc CursorCmd {x y} {
     switch -- $current(mode) {
 	none {$current(frame) warp $x $y}
 	pointer -
-	region {MarkerArrowKey $current(frame) $x $y}
-	catalog {MarkerArrowKey $current(frame) $x $y}
+	region -
+	catalog -
+	footprint {MarkerArrowKey $current(frame) $x $y}
 	crosshair {CrosshairArrowKey $current(frame) $x $y}
 	colorbar {}
 	pan {PanCanvas $x $y}
@@ -1735,12 +1724,16 @@ proc ProcessTclCmd {varname iname buf fn} {
 proc ProcessThemeCmd {varname iname} {
     upvar $varname var
     upvar $iname i
+
+    global pds9
+    set pds9(theme) [lindex $var $i]
+    ThemeChange
 }
 
 # backward compatibility
 proc ProcessSendThemeCmd {proc id param {sock {}} {fn {}}} {
     global pds9
-    $proc $id "native\n"
+    $proc $id "$pds9(theme)\n"
 }
 
 proc ProcessSendVersionCmd {proc id param {sock {}} {fn {}}} {
