@@ -48,7 +48,7 @@ proc VLADialog {} {
     set w $var(top)
     IMGSVRInit $varname "VLA [msgcat::mc {Server}]" VLAExec VLAAck
 
-    menu $var(mb).survey
+    ThemeMenu $var(mb).survey
     $var(mb) add cascade -label Survey -menu $var(mb).survey
     $var(mb).survey add radiobutton -label {First} \
 	-variable ${varname}(survey) -value first
@@ -65,7 +65,7 @@ proc VLAExec {varname} {
     global $varname
 
     if {$var(save)} {
-	set var(fn) [SaveFileDialog savefitsfbox]
+	set var(fn) [SaveFileDialog savefitsfbox $var(top)]
 	if {$var(fn) == {}} {
 	    ARDone $varname
 	    return
