@@ -21,6 +21,7 @@ proc VODef {} {
     # prefs only
     set pvo(server) {http://cxc.harvard.edu/chandraed/list.txt}
     set pvo(hv) 1
+    # only support mime now (not xpa)
     set pvo(method) mime
     set pvo(delay) 15
 }
@@ -150,7 +151,7 @@ proc VODialog {} {
 
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
 
-    menu $mb.file
+    ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] \
 	-command "VOApply $varname"
     $mb.file add command -label [msgcat::mc {Cancel}] \
@@ -162,7 +163,7 @@ proc VODialog {} {
 	-command [list PrefsDialog http]
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command "VODestroy $varname"
+	-command "VODestroy $varname" -accelerator "${ds9(ctrl)}W"
 
     # Sites
     ttk::labelframe $w.param -text [msgcat::mc {Sites}] -padding 2
@@ -173,14 +174,7 @@ proc VODialog {} {
 			    -text [msgcat::mc {Use Internal Web Browser}] \
 			    -variable pvo(hv) \
 			    -command SavePrefs]
-    ttk::radiobutton $w.opt.xpa \
-	-text [msgcat::mc {Connect Directly}] \
-	-variable pvo(method) -value xpa -command PrefsVOMethod
-    ttk::radiobutton $w.opt.http \
-	-text [msgcat::mc {Connect Using Web Proxy}] \
-	-variable pvo(method) -value mime -command PrefsVOMethod
     grid $w.opt.hv -padx 2 -pady 2 -sticky w
-    grid $w.opt.xpa $w.opt.http -padx 2 -pady 2 -sticky w
 
     set f [ttk::frame $w.buttons]
     ttk::button $f.help -text [msgcat::mc {Help Me Choose}] \
@@ -199,6 +193,8 @@ proc VODialog {} {
     grid rowconfigure $w 1 -weight 1
     grid columnconfigure $w 0 -weight 1
 
+    bind $w <<Close>> [list VODestroy $varname]
+
     if {[string length $ivo(server,host)] == 0} {
 	VOApply $varname
     } else {
@@ -422,21 +418,16 @@ proc PrefsDialogVO {} {
 
     set w $dprefs(tab)
 
-    $dprefs(list) insert end [msgcat::mc {VO}]
-    lappend dprefs(tabs) [ttk::frame $w.vo]
+    $dprefs(listbox) insert {} end -id [ttk::frame $w.vo] \
+	-text [msgcat::mc {VO}]
 
     # Browser
     set f [ttk::labelframe $w.vo.browser -text [msgcat::mc {Browser}]]
 
     ttk::checkbutton $f.web -text [msgcat::mc {Use Internal Web Browser}] \
 	-variable pvo(hv)
-    ttk::radiobutton $f.xpa -text [msgcat::mc {Connect Directly}] \
-	-variable pvo(method) -value xpa -command PrefsVOMethod
-    ttk::radiobutton $f.mime -text [msgcat::mc {Connect Using Web Proxy}] \
-	-variable pvo(method) -value mime -command PrefsVOMethod
 
     grid $f.web -padx 2 -pady 2 -sticky w
-    grid $f.xpa $f.mime -padx 2 -pady 2 -sticky w
 
     # Server
     set f [ttk::labelframe $w.vo.server -text [msgcat::mc {VO Server}]]
