@@ -167,18 +167,21 @@ proc WCSDialog {} {
     $mb add cascade -label [msgcat::mc {WCS}] -menu $mb.wcs
     $mb add cascade -label [msgcat::mc {Extention}] -menu $mb.ext
 
-    menu $mb.file
+    ThemeMenu $mb.file
+    $mb.file add command -label "[msgcat::mc {Open}]..." \
+	-command WCSLoadDialog -accelerator "${ds9(ctrl)}O"
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command WCSSaveDialog -accelerator "${ds9(ctrl)}S"
+    $mb.file add separator
     $mb.file add command -label [msgcat::mc {Apply}] -command WCSApplyDialog
     $mb.file add command -label [msgcat::mc {Reset}] -command WCSResetDialog
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load}]..." -command WCSLoadDialog
-    $mb.file add command -label "[msgcat::mc {Save}]..." -command WCSSaveDialog
-    $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Close}] -command WCSDestroyDialog
+    $mb.file add command -label [msgcat::mc {Close}] \
+	-command WCSDestroyDialog -accelerator "${ds9(ctrl)}W"
 
     EditMenu $mb iwcs
 
-    menu $mb.wcs
+    ThemeMenu $mb.wcs
     $mb.wcs add radiobutton -label [msgcat::mc {WCS}] \
 	-variable dwcs(system) -value wcs -command ConfigWCSDialog
     $mb.wcs add separator
@@ -188,7 +191,7 @@ proc WCSDialog {} {
     }
 
     # configured later
-    menu $mb.ext
+    ThemeMenu $mb.ext
 
     # Param
     set tt [ttk::notebook $w.param]
@@ -224,6 +227,10 @@ proc WCSDialog {} {
 	ttk::entry $base.wcsname${aa} \
 	    -textvariable dwcs(wcsname${aa}) -width 14
 
+	ttk::label $base.twcsaxes${aa} -text "WCSAXES${bb}"
+	ttk::entry $base.wcsaxes${aa} \
+	    -textvariable dwcs(wcsaxes${aa}) -width 14
+
 	ttk::label $base.tradesys${aa} -text "RADESYS${bb}"
 	ttk::entry $base.radesys${aa} \
 	    -textvariable dwcs(radesys${aa}) -width 14
@@ -240,6 +247,7 @@ proc WCSDialog {} {
 	ttk::entry $base.lonpole${aa} \
 	    -textvariable dwcs(lonpole${aa}) -width 14
 
+	# CTYPEx CRPIXx CRVALx CUNITx CDELTx
 	for {set ii 1} {$ii<=4} {incr ii} {
 	    ttk::label $base.tctype${ii}${aa} -text "CTYPE${ii}${bb}"
 	    ttk::entry $base.ctype${ii}${aa} \
@@ -262,6 +270,7 @@ proc WCSDialog {} {
 		-textvariable dwcs(cdelt${ii}${aa}) -width 14
 	}
 
+	# CDx_x PCx_x
 	for {set ii 1} {$ii<=4} {incr ii} {
 	    for {set jj 1} {$jj<=4} {incr jj} {
 		ttk::label $base.tcd${ii}_${jj}${aa} \
@@ -273,9 +282,22 @@ proc WCSDialog {} {
 		    -text "PC${ii}_${jj}${bb}"
 		ttk::entry $base.pc${ii}_${jj}${aa} \
 		    -textvariable dwcs(pc${ii}_${jj}${aa}) -width 14
+
 	    }
 	}
 
+	# PSx_x
+	for {set ii 1} {$ii<=4} {incr ii} {
+	    for {set jj 0} {$jj<=1} {incr jj} {
+		ttk::label $base.tps${ii}_${jj}${aa} \
+		    -text "PS${ii}_${jj}${bb}"
+		ttk::entry $base.ps${ii}_${jj}${aa} \
+		    -textvariable dwcs(ps${ii}_${jj}${aa}) -width 14
+	    }
+	}
+
+
+	# PVx_x
 	for {set ii 1} {$ii<=4} {incr ii} {
 	    for {set mm 0} {$mm<18} {incr mm} {
 		ttk::label $pv00.tpv${ii}_${mm}${aa} \
@@ -354,6 +376,10 @@ proc WCSDialog {} {
     pack $w.buttons -side bottom -fill x
     pack $w.param -side top -fill both -expand true
 
+    bind $w <<Open>> WCSLoadDialog
+    bind $w <<Save>> WCSSaveDialog
+    bind $w <<Close>> WCSDestroyDialog
+
     ConfigWCSDialog
     UpdateWCSDialog
 }
@@ -367,6 +393,7 @@ proc WCSApplyDialog {} {
 	RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs replace text $dwcs(ext) \{\{[WCSFromVar]\}\}"
 	UpdateWCS
 	CATUpdateWCS
+	FPUpdateWCS
     }
 }
 
@@ -379,6 +406,7 @@ proc WCSResetDialog {} {
 	RGBEvalLock rgb(lock,wcs) $current(frame) [list $current(frame) wcs reset $dwcs(ext)]
 	UpdateWCS
 	CATUpdateWCS
+	FPUpdateWCS
 	UpdateWCSDialog
     }
 }
@@ -395,10 +423,13 @@ proc WCSDestroyDialog {} {
 }
 
 proc WCSSaveDialog {} {
+    global iwcs
     global dwcs
 
-    set fn [SaveFileDialog wcsfbox]
-    WCSSaveFile $fn
+    set fn [SaveFileDialog wcsfbox $iwcs(top)]
+    if {$fn != {}} {
+	WCSSaveFile $fn
+    }
 }
 
 # used by backup
@@ -412,9 +443,10 @@ proc WCSSaveFile {fn} {
 }
 
 proc WCSLoadDialog {} {
+    global iwcs
     global dwcs
 
-    set fn [OpenFileDialog wcsfbox]
+    set fn [OpenFileDialog wcsfbox $iwcs(top)]
     WCSLoadFile $fn
 }
 
@@ -498,6 +530,7 @@ proc ConfigWCSDialog {{force {0}}} {
     set aa [string tolower [string range $dwcs(prev) 3 3]]
 
     grid forget $base.twcsname${aa} $base.wcsname${aa}
+    grid forget $base.twcsaxes${aa} $base.wcsaxes${aa}
     grid forget $base.tradesys${aa} $base.radesys${aa}
     grid forget $base.tequinox${aa} $base.equinox${aa}
     grid forget $base.tlatpole${aa} $base.latpole${aa}
@@ -518,6 +551,12 @@ proc ConfigWCSDialog {{force {0}}} {
 	}
     }
 
+    for {set ii 1} {$ii<=4} {incr ii} {
+	for {set jj 0} {$jj<=1} {incr jj} {
+	    grid forget $base.tps${ii}_${jj}${aa} $base.ps${ii}_${jj}${aa}
+	}
+    }
+
     for {set ii 1} {$ii<=4} {incr ii} {
 	for {set mm 0} {$mm<18} {incr mm} {
 	    grid forget $pv00.tpv${ii}_${mm}${aa} $pv00.pv${ii}_${mm}${aa}
@@ -565,6 +604,7 @@ proc ConfigWCSDialog {{force {0}}} {
     set aa [string tolower [string range $dwcs(system) 3 3]]
 
     grid $base.twcsname${aa} $base.wcsname${aa} -padx 2 -pady 2 -sticky w
+    grid $base.twcsaxes${aa} $base.wcsaxes${aa} -padx 2 -pady 2 -sticky w
     grid $base.tradesys${aa} $base.radesys${aa} -padx 2 -pady 2 -sticky w
 
     grid $base.tequinox${aa} $base.equinox${aa} \
@@ -641,6 +681,17 @@ proc ConfigWCSDialog {{force {0}}} {
 	$base.tpc4_4${aa} $base.pc4_4${aa} \
 	-padx 2 -pady 2 -sticky w
 
+    grid $base.tps1_0${aa} $base.ps1_0${aa} \
+	$base.tps2_0${aa} $base.ps2_0${aa} \
+	$base.tps3_0${aa} $base.ps3_0${aa} \
+	$base.tps4_0${aa} $base.ps4_0${aa} \
+	-padx 2 -pady 2 -sticky w
+    grid $base.tps1_1${aa} $base.ps1_1${aa} \
+	$base.tps2_1${aa} $base.ps2_1${aa} \
+	$base.tps3_1${aa} $base.ps3_1${aa} \
+	$base.tps4_1${aa} $base.ps4_1${aa} \
+	-padx 2 -pady 2 -sticky w
+
     grid $base.tlatpole${aa} $base.latpole${aa} \
 	$base.tlonpole${aa} $base.lonpole${aa} -padx 2 -pady 2 -sticky w
 
@@ -811,6 +862,7 @@ proc WCSToVar {txt} {
 
     foreach aa {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	set dwcs(wcsname${aa}) {}
+	set dwcs(wcsaxes${aa}) {}
 	set dwcs(radesys${aa}) {}
 	set dwcs(equinox${aa}) {}
 	set dwcs(latpole${aa}) {}
@@ -831,6 +883,12 @@ proc WCSToVar {txt} {
 	    }
 	}
 
+	for {set ii 1} {$ii<=4} {incr ii} {
+	    for {set jj 0} {$jj<=1} {incr jj} {
+		set dwcs(ps${ii}_${jj}${aa}) {}
+	    }
+	}
+
 	for {set ii 1} {$ii<=4} {incr ii} {
 	    for {set mm 0} {$mm<36} {incr mm} {
 		set dwcs(pv${ii}_${mm}${aa}) {}
@@ -933,6 +991,7 @@ proc WCSToVar {txt} {
 	}
 	switch [string range $key 0 5] {
 	    wcsnam -
+	    wcsaxe -
 	    radesy -
 	    equino -
 	    latpol -
@@ -966,6 +1025,10 @@ proc WCSToVar {txt} {
 	    pc2_ -
 	    pc3_ -
 	    pc4_ -
+	    ps1_ -
+	    ps2_ -
+	    ps3_ -
+	    ps4_ -
 	    pv1_ -
 	    pv2_ -
 	    pv3_ -
@@ -1012,6 +1075,9 @@ proc WCSFromVar {} {
 	if {$dwcs(wcsname${aa}) != {}} {
 	    append rr "WCSNAME${bb} = '$dwcs(wcsname${aa})'\n"
 	}
+	if {$dwcs(wcsaxes${aa}) != {}} {
+	    append rr "WCSAXES${bb} = '$dwcs(wcsaxes${aa})'\n"
+	}
 	if {$dwcs(radesys${aa}) != {}} {
 	    append rr "RADESYS${bb} = '$dwcs(radesys${aa})'\n"
 	}
@@ -1054,6 +1120,15 @@ proc WCSFromVar {} {
 	    }
 	}
 
+	for {set ii 1} {$ii<=4} {incr ii} {
+	    for {set jj 0} {$jj<=1} {incr jj} {
+		if {$dwcs(ps${ii}_${jj}${aa}) != {}} {
+		    append rr \
+			"PS${ii}_${jj}${bb} = '$dwcs(ps${ii}_${jj}${aa})'\n"
+		}
+	    }
+	}
+
 	for {set ii 1} {$ii<=4} {incr ii} {
 	    for {set mm 0} {$mm<36} {incr mm} {
 		if {$dwcs(pv${ii}_${mm}${aa}) != {}} {
@@ -1142,6 +1217,9 @@ proc WCSCmdReset {ext} {
     RGBEvalLock rgb(lock,wcs) $current(frame) \
 	[list $current(frame) wcs reset $ext]
     UpdateWCS
+    CATUpdateWCS
+    FPUpdateWCS
+    UpdateWCSDialog
 }
 
 proc WCSCmdLoad {cmd ext} {
@@ -1157,8 +1235,12 @@ proc WCSCmdLoad {cmd ext} {
 	RGBEvalLock rgb(lock,wcs) $current(frame) [list $current(frame) wcs $cmd $ext $parse(sock)]
     } elseif {$parse(fn) != {}} {
 	RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs $cmd $ext \{\{$parse(fn)\}\}"
-	UpdateWCS
     }
+
+    UpdateWCS
+    CATUpdateWCS
+    FPUpdateWCS
+    UpdateWCSDialog
 }
 
 proc WCSCmdLoadFn {cmd ext fn} {
@@ -1171,6 +1253,9 @@ proc WCSCmdLoadFn {cmd ext fn} {
 
     RGBEvalLock rgb(lock,wcs) $current(frame) "$current(frame) wcs $cmd $ext \{\{$fn\}\}"
     UpdateWCS
+    CATUpdateWCS
+    FPUpdateWCS
+    UpdateWCSDialog
 }
 
 proc ProcessSendWCSCmd {proc id param {sock {}} {fn {}}} {
