@@ -214,6 +214,11 @@ proc CreateXPA {} {
 	XPASendFits {} "fillbuf=false" \
 	XPARcvdFits {} "fillbuf=false"
 
+    xpacmdadd $xpa footprint \
+	{} \
+	XPASendFP {} {} \
+	XPARcvdFP {} "fillbuf=false"
+
     xpacmdadd $xpa frame \
 	{} \
 	XPASendFrame {} {} \
@@ -445,6 +450,11 @@ proc CreateXPA {} {
 	XPASendPrint {} {} \
 	XPARcvdPrint {} "fillbuf=false"
 
+    xpacmdadd $xpa prism \
+	{} \
+	XPASendPrism {} {} \
+	XPARcvdPrism {} "fillbuf=false"
+
     xpacmdadd $xpa psprint \
 	{} \
 	XPASendPSPrint {} {} \
@@ -1044,6 +1054,19 @@ proc XPARcvdFits {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendFP {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendFootprintCmd xpasetbuf $xpa $param {} {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdFP {xpa cdata param buf len} {
+    XPADebug "XPARcvdFP" $param
+    InitError xpa
+    catch {set i 0; ProcessFootprintCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendFrame {xpa cdata param} {
     InitError xpa
     catch {ProcessSendFrameCmd xpasetbuf $xpa $param}
@@ -1133,6 +1156,7 @@ proc XPARcvdIconify {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+# backward compatibility
 proc XPASendIExam {xpa cdata param} {
     InitError xpa
     catch {ProcessSendIExamCmd xpasetbuf $xpa $param}
@@ -1596,6 +1620,19 @@ proc XPARcvdPrint {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendPrism {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendPrismCmd xpasetbuf $xpa $param}
+    XPACatchError $xpa
+}
+
+proc XPARcvdPrism {xpa cdata param buf len} {
+    XPADebug "XPARcvdPrism" $param
+    InitError xpa
+    catch {set i 0; ProcessPrismCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendPSPrint {xpa cdata param} {
     InitError xpa
     catch {ProcessSendPSPrintCmd xpasetbuf $xpa $param}
