@@ -32,15 +32,20 @@ set WCSZ_ 287
 set INT_ 288
 set REAL_ 289
 set STRING_ 290
-set CLEAR_ 291
-set CLOSE_ 292
-set COLOR_ 293
-set MARK_ 294
-set NAN_ 295
-set NONNAN_ 296
-set NONZERO_ 297
-set OPEN_ 298
-set RANGE_ 299
-set SYSTEM_ 300
-set TRANSPARENCY_ 301
-set ZERO_ 302
+set BLEND_ 291
+set CLEAR_ 292
+set CLOSE_ 293
+set COLOR_ 294
+set DARKEN_ 295
+set LIGHTEN_ 296
+set LOAD_ 297
+set MARK_ 298
+set NAN_ 299
+set NONNAN_ 300
+set NONZERO_ 301
+set OPEN_ 302
+set RANGE_ 303
+set SOURCE_ 304
+set SYSTEM_ 305
+set TRANSPARENCY_ 306
+set ZERO_ 307
