@@ -45,9 +45,11 @@ set STRING_ 300
 set ALIGN_ 301
 set APPEND_ 302
 set CLOSE_ 303
-set OPEN_ 304
-set REPLACE_ 305
-set RESET_ 306
-set SKY_ 307
-set SKYFORMAT_ 308
-set SYSTEM_ 309
+set LOAD_ 304
+set OPEN_ 305
+set REPLACE_ 306
+set RESET_ 307
+set SAVE_ 308
+set SKY_ 309
+set SKYFORMAT_ 310
+set SYSTEM_ 311
