@@ -6,7 +6,10 @@
 #define __base_h__
 
 #include "widget.h"
+#include "vector.h"
 #include "vector3d.h"
+#include "vectorstr.h"
+#include "fuzzy.h"
 
 #include "callback.h"
 #include "fvcontour.h"
@@ -18,7 +21,6 @@
 #include "inversescale.h"
 #include "list.h"
 #include "tag.h"
-#include "util.h"
 #include "point.h"
 #include "fitsmask.h"
 
@@ -118,7 +120,8 @@ public:
   enum CompressType {NOCOMPRESS, GZ};
   enum FileNameType {ROOTBASE, FULLBASE, ROOT, FULL};
   enum MarkerFormat {DS9, XML, CIAO, SAOTNG, SAOIMAGE, PROS, RAWXY};
-  enum MarkerLayer {USER, TEMPLATE, CATALOG, ANALYSIS};
+  enum MarkerLayer {USER, CATALOG, FOOTPRINT};
+  enum MarkerRenderOrder {HEAD,TAIL};
   enum ShmType {SHMID,KEY};
   enum UndoMarkerType {NONE, MOVE, EDIT, DELETE};
   enum UpdateType {MATRIX, BASE, BASEONLY, PIXMAP, NOUPDATE};
@@ -151,6 +154,10 @@ public:
   List<Marker> undoCatalogMarkers;  // remember marker to undo
   List<Marker> pasteCatalogMarkers; // cut/copy/paste
 
+  List<Marker> footprintMarkers;      // background marker stack
+  List<Marker> undoFootprintMarkers;  // remember marker to undo
+  List<Marker> pasteFootprintMarkers; // cut/copy/paste
+
   UndoMarkerType undoMarkerType; // type
 
   Vector markerBegin;        // marker move begin in image coords
@@ -187,7 +194,6 @@ public:
   int pannerHeight;          // panner height
   char pannerName[32];       // panner widget name
   int usePanner;             // panner status
-  GC pannerGC;
 
   Pixmap magnifierPixmap;    // pixmap for magnifier
   XImage* magnifierXImage;   // ximage for magnifier
@@ -226,7 +232,8 @@ public:
   int invert;
 
   int useHighlite;
-  GC highliteGC;
+  char* highliteColourName;
+  GC highliteGC_;
 
   int useCrosshair;
 
@@ -248,6 +255,9 @@ public:
   float centroidRadius;
   int preserveMarkers;       // flag to indicate preserve between loads
 
+  int useMarkerColor_;
+  char* markerColor_;
+
   GC markerGC_; // marker gc
   GC markerGCXOR_; // marker xor gc
   GC selectGCXOR; // select gc
@@ -257,6 +267,7 @@ public:
 
   GC contourGC_;
 
+  int useBgColor;
   char* bgColourName;
   char* nanColourName;
 
@@ -420,7 +431,7 @@ public:
   void psCrosshair(PSColorSpace);
   virtual void psGraphics(PSColorSpace) {}
   void psImage(ostream&, Filter&, int, int, float);
-  void psMarkers(List<Marker>*, PSColorSpace);
+  void psMarkers(List<Marker>*, PSColorSpace, MarkerRenderOrder);
   Matrix psMatrix(float scale, int width, int height);
   void pushMatrices(FitsImage*, Matrix&);
   void pushMagnifierMatrices(FitsImage*);
@@ -478,7 +489,7 @@ public:
   virtual void x11Graphics();
   virtual void x11MagnifierCursor(const Vector&) {}
   void x11MagnifierMarkers(List<Marker>*, const BBox& bb);
-  void x11Markers(List<Marker>*, const BBox&);
+  void x11Markers(List<Marker>*, const BBox&, MarkerRenderOrder);
   void xmlParse(istream&);
   void xmlParseFIELD(void*, int*, char**, char**, char**, char**, int);
   void xmlParseTR(char**, int*, char**, char**, char**, char**, int);
@@ -555,6 +566,9 @@ public:
   Coord::CoordSystem xySystem() {return xySystem_;}
   Coord::SkyFrame xySky() {return xySky_;}
 
+  int useMarkerColor() {return useMarkerColor_;}
+  char* markerColor() {return markerColor_;}
+
   void matchCmd(const char* xxname1, const char* yyname1,
 		Coord::CoordSystem sys1, Coord::SkyFrame sky1,
 		const char* xxname2, const char* yyname2,
@@ -567,6 +581,8 @@ public:
   void getAxesOrderCmd();
 
   // Background Commands
+  void useBgColorCmd(int);
+  void hasBgColorCmd();
   void bgColorCmd(const char*);
   void getBgColorCmd();
 
@@ -613,6 +629,7 @@ public:
   void clipModeCmd(float);
   void clipModeCmd(FrScale::ClipMode);
   void clipMinMaxCmd(FrScale::MinMaxMode, int);
+  void clipMinMaxRescanCmd();
   // backward compatibilty backup
   void clipMinMaxModeCmd(FrScale::MinMaxMode);
   // backward compatibilty backup
@@ -969,6 +986,8 @@ public:
   virtual void getTypeCmd() =0;
   void getFitsWidthCmd();
   void highliteCmd(int);
+  void highliteColorCmd(const char*);
+  void getHighliteColorCmd();
   void warpCmd(const Vector&);
   void warpToCmd(const Vector&);
 
@@ -1383,10 +1402,10 @@ public:
   void markerCutCmd();
   void markerCutCmd(const char*);
 
-  void markerDeleteCmd();
+  void markerDeleteAllCmd(int);
+
   void markerDeleteCmd(const char*);
   void markerDeleteCmd(int);
-  void markerDeleteAllCmd();
   void markerDeleteLastCmd();
   void markerDeleteCallBackCmd(int, CallBack::Type, const char*);
   void markerDeleteTagCmd(int);
@@ -1437,18 +1456,20 @@ public:
   void markerKeyCmd();
   void markerKeyCmd(const Vector&);
 
-  void markerLineCmd(int, const Vector&, const Vector&, Coord::CoordSystem, Coord::SkyFrame);
+  void markerLineCmd(int, const Vector&, const Vector&,
+		     Coord::CoordSystem, Coord::SkyFrame);
   void markerLineArrowCmd(int, int, int);
   void markerLineWidthCmd(int);
   void markerLineWidthCmd(int, int);
-  void markerListCmd(MarkerFormat, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, 
+  void markerListCmd(MarkerFormat,
+		     Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, 
 		     int strip, int select,
 		     unsigned short, unsigned short, List<Tag>&);
-  void markerLoadCmd(MarkerFormat,const char*);
-  void markerLoadCmd(MarkerFormat,const char*,Coord::CoordSystem,Coord::SkyFrame);
-  void markerLoadCmd(MarkerFormat,int);
-  void markerLoadCmd(MarkerFormat,int,Coord::CoordSystem,Coord::SkyFrame);
-  void markerLoadFitsCmd(const char*, const char*, int*, int, const char*);
+  void markerLoadCmd(MarkerFormat, const char*, int, const char*,
+		     Coord::CoordSystem, Coord::SkyFrame);
+  void markerLoadCmd(MarkerFormat, int, int, const char*,
+		     Coord::CoordSystem, Coord::SkyFrame);
+  void markerLoadFitsCmd(const char*, const char*);
 
   void markerMoveCmd(const Vector&);
   void markerMoveCmd(const char*, const Vector&);
@@ -1487,8 +1508,7 @@ public:
   void markerRulerSystemCmd(int, Coord::CoordSystem, Coord::SkyFrame, 
 			    Coord::CoordSystem, Coord::DistFormat);
 
-  void markerSaveCmd(const char*, MarkerFormat, Coord::CoordSystem, Coord::SkyFrame,
-		     Coord::SkyFormat, int strip);
+  void markerSaveCmd(const char*, MarkerFormat, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int strip, int select);
   void markerSaveTemplateCmd(const char*);
   void markerSegmentCreateVertexCmd(int, int, const Vector&);
   void markerSegmentDeleteVertexCmd(int, int);
@@ -1542,12 +1562,14 @@ public:
   virtual void getMaskRangeCmd();
   virtual void getMaskSystemCmd();
   virtual void getMaskTransparencyCmd();
+  virtual void getMaskBlendCmd();
 
   virtual void maskClearCmd() {};
   virtual void maskColorCmd(const char*) {};
   virtual void maskMarkCmd(FitsMask::MaskType) {};
   virtual void maskRangeCmd(double,double) {};
   virtual void maskTransparencyCmd(float) {};
+  virtual void maskBlendCmd(FitsMask::MaskBlend) {};
   virtual void maskSystemCmd(Coord::CoordSystem) {};
 
   // NaN Commands
@@ -1684,7 +1706,6 @@ public:
   virtual void set3dViewPointCmd(const Vector3d&, const Vector&) {}
   virtual void set3dRenderMethodCmd(int) {}
   virtual void set3dRenderBackgroundCmd(int) {}
-  virtual void set3dPreserveCmd() {}
 };
 
 #endif
