@@ -154,6 +154,7 @@ class FitsImage {
   void initBin();
   void initHPX();
 
+  void clearWCS();
   void initWCS(FitsHead*);
   void scanWCS(FitsHead*);
   void wcsPhyInit(FitsHead*);
@@ -338,9 +339,9 @@ class FitsImage {
 
   Matrix nextBin(const Vector&);
   void calcHistSize();
+  Vector getColMinMax(const char*);
+  Vector getColDim(const char*);
   Vector getHistDim();
-  Vector getHistColMinMax(const char*);
-  Vector getHistColDim(const char*);
   Vector getHistCursor() {return actualHistCursor;}
   const char* getHistFilter();
   const char* getHistX();
@@ -507,7 +508,6 @@ class FitsImage {
   double low() {return data_ ? data_->low() : 0;}
   double high() {return data_ ? data_->high() : 0;}
 
-  void updateClip(FrScale*);
   void updateClip(FrScale* fr, pthread_t* thread, t_clip_arg* targ);
 
   int hasDATAMIN() {return data_ ? data_->hasDATAMIN() : 0;}
