@@ -5,7 +5,7 @@
 #ifndef __fitsmask_h__
 #define __fitsmask_h__
 
-#include "util.h"
+#include "vector.h"
 
 class Base;
 class Context;
@@ -13,6 +13,7 @@ class Context;
 class FitsMask {
  public:
   enum MaskType {ZERO, NONZERO, NaN, NONNaN, RANGE};
+  enum MaskBlend {SOURCE, SCREEN, DARKEN, LIGHTEN};
 
  private:
   Context* context_;
