@@ -9,12 +9,15 @@
 
 #include "vector.h"
 #include "vector3d.h"
+#include "vectorstr.h"
+#include "fuzzy.h"
+
 #include "callback.h"
 #include "list.h"
 #include "tag.h"
 #include "coord.h"
 #include "xml.h"
-#include "util.h"
+#include "psutil.h"
 
 #define POINTSIZE 11
 
