@@ -16,11 +16,13 @@
 #include <iomanip>
 using namespace std;
 
-#include <tcl.h>
 #include <tk.h>
 
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+
 #include "vector.h"
-#include "util.h"
+#include "psutil.h"
 
 class Attribute;
 
@@ -167,7 +169,10 @@ class Widget {
 
   void warp(Vector&);
   void warpTo(Vector&);
+  int setClipRectangles(Display *d, GC gc, int x, int y,
+			XRectangle* rects, int n, int order);
 
+  Vector TkCanvasPs(const Vector&);
   void psColor(PSColorSpace mode, XColor* clr);
 
   // Required Canvas Functions
